#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqX0XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwXtX6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X7X7X0XrXeXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXeXrXqX5XwXrXeXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXeXrX0X6XeXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXeXrX8X0XqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXCX.X;X*X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X*X=X&X@X(.T.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.T.(.+X~.T.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.T.`.+XQ.R.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.T.].8XwXqXqXqXqXqXqX",
"qXqXqXqXqXqX9XdXMX*XiXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXtX4X:Xx.} $.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.$.} j.9Xw. .#.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.%.{ Z.5X<.X.#.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.%.} T.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XrX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XwX2X-Xm.%.<.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.%.c.5Xa.&.,.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.$.F.2X9.-.,.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.%.E.eXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqX9X8X8X8X8X0XqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqX0XsXkXlXlXhXeX0XqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX0XrX/.M.M.N.J.2XrX0XqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XdXU         E <XtX0XqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX_ = x.^.|   x.pX0XqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX~ & $XMX).= | qXwXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX~ &  XdX_.3 _ 0XeXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX~ % _.yXa.  w.yXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX)   5 u $ 9 .XpX0XqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX( o N % 5 W.iX9XqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX! = 2X$.  T.dX8XqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX^ @ %X^.  / 9XwX0XqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX! #  XuX`   ^.sX9XqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX( ; |.hXH.@  .0XeXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqX9X8XqXqXwX0X7XqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXwXeXqXqXqXwXwXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX3X;Xn.#.>.;.;.:.;.;.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.#.x.6Xi.%.>.;.;.:.;.;.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.,.@.D.2X7.*.:.;.;.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.,.#.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX&XyXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX3X;Xv.X.=.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.=.X.l.7Xt.O.=.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.*.&.&.&.&.&.-...S.3X4.#.*.&.&.&.&.&.&.&.&.*.&.&.&.&.&.&.*.&.&.&.&.&.-.X.R.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXNX$XwX8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X9X1X=XV.<.9.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.9.<.M.3Xj.2.8.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.9.<.J.<Xu.4.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.9.<.Q.eXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XsXVX X+XOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXoX@XOX*X4X2X2X2X2X2X2X2X2X1X<X<X<X<X<X<X1X2X2X2X2X2X2X2X4X-X{.:X4X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X4X&X}.<X3X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X5X+X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXBX+X1X>X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X>X,X-X%XQ.Z.F.D.D.D.D.D.A.A.H.I.U.T.Y.U.P.G.A.S.D.D.D.D.F.Z.W.*XU.A.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.F.C./.&XJ.S.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.F.Z.`.0XwXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX&XuXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXtX4X;Xz.{ #.+.+.+.+.O.*.*.^ M k s d l B _ =.&.O.+.+.+.#.{ h.8Xw.| #.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.$.[ C.4X<...@.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.+.$.{ T.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XrX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XwX2X-Xm.%.<.>.>.>.<.1.P t 3 X         O 5 i Q 3.,.>.>.<.%.c.5Xa.&.,.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.$.F.2X9.-.,.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.%.E.eXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.-.1._ 0 o       . X X .       @ t  .1.-.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.-.<.I $     . .             . .     = ^ 1.:.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqX8X6X0XqX0X6X9XqXqXqXqXqXqXqXqXeX3X;Xn.@.>.1.P   .                               X ~ 2.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqX0XgXxXrX0XyXcXsXqXqXqXqXqXqXqXqXeX3X;Xn.@.<._ @ .                                   * X.#.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX0XyXA.0.:XuX@X8.T.eXqXqXqXqXqXqXqXeX3X;Xn.@.>.4                                         u *.z.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XdXJ   ].hXH.  @.tXwXqXqXqXqXqXqXeX3X;Xb.&.J .                                         # J n.5Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX) : |.fXY.= 1.rXwXqXqXqXqXqXqXeX3X-Xv.&.5   .                                     .   7 B.4Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX~ % {.sXP.@ ,.tXwXqXqXqXqXqXqXeX3X-XM.Q ;                                         .   - u.8Xu.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX~ & &XNX^.# >.tXwXqXqXqXqXqXqXeX3X=XZ.l X                                           .   #.eXy.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX^ # b._.u.X ,.rXwXqXqXqXqXqXqXeX3X*XA.t   .                                         o   [ tXy.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX_           3.eXwXqXqXqXqXqXqXeX3X*XD.8   .                                         O   ( yXt.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX/ + e.S.1.  <.rXwXqXqXqXqXqXqXeX3X*XD.8   .                                         O   ( yXt.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX~ & *XBX/.# >.tXwXqXqXqXqXqXqXeX3X*XS.r   .                                         o   [ tXy.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsX^ & ].pXL.# ,.tXwXqXqXqXqXqXqXeX3X*XZ.h                                             X   +.eXy.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XsXR X {.gXL.  -.tXwXqXqXqXqXqXqXeX3X=XN.T -                                         .   & e.9Xu.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqX9XaXO.u XXdXQ.r w.rXqXqXqXqXqXqXqXeX3X-Xv.%.2   .                                     .   5 M.4Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqX0XpXfXeX0XrXfXuXqXqXqXqXqXqXqXqXeX3X;Xv.*.Z .                                         @ A m.4Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqX9X8XqXqX0X8X0XqXqXqXqXqXqXqXqXeX3X;Xb.@.:.,                                         w %.z.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.<.W o .                                   $ ] $.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.1.Z   .                                 I 3.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.,.Z X     .                 .     @ P <.:.@.x.6Xi.$.:.;.;.;.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX2X-Xn.#.,.:.:.2.Q 1 X     . X X X X .     X 6 ` 2.;.,.#.c.6Xp.%.>.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.,.#.D.2X8.=.>.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.,.#.E.eXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX&XuXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXrX4X;Xx. .&.$.$.$.&.@.b = +             # : Z $.&.$.$.&. .k.8Xr.X.%.$.$.$.$.$.$.$.#.$.$.$.$.$.$.#.$.$.$.$.$.$.&.| A.4X2.O.%.$.$.$.$.$.$.$.#.$.$.$.$.$.$.#.$.$.$.$.$.$.&. .T.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXNX#X9X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X6X,X*XF.w.p.i.i.i.i.i.d.s.*.T D N N D E :.d.d.i.i.i.i.p.w.S.<Xn.r.p.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.a.w.U.:Xj.t.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.a.w.~.wXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XsXVX|.OXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXX+XoX-X8X5X6X6X6X6X6X5X5X9XeXtXyXyXtXeX8X5X5X6X6X6X6X6X8X:X[.<X8X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X5X8X*X{.3X7X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X5X9X+X5XwXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXNX@X5X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X3X>X&XP.j.c.x.x.x.x.x.x.x.z.l.l.k.k.l.l.z.x.x.x.x.x.x.c.j.L.:XS.k.c.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.c.h.W.-XM.l.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.c.j.(.qXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX&XuXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXtX4X;Xz.} $.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.$.} j.8Xw. .#.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.%.{ Z.4X<.X.#.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.%.} T.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX2X-Xn.$.<.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.$.c.6Xp.&.,.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.#.F.2X9.=.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.$.E.eXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X;Xn.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.x.6Xi.$.:.;.;.;.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.+.D.2X7.&.;.;.;.;.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.E.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX%XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX2X-Xn.$.<.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.$.c.5Xp.&.,.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.#.F.2X9.=.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.$.E.eXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XdXMX&XuXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXrX3X;Xx.{ $.@.@.@.@.@.@.@.+.@.@.@.@.@.@.+.@.@.@.@.@.@.$.} j.8Xw. .#.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.%.{ Z.4X<.X.#.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.@.%.} T.rXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX9XsXNX%X7X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X5X1X=XI.x.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.z.P.-XF.x.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.m.z.Q.*XV.v.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.n.m.x.(.0XqXqXqXqXqXqXqX",
"qXqXqXqXqXqX8XfXBXW._.).(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.)./.].=X;X-X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X-X;X&XoX*X;X-X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X-X;X%XOX=X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X-X:X@X7XwXqXqXqXqXqXqX",
"qXqXqXqXqXqX0XrXuX;X<X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X;XqXrX&X5X2X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X2X4X>X+X,X4X2X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X2X4X-X@X1X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X2X4X&X7XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX0X0XtXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXtX0XnXcX=XuXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXtX3XXX6XrXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXtX,XoX9XrXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXtX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqX0XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX6XlXkX=XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX2XoX5XwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX>XOX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX*X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqXqXqX7X6X0XqXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqXqX0XgXvXyXqXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqX0XwXeX*.s Q.tXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqX0X0X9XO.    V.yXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqX9XaXe.# V @ C.yXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqX9XaX^.R.g.  C.yXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqX0XqXxXi.  Z.yXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqX6XdXp.  Z.yXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqX7XgXp.  Z.yXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqX7XgXp.  Z.yXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqX7XgXp.  Z.yXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqX7XfXa.. A.yXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqX7XhXq.  m.uXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqX9XpXU._ _.rXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqXqX0XaXbXuX0XqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqXqXqX9X5X9XqXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX=XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2XoX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX,XOX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXlX*XrX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XwX2XoX5XwX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XeX>XOX8XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XeX*X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzXkX=XuXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXtX3XXX6XtXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXtX,XoX0XrXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXtX=X6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XlXxX#X3X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X1X:X$X>X1X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X1X;X%X,X1X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X1X*X8XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX6XcXjXT.)././././././././././././././././././././././././.(._.(./././././././././././././././././././././././././.)._.(././././././././././././././././././././././././.(./.6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXwX3X5X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X5X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X5X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X5X4X0XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXwXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqX9XwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXqXqXqXqX",
"qXwX9XjX5X;X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X:X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X1X;X;X1X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X1X;X:X1X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X>XqXqXqXqX",
"qXwX7XBX3X4X7X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X7X,XW.<.6.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.6.:.~.~.:.6.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.6.>._.R.:.6.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.4.5.<.`.tX0XqXqX",
"qXwX7XmX5XqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeX3XW.@.-.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.-.o.~.~.o.-.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.-.O.`.T.o.;.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.-.@.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX2XW.%.>.:.:.:.:.:.:.:.:.:.:.:.;.:.;.;.:.>.@.~.~.@.>.:.:.:.:.:.:.:.:.:.:.:.;.:.;.;.:.>.#.`.T.@.>.:.:.:.:.:.:.:.:.:.:.:.;.:.;.;.:.>.%.`.tX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqX9X7X7X7X9XqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqX0XpXzXxXzXyX0XqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX0XyX/.t.e.i.#XyX0XqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XjX$.  i = t -XtX0XqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XjX=.a uX+X# d.sX9XqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.@.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XkX%.i sX0Xa <.dX9XqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.@.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XjX*.8 {.n.  A.aX9XqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XgX1.  % . ( 9XwX0XqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XjX%.s x.+ I.gX7XqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XjX=.d aXj U sX0XqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XlX ., uXS.  I.pX9XqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX9XpXG.q.wX4X4.H.uX0XqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqX0XsXkXqXwXzXsX0XqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqX9X7XqXqX7X9XqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX4X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX2XQ.&.,.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.,.#.~.~.#.,.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.,.$.`.T.#.,.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.>.&.`.tX0XqXqX",
"qXwX7XmX5XqXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXeX3XE.X.&.$.$.$.$.$.$.$.$.$.$.$.$.$.$.$.$.&.| !.!.| &.$.$.$.$.$.$.$.$.$.$.$.$.$.$.$.$.&. ._.Y.| &.$.$.$.$.$.$.$.$.$.$.$.$.$.$.$.$.%.X._.yX0XqXqX",
"qXwX7XMX3X2X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X5X>X(.i.f.d.d.d.d.d.d.s.s.s.s.s.d.d.d.d.d.f.u._._.u.f.d.d.d.d.d.d.d.d.d.d.d.d.d.d.d.d.f.u.[.^.y.f.d.d.d.d.d.d.d.d.d.d.d.d.d.d.d.d.f.i.{.rX0XqXqX",
"qXwX7XNX1XXX@X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X@X+X;X-X-X-X-X-X=X;X<X1X1X1X,X-X=X-X-X-X-X:XOXOX:X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X;XOX+X:X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X#XqXqXqXqX",
"qXwX7XMX4X8X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XqX1XQ.;.2.1.1.<.2.9.<...] ' { O.4.8.1.<.1.2.*.^.^.*.2.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.2.=.`.R.*.3.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.2.;.'.tX0XqXqX",
"qXwX7XMX5X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.#.;.=.*.,.+.M 0 O       % y H -.:.*.;.O.~.~.O.;.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.;.+._.T.o.;.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.-.#.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX2XW.%.:.;.1.I ;       . X .       7 ] 2.;.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.#.`.T.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqX9X7XqXqX7X9XqXqXqXqXqXqXwX2XW.$.:.<.N     . .         . X .   @ W 3.+.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqX0XsXkXqXeXlXiX0XqXqXqXqXqXwX2XW.#.2.H     .                   .   + ] %.!.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX0XiXI.d.wX3Xu.`.yX0XqXqXqXqXwX2XW.=.| @   .                       .   7 +.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XlX| < rX&X+ y.dX9XqXqXqXqXwX2XW.-.f   .                           .   B '.!.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XjX=.p 0X$X8 h.sX9XqXqXqXqXwX2X!. .*                               X   6 (.!.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.@.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XkX%.p xX9X7 f.sX9XqXqXqXqXwX<X(.S .                               .   . S.).+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.@.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XjX-.1 l.t.= h.aX9XqXqXqXqXwX<X`.l   X                               X   b.`.O.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XhX1.  6 4   l.pX9XqXqXqXqXwX<X'.f   X                               o   x.'.O.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XkX&.y eX*X4 f.sX9XqXqXqXqXwX<X`.j   X                               o   v.'.O.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XjX=.a tX-X9 h.sX9XqXqXqXqXwX<X_.m   .                               .   B._.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX8XlX| < eX%X+ y.dX9XqXqXqXqXwX1X~.( $                               .   > E.^.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqX0XiXI.d.wX3Xu.`.yX0XqXqXqXqXwX2XW.*.7   .                           .   d ].Q.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqX0XsXkXqXeXlXiX0XqXqXqXqXqXwX2XE.-.W   .                         .   * ' /.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqX9X7XqXqX7X9XqXqXqXqXqXqXwX2XW.%.,.s   X                     . .   G *.!.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.,.%.6   . .               .     l 1.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX4X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqX2XQ.&.>.<.&.s     . X o o o X     O V <.,.#.~.~.#.,.:.>.:.:.>.>.>.>.>.>.>.>.>.>.>.>.,.$.`.R.#.,.:.>.:.:.>.>.>.>.>.>.>.>.>.>.>.>.,.&.`.tX0XqXqX",
"qXwX7XmX5XqXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXrX3XE...%.@.%.$.H :               8 Q =.#.$.} !.!.} %.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.%.| _.U.} %.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.$.X._.yX0XqXqX",
"qXwX7XMX3X1X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X2X3X:X_.g.z.l.k.l.v.l.7.' E Y Q ..t.x.v.k.l.z.f.`.`.f.z.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.z.f.[.(.f.z.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.l.z.g.}.rX0XqXqX",
"qXwX7XNX1XoX@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X#X+X=X*X*X*X*X&X*X;X<X2X2X2X<X-X*X&X*X*X*X=XOXOX=X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X=XoX+X=X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X#XqXqXqXqX",
"qXwX7XMX4X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqX2XQ.&.,.>.>.>.>.>.:.;.;.-.;.;.:.>.>.>.>.,.$.~.~.$.,.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.,.$.`.R.#.,.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.,.&.`.tX0XqXqX",
"qXwX7XMX5X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.#.;.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.:.+.~.~.+.:.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.;.+._.T.O.:.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.;.$.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.%.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.+.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.@.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.@.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2XW.$.:.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.@.~.~.@.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.`.T.+.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.%.`.yX0XqXqX",
"qXwX7XMX4X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqX2XQ.&.,.>.>.:.>.>.>.>.>.>.>.>.>.>.>.>.>.,.$.~.~.$.,.>.>.:.>.>.>.>.>.>.>.>.>.>.>.>.>.,.$.`.R.#.,.>.>.:.>.>.>.>.>.>.>.>.>.>.>.>.>.,.&.`.tX0XqXqX",
"qXwX7XmX5XqXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXrX3XE...$.#.#.#.#.#.@.#.#.#.#.#.#.#.#.#.#.%.} !.!.} %.#.#.#.#.#.@.#.#.#.#.#.#.#.#.#.#.$.| _.U.} %.#.#.#.#.#.@.#.#.#.#.#.#.#.#.#.#.$..._.yX0XqXqX",
"qXwX7XNX4X<X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X3X:X_.l.v.v.v.c.c.v.c.v.v.v.v.c.c.v.v.v.v.v.k.`.`.k.v.v.v.c.c.v.c.v.v.v.v.c.c.v.v.v.v.v.k.{.(.k.v.v.v.c.v.v.c.v.v.v.v.c.c.v.v.v.v.v.l.}.rX0XqXqX",
"qXwX7XmX$X).].].].].].].].].].].].].].].].].].].'.}.%X,X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X,X$X$X,X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X,X$X%X<X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X*XqXqXqXqX",
"qXqXqXqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX7XmX2X8X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9XqX=X=XqX9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9XqX*X-XqX9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X;XqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XNX3XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqXqXqX7X8XqXqXqXqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqX0XqXlXjXqXqXqXqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqX0XtXyX;.q.eXqXqXqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqX0XqX5X`   v eXqX0XqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqX0XpX^.I D S eXqX0XqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXwX7XgX{ m tXqX0XqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqX9XhX) M tXqX0XqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqX9XgX_ M tXqX0XqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqX9XhX_ M tXqX0XqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqX9XhX' V tXqX0XqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqX9XjXT d tXqX0XqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqX0XyX!.L.wXqXqXqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqXqX0XaXfXqXqXqXqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqXqXqX9X8XqXqXqXqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX*X;XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3X0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX=X=XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX*X;XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XMX3XeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXtX-X-XtXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXtX*X;XtXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXrX;X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XBX<X,X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X1X&X&X1X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X1X%X*X1X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X=XqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XnX+X`.[.].].].].].].].].].].].].].].].].].].{.{.].].].].].].].].].].].].].].].].].].].].{.{.].].].].].].].].].].].].].].].].].].[.'..XwXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqX0XqXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXwXqXqXqX",
"qXqX0XtXwX2X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X5XwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXeX0X4XeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXeX9X4XeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXeX9X8XwXqXqX",
"qXwX7XlXyX-X3X2X2X2X2X2X2X2X2X2X2X2X2X2X2X1X2X,X Xk.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.j.d.A.oXh.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.j.s.D.XXg.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.j.d.A.9XqXqXqX",
"qXwX7XjXyX7XrXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXrX8X X*.#.$.$.$.$.$.$.$.$.$.$.$.$.$.$.%...a.#X#.$.$.$.$.$.$.$.$.$.$.$.$.$.$.$.%...f.+X@.$.$.$.$.$.$.$.$.$.$.$.$.$.$.$.&...d.eX0XqXqX",
"qXwX7XjXyX4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX6X X<.:.>.:.:.:.:.:.:.:.:.:.:.:.:.:.,.%.h.@X:.:.>.:.:.:.:.:.:.:.:.:.:.:.:.:.,.%.l.+X-.:.>.:.:.:.:.:.:.:.:.:.:.:.:.:.,.&.j.wXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqX7X7X7X9XqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXwXjXxXcXdX0XqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XrX<X..K G k.tXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XyX*X% I X.o L.aX9XqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XtX-X6 !.AXM $.fX9XqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XyX-X2 I.gXy 1.fX9XqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XtX-X6 t c 7 }.iX9XqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XtX=X8 _ & t.kX8XqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XtX-X4 |. .V sX0X0XqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XyX=Xo G.&X  N.dX9XqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XeX3Xw.XXpXf.F.uX0XqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXwXkXyX9XjXdX0XqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqX7X0XqX8X9XqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XeXqXwXwXwXwXwXwXwXwXwXwXwXwXwXqXeX7X X;.*.=.=.=.=.=.*.=.*.=.*.=.=.=.=.-.@.d.@X*.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.-.+.h.+X&.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.-.@.g.eXqXqXqX",
"qXwX7XkXtXXX%X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$XOXOX+X+X+X+XOXoX+X@X@X@X+XoXoX+X+X+X+XOXXX+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+XOXXX+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+X+XXX4XeXqXqX",
"qXwX7XkXyX:X4X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X4X<X.Xl.j.k.k.h.z.n.j.s.a.s.g.v.c.h.j.l.f.D.+Xj.j.k.k.k.k.k.k.k.k.k.k.k.k.k.k.l.f.G.OXh.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.l.f.D.9XqXqXqX",
"qXwX7XjXyX6XrXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXrX8X|.&.#.#.#.;.[ m 5 X   . : k ! -.%.$...a.@X#.#.$.#.#.#.#.#.#.#.#.#.#.#.#.#.%. .f.+X+.#.$.#.#.#.#.#.#.#.#.#.#.#.#.#.%...s.eX0XqXqX",
"qXwX7XjXyX4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX6X X<.;.>.1.D *               O l =.1.$.h.@X:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.,.%.l.+X-.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.,.%.j.wXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqX8X0XqX8X9XqXqXqXqXqXwX7X X>.;.>.h     X .       . X     4 #.*.f.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXwXjXtX0XgXpX0XqXqXqXqXwX7X X>.<.m   . .                 X   q @.h.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XrX<X) ).pX#.V.pX0XqXqXqXwX7X|.2.) .                         X   m z.+X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XyX=X# S.fXr 1.gX9XqXqXqXwX7X}.4.t   .                       .   + i.$X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XtX-X6 K.fXz 9.fX9XqXqXqXwX6XXXO.*   .                         X   &.*X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XyX-X3 G.sXh 8.fX9XqXqXqXwX5X@XR   .                           X   Y -X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XtX=X7 ; q   t.sX9XqXqXqXwX5X$XK   X                           o   F ;X*.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XtX-X4 8.~.w 0.dX9XqXqXqXwX5X$XL   X                           o   F ;X*.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XtX-X6 R.nXv 9.fX9XqXqXqXwX5X@XR   .                           o   Y -X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XyX=XO C.sX0 <.gX9XqXqXqXwX6XXXO.*   .                         X   %.*X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqX0XeX4Xi.OXyXl.~.yX0XqXqXqXwX7X|.4.r   .                       .   + i.$X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXwXkXyX0XhXpX0XqXqXqXqXwX7X|.2.(                           X   n z.+X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqX7X0XqX8X9XqXqXqXqXqXwX7X X>.<.b   . .                 X   0 @.h.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.;.>.f     X .       . X     3 @.*.f.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.=.;.,.Z %               X g %.<.@.g.@X-.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.j.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.-.-.1. .V 9 # X O 1 c ( <.:.;.#.f.@X=.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.:.#.j.+X*.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.:.#.h.eXqXqXqX",
"qXwX7XkXtXXX$X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X$XOX@X@X@X@X+X%X-XOX|.{.}.XX*X*X+X@X@X@X+XXX@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X+XXX@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X#XoX4XeXqXqX",
"qXwX7XkXyX>X5X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X1X.Xh.f.g.g.g.f.d.g.j.j.j.h.f.f.g.g.h.a.A.+Xf.g.g.g.g.g.g.g.g.g.g.g.g.g.g.g.h.a.D.OXd.g.g.g.g.g.g.g.g.g.g.g.g.g.g.g.h.a.A.0XqXqXqX",
"qXwX7XjXyX6XrXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXrX8X|.&.#.$.$.$.$.$.$.#.#.#.$.$.$.$.$.%...a.@X#.$.$.$.$.$.$.$.$.$.$.$.$.$.$.$.%...f.+X@.$.$.$.$.$.$.$.$.$.$.$.$.$.$.$.%...d.eXqXqXqX",
"qXwX7XjXyX4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX6X X<.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.,.%.h.@X;.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.,.%.k.+X-.:.:.:.:.:.:.:.:.:.:.:.:.:.:.:.,.%.j.wXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.#.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.h.eXqXqXqX",
"qXwX7XjXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X X>.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.$.g.@X-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.k.+X=.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.>.$.h.eXqXqXqX",
"qXwX7XkXyX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX6X X>.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.:.#.f.@X-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.:.#.j.+X*.-.-.-.-.-.-.-.-.-.-.-.-.-.-.-.:.#.h.eXqXqXqX",
"qXwX7XjXuX6XrXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeX9X X<.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.&.h.@X>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.&.l.OX;.>.>.>.>.>.>.>.>.>.>.>.>.>.>.>.<.*.k.wXqXqXqX",
"qXwX7XlXqX`..X X X X X X X X X X X X X X X X X}..X X|. X X X X X X X X X X X X X X X|..XOX X X X X X X X X X X X X X X X X X|..XOX X X X X X X X X X X X X X X X X X X X5XwXqXqX",
"qXqX0XyX8X;X,X>X>X>X>X>X>X>X>X>X>X>X>X>X>X,X;X9X6X3X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X6X8X1X$X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X6X8X<X$X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X6X8X,X4XeXqXqX",
"qXqXqX0XwXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXtX0XcXuX6XeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX4X#XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX4X$XeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX2X4XeXqXqX",
"qXqXqXqXqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX7XkXrX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX3X$XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX1X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqXqXqX9X8XqXqXqXqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqXqX9XsXjXwXqXqXqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqX0XhXi.A :XrX0XqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqX9XiXi.. * OXtX0XqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqX9XyXB.r.t OXyX0XqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqX8XxX^.5 +XyX0XqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqX9XaXY.6 +XyX0XqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqX9XsXT.6 +XyX0XqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqX9XsXR.9 @XyX0XqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqX8XdXP.# oXyX0XqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqX0XtX*Xx.2XeXqXqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqXqX0XtXjXeXqXqXqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XwXqXqXqXqXqXqXqX0X8XqXqXqXqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X$XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXtX5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X#XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X#XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX1X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XkXyX7XeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX5X%XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX4X&XeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX3X4XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XzX9X`. X|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.}.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.}.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.{.3XeXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX8X>X<X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X,X8XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXwXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX0XqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXqX0X0X0X0X0X0X0X0X0X0X0X0XqXqX0X0X0X0X0X0X0X0X0X0X0X0XqXqX0X0X0X0X0X0X0X0X0X0X0X0XqXqXqXqXqX",
"qXqXqXwXqX6X7X7X7X7X7X7X7X7X7X7X7X7X0XtXtXtXtXtXtXtXtXtXtXtXtXeX0XtXtXtXtXtXtXtXtXtXtXtXtXwX0XtXtXtXtXtXtXtXtXtXtXtXtXwX0XqXqXqX",
"qXqX9XaXrX<X4X4X4X4X4X4X4X4X4X3X3X5X).f.k.j.j.j.j.j.j.j.j.k.f.A./.d.k.j.j.j.j.j.j.j.j.k.d.F.~.s.k.j.j.j.j.j.j.j.j.k.d.F.wXqXqXqX",
"qXqX9XpXyX9XeXwXeXwX0XqXwXwXwXwXwXrXT.o.%.$.$.$.$.$.$.$.$.%.X.u.Y...%.$.$.$.$.$.$.$.$.%...f.K. .&.$.$.$.$.$.$.$.$.%.X.d.tX0XqXqX",
"qXqX9XpXyX7XqXqX0XeXsXsXqX0XqXqX0XwXE.&.>.:.:.:.:.:.:.:.:.>.&.d.R.%.,.:.:.:.:.:.:.:.:.>.%.k.I.$.,.:.:.:.:.:.:.:.:.,.&.k.tX0XqXqX",
"qXqX9XpXyX8XwX0XeX1XE.W.qXwXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX8XhXz.r Z *.dX9XqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX8XkXi.7.rXx 9XwX0XqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.j.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX8XhXz.z ] { aX9XqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX8XhXx.M y }.aX9XqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX8XlXw.;.y.] hX8XqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX0XpX^.H.,Xa.qXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwXqX0XiXaXeXgXqXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.:.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX7XqXqXqX9X9X0X8XqXqX0X0XwXE.*.,.:.:.>.>.>.>.>.>.>.&.d.R.%.,.:.:.>.>.>.>.>.>.,.%.l.I.$.,.:.:.>.>.>.>.>.>.,.&.k.tX0XqXqX",
"qXqX9XpXyX0XrXeXeXeXeXeXeXeXeXeXeXtXT...#.@.@.@.+.+.+.@.@.#. .t.U.| $.@.@.@.@.@.@.@.@.#.| d.K.} $.@.@.@.@.@.@.@.@.$. .s.tX0XqXqX",
"qXqX9XaXeX*X>X:X:X:X:X:X:X:X:X:X:X:X{.K.I.P.L.I.R.E.R.I.L.P.K.Q.[.K.I.P.P.P.P.P.P.P.P.P.K.~.'.K.I.P.P.P.P.P.P.P.P.I.K.~.0XqXqXqX",
"qXqX9XaXrX,X4X3X3X3X3X3X3X3X3X3X3X4X).g.j.l.b.d.2.>.3.f.b.l.d.A./.d.k.k.k.k.k.k.k.k.k.k.f.G.~.d.l.k.k.k.k.k.k.k.k.k.f.F.wXqXqXqX",
"qXqX9XpXyX9XeXeXeXwXqXwXqXeXeXwXwXrXT...*.+.k @       $ c $.O.t.Y. .%.#.#.#.#.#.#.#.#.%. .f.K.| %.#.#.#.#.#.#.#.#.%...d.tX0XqXqX",
"qXqX9XpXyX7XqXqX0XtXuXwXiXqXqXqX0XwXR.-.%.5     X X .     q +.f.T.$.>.:.:.:.:.:.:.:.:.>.%.k.P.#.,.:.:.:.:.:.:.:.:.>.%.k.tX0XqXqX",
"qXqX9XpXyX8XwX0XtX&XoX5X'.wXqXqXqXwXE.*.r   o .       . X   e h.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX8XkXu.X. XC rXqX0XqXqX/.P   X               X   -.~.@.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX8XkXa.<.1XK eXqX0XqXqX^.y   .               X   I ~.@.:.;.;.;.;.;.;.;.;.:.#.j.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX8XhXc.i L A tX0X0XqXwXQ.>   .               X   b !.@.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX8XjXj.W z.J rXqX0XqXwXQ.:   .               X   b !.@.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX8XlXe.@.-XM eXqX0XqXqX^.r   .               X   L ~.@.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwX0XiX'.Y.,XC.wXqXqXqXqX/.K   X               X   *.~.@.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwXqX0XuXaXeXdXqXqXqXqXwXE.&.0   o .       . o   9 g.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.:.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX7XqXqXqX9X9X0X8XqXqX0X0XwXR.-.@.<     X o X     6 o.g.T.%.,.:.:.:.:.:.:.:.:.>.%.k.I.$.,.:.:.:.:.:.:.:.:.,.%.k.tX0XqXqX",
"qXqX9XpXyX0XeXeXeXeXeXeXeXeXeXeXeXrXT...=.X.a .       o g +.O.t.Y. .%.#.#.#.#.#.#.#.#.$. .d.K.| %.#.#.#.#.#.#.#.#.%...d.tX0XqXqX",
"qXqX9XaXeX&X;X;X;X;X;X;X;X;X;X;X;X;X}.Y.T.E.^.H.h.a.j.J.^.E.U.^.{.Y.R.T.T.T.T.T.T.T.T.R.Y./.[.U.R.T.T.T.T.T.T.T.T.R.Y./.0XqXqXqX",
"qXqX9XaXrX1X5X5X5X5X5X5X5X5X5X4X4X6X/.u.d.a.p.f.k.l.k.d.p.s.u.B.^.y.d.s.s.s.s.s.s.s.s.d.y.A.Q.t.d.s.s.s.s.s.s.s.s.d.u.A.eXqXqXqX",
"qXqX9XpXyX9XeXwXwXwXwXwXwXwXwXwXwXrXT.o.&.$.$.$.#.#.#.$.$.%.o.u.Y...&.$.$.$.$.$.$.$.$.&...f.K. .&.$.$.$.$.$.$.$.$.&.X.f.tX0XqXqX",
"qXqX9XpXyX7XqXqXqXqXqXqXqXqXqXqXqXwXE.&.>.:.:.:.:.:.:.:.:.>.%.s.R.$.>.:.:.:.:.:.:.:.:.>.$.k.P.#.>.:.:.:.:.:.:.:.:.>.%.k.tX0XqXqX",
"qXqX9XpXyX8XwXqXqXqXqXqXqXqXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwXqXqXqXqXqXqXqXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwXqXqXqXqXqXqXqXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.j.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwXqXqXqXqXqXqXqXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwXqXqXqXqXqXqXqXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwXqXqXqXqXqXqXqXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwXqXqXqXqXqXqXqXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.>.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX8XwXqXqXqXqXqXqXqXqXqXqXwXE.%.:.;.;.;.;.;.;.;.;.:.$.s.T.#.:.;.;.;.;.;.;.;.;.:.#.k.P.@.:.;.;.;.;.;.;.;.;.:.$.j.tX0XqXqX",
"qXqX9XpXyX7XqXqXqXqXqXqXqXqXqX0X0XwXE.&.>.:.:.:.:.:.:.:.:.>.&.d.R.$.>.:.:.:.:.:.:.:.:.>.%.k.P.#.,.:.:.:.:.:.:.:.:.>.%.k.tX0XqXqX",
"qXqX9XpXuX0XrXeXeXeXeXeXeXeXeXeXeXtXR.O.&.%.%.%.%.%.%.%.%.&.o.u.Y.X.&.%.%.%.%.%.%.%.%.&.X.f.K...*.%.%.%.%.%.%.%.%.&.o.f.tX0XqXqX",
"qXqX9XsX9XoX$X#X#X#X#X#X#X#X#X#X#X#X}.R.E.E.E.E.E.E.E.E.E.E.T./.}.T.E.E.E.E.E.E.E.E.E.E.T.).{.T.E.E.E.E.E.E.E.E.E.E.T.).0XqXqXqX",
"qXqXqXeX8X1X2X2X2X2X2X2X2X2X2X2X<X0X0XqXeXwXwXwXwXwXwXwXwXwXrX6X;XrXwXwXwXwXwXwXwXwXwXwXrX4X:XtXwXwXwXwXwXwXwXwXwXwXrX5X7XwXqXqX",
"qXqXqXqXwXeXeXeXeXeXeXeXeXeXeXeXqXfXtX8XqXqXqXqXqXqXqXqXqXqXwX4X;XeX0XqXqXqXqXqXqXqXqX0XwX3X:XeX0XqXqXqX9X8XqXqXqX0XwX3X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XaXrX8XqXqXqXqXqXqXqXqXqXqXwX4X;XeX0XqXqXqXqXqXqXqXqXqXwX3X:XeX0XqXqX9XiXsX0XqXqXqXwX3X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXrX8XwXqXqXqXqXqXqXqXqXqXwX5X;XeXqXqXqXqXqXqXqXqXqXqXeX3X:XeXqXqX9XaX_.J.yX0XqXqXwX4X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXrX8XwXqXqXqXqXqXqXqXqXqXwX5X;XeXqXqXqXqXqXqXqXqXqXqXeX3X:XeXqX0XyX%X0 K fX9XqXqXwX4X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXrX8XwXqXqXqXqXqXqXqXqXqXwX5X;XeXqXqXqXqXqXqXqXqXqXqXeX3X:XeXqX0XwX7Xg.` aX9XqXqXwX4X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXrX8XwXqXqXqXqXqXqXqXqXqXwX5X;XeXqXqXqXqXqXqXqXqXqXqXeX3X:XeXqXqX8XkXL.Q dX9XqXqXwX4X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXrX8XwXqXqXqXqXqXqXqXqXqXwX5X;XeXqXqXqXqXqXqXqXqXqXqXeX3X:XeXqXqX9XfXF.^ sX9XqXqXwX4X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXrX8XwXqXqXqXqXqXqXqXqXqXwX5X;XeXqXqXqXqXqXqXqXqXqXqXeX3X:XeXqXqX9XgXA.I dX9XqXqXwX4X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXrX8XwXqXqXqXqXqXqXqXqXqXwX5X;XeXqXqXqXqXqXqXqXqXqXqXeX3X:XeXqXqX0XtX=X(.rX0XqXqXwX4X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXrX8XwXqXqXqXqXqXqXqXqXqXwX5X;XeXqXqXqXqXqXqXqXqXqXqXeX3X:XeXqXqXqX0XtXpX0XqXqXqXwX4X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXrX8XqXqXqXqXqXqXqXqXqX0XwX4X-XwX0XqXqXqXqXqXqXqXqX0XwX3X;XeX0XqXqXqX0X9XqXqXqX0XwX3X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXtX0XeXeXeXeXeXeXeXeXeXeXrX6X:XtXeXeXeXeXeXeXeXeXeXeXtX5X>XtXeXeXeXeXeXeXeXeXeXeXrX5X7XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX5XXX#X@X@X@X@X@X@X@X@X@X@X+XoX@X@X@X@X@X@X@X@X@X@X@X@XOXoX@X@X@X@X@X@X@X@X@X@X@X@X+X8XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8X3X4X4X4X4X4X4X4X4X4X4X4X4X5X4X4X4X4X4X4X4X4X4X4X4X4X5X5X4X4X4X4X4X4X4X4X4X4X4X4X5X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0X0X0X0X0X0X0XqXqX0X0X0X0X0X0X0X0XqXqX0X0X0X0X0X0X0X0XqXqXqXqXqX",
"qXqXqXqXwXwXwXwXwXwXwXwXwXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXqXqXqXqX",
"qXqXqXeX8X5X6X6X6X6X6X6X6X6X3X2X2X2X2X2X2X2X2X3X3X2X2X2X2X2X2X2X2X3X3X2X2X2X2X2X2X2X2X4XqXqXqXqX",
"qXqX0XpX9X7X8X7X4X5X8X8X8X7Xl.>.4.3.3.3.3.4.:.v.v.:.4.3.3.3.3.4.:.b.x.>.4.3.3.3.3.4.:.b.tX0XqXqX",
"qXqX0XiXwXqXqXrXkXfXwXqXwXqXd.#.-.=.=.=.=.-.@.k.k.@.-.=.=.=.=.-.+.l.h.@.-.=.=.=.=.;.@.l.yX0XqXqX",
"qXqX0XiXqX0XrX:X5.m.rX0XqX0Xg.%.>.;.;.;.;.>.$.l.l.$.>.;.;.;.;.>.$.x.j.$.>.;.;.;.;.>.$.z.yX0XqXqX",
"qXqX0XiXqX9XdXP.&.#.~.aX0X0Xf.%.:.;.;.;.;.:.$.l.l.$.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqX9XaX(.P X.=XrX0X0Xf.%.:.;.;.;.;.:.$.l.l.$.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqX9XsXQ.J  .eX0XqX0Xf.%.:.;.;.;.;.:.$.l.l.$.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqX9XiX}.R.A.OXyX0X0Xf.%.:.;.;.;.;.:.$.l.l.$.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqX0X0XrXyXpXeX0XqX0Xg.&.>.:.:.:.:.>.%.l.l.%.>.:.:.:.:.>.%.x.k.%.>.:.:.:.:.,.%.x.yX0XqXqX",
"qXqX0XiXwXwXwXwXqXqXwXwXwXwXa.o.&.#.#.#.#.&.X.h.h.X.&.%.%.%.%.&.X.j.f.X.&.%.%.%.%.&.X.j.uX0XqXqX",
"qXqX9XpX4X>X,X,X,X,X,X,X,X>XT.C.S.K.L.L.L.F.V.R.R.C.S.S.S.S.S.S.C.E.T.C.S.S.S.S.S.D.C.W.eXqXqXqX",
"qXqX0XpX9X7X8X7X6X6X7X8X8X7Xc.6.q._ M v U 2.8.n.M.3.0.9.9.9.9.0.3.N.n.4.0.9.9.9.9.0.3.N.tX0XqXqX",
"qXqX0XiXwXwXqXyXiXpXtXqXwX0Xf...9         # Y c.h.O.=.*.*.*.*.=.O.l.g.O.=.*.*.*.*.=.O.k.yX0XqXqX",
"qXqX0XiXqX0XyX+X!.Q.%XtX0X9Xz.r   o X X o   X a.x.#.>.;.;.;.;.>.$.x.j.$.>.;.;.;.;.>.$.z.yX0XqXqX",
"qXqX0XiXqX9XfXJ.y.w.E.aX9XrX6.  X         O   { m.@.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqX9XaX/.L P {.iX8XuX+.  o         o   J n.@.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqX9XdXP.:.=.!.aX8XuX%.  o         o   I n.@.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqX0XuX XE.T.OXyX0XwXr.    .       O   $.n.@.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqX0X0XtXuXuXrX0XqX9Xx.m     X o X   2 z.z.$.>.:.:.:.:.>.$.x.k.%.>.:.:.:.:.>.%.x.yX0XqXqX",
"qXqX0XiXwXwXwXqXqXqXqXwXwXqXa.#.M         w [ k.g.o.*.%.%.%.%.*.X.k.f.o.*.%.%.%.%.*.o.j.yX0XqXqX",
"qXqX9XpX4X:X,X,X,X,X,X,X,X>XT.Z.L.n.9.5.g.J.S.R.E.Z.D.D.D.D.D.D.Z.E.R.Z.D.D.D.D.D.D.Z.Q.eXqXqXqX",
"qXqX0XpX9X7X8X8X8X8X8X8X8X7Xc.3.7.0.r.r.q.7.1.m.m.2.8.7.7.7.7.8.2.M.b.2.8.7.7.7.7.8.2.M.tX0XqXqX",
"qXqX0XiXwXqXwXwXwXwXwXqXwXqXd.@.-.*.&.&.&.=.+.j.j.+.=.*.*.*.*.=.O.l.g.+.=.*.*.*.*.-.+.k.yX0XqXqX",
"qXqX0XiXqX0XqXqXqXqXqXqXqX0Xg.%.>.;.;.;.;.>.$.l.l.$.>.;.;.;.;.>.$.x.j.$.:.;.;.;.;.>.$.z.yX0XqXqX",
"qXqX0XiXqXqXqXqXqXqXqXqXqX0Xf.%.:.;.;.;.;.:.$.l.l.$.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqXqXqXqXqXqXqXqXqX0Xf.%.:.;.;.;.;.:.$.l.l.$.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqXqXqXqXqXqXqXqXqX0Xf.%.:.;.;.;.;.:.$.l.l.$.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqXqXqXqXqXqXqXqXqX0Xf.%.:.;.;.;.;.:.$.l.l.$.:.;.;.;.;.:.#.z.j.$.:.;.;.;.;.:.$.z.yX0XqXqX",
"qXqX0XiXqX0XqXqXqXqXqX0XqX0Xg.&.,.:.:.:.:.,.%.z.z.%.>.:.:.:.:.,.%.x.k.%.>.:.:.:.:.,.%.x.yX0XqXqX",
"qXqX0XpXeXwXeXeXeXeXeXeXeXwXp.X.%.$.$.$.$.%...g.g...%.$.$.$.$.%...j.d...%.$.$.$.$.%...h.uX0XqXqX",
"qXqX0XpX,X&X=X=X=X=X=X=X=X=X^.P.U.U.U.U.U.U.P././.P.U.U.U.U.U.U.P./.^.P.U.U.U.U.U.Y.P.).wXqXqXqX",
"qXqXqXqX8X6X7X6X6X6X6X7X5XrXrXyXyXyXyXyXyXtXiX6X6XiXtXyXyXyXyXtXiX5X6XiXtXyXeXrXyXtXuX8X8XwXqXqX",
"qXqXqXqXwXwXwXwXwXwXwXwXqXaX0X0X0X0X0X0X0X0XwX2X2XwX0X0X0X0X0X0XwX2X3XwX0X0XfXyX9X0XqX5X9XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqX0XiXqXqXqXqXqXqXqXqXeX3X3XeXqXqXqXqXqXqXeX2X3XwX0XyXl.W.pX9XwX5X9XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqX0XpXqXqXqXqXqXqXqXqXeX3X3XeXqXqXqXqXqXqXeX2X3XwXqXrX~ a.jX8XwX5X9XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqX0XpXqXqXqXqXqXqXqXqXeX3X3XeXqXqXqXqXqXqXeX2X3XeX8XhXG.j.hX8XwX5X9XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqX0XpXqXqXqXqXqXqXqXqXeX3X3XeXqXqXqXqXqXqXeX2X3XeX8XhXz.u.jX8XwX5X9XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqX0XpXqXqXqXqXqXqXqXqXeX3X3XeXqXqXqXqXqXqXeX2X3XeX9XiX'.^.iX9XwX5X9XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqX0XpXqX0XqXqXqXqXqX0XwX3X3XwX0XqXqXqXqX0XwX2X3XwXqX0XyXuX0XqXwX5X9XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqX0XpXwXwXeXeXeXeXeXwXrX4X4XrXwXeXeXeXeXwXrX3X4XrXwXeXqXqXeXwXrX6X9XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqX0XpX>X&X=X*X*X*X*X*X=X%X%X=X*X*X*X*X*X*X=X%X%X=X*X*X*X*X*X=X*X*X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqX8X7X7X7X7X7X7X7X7X8X8X7X7X7X7X7X7X7X7X8X8X7X7X7X7X7X7X7X7X8XqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXwXwXwXwXwXwXwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXwX0X7X8X8X8X8X8X8X8X0XqXqXqXqXqXqXqX0X0XqXqXqXqXqXqXqX0X0XqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqX0XyXqX5X7X5X4X5X7X6X9XF.0.y.t.t.t.t.q.x.S.0.y.t.t.t.t.q.v.A.0.y.t.t.t.t.q.z.qXqXqXqX",
"qXqX0XyXrXqXqXuXhXiXqXqXtXv.o.*.&.&.&.*.+.e.x.o.*.&.&.&.*.+.t.l.o.*.&.&.&.*.+.q.qXqXqXqX",
"qXqX0XyXeX8XpX^.&.(.uX9XrXm.%.>.:.:.:.>.&.u.b.%.>.:.:.:.>.&.p.c.%.>.:.:.:.>.*.t.qXqXqXqX",
"qXqX0XyXeX7XjXf.<.>.uX9XrXm.$.:.;.;.;.:.%.y.v.$.:.;.;.;.:.%.i.c.$.:.;.;.;.:.&.t.qXqXqXqX",
"qXqX0XyXeX7XgXn.g C.sX8XrXm.$.:.;.;.;.:.%.y.v.$.:.;.;.;.:.%.i.c.$.:.;.;.;.:.&.t.qXqXqXqX",
"qXqX0XyXeX7XfXM.;.z.sX8XrXm.$.:.;.;.;.:.%.y.v.$.:.;.;.;.:.%.i.c.$.:.;.;.;.:.&.t.qXqXqXqX",
"qXqX0XyXeX9XeX1X5X-XqX0XrXm.%.,.:.:.:.>.*.u.b.%.>.:.:.:.>.&.p.c.%.>.:.:.:.>.*.y.qXqXqXqX",
"qXqX0XyXrXwXwXtXrXyXwXwXyXc...%.@.@.@.$.o.q.z...%.$.$.$.%.X.e.k...%.$.$.$.%.o.0.qXqXqXqX",
"qXqX0XuX9X<X2X2X1X1X2X2X4XU.j.v.N.V.B.m.k.A.P.k.c.c.c.c.c.l.S.L.k.c.c.c.c.c.l.A.0XqXqXqX",
"qXqX0XuX0X4X6X4X4X4X5X5X8XF.y.p.X.U Q <.a.v.D.r.p.i.i.i.p.r.n.S.e.p.i.i.i.p.t.v.0XqXqXqX",
"qXqX0XyXrXwXqXiXuXpXwXwXtXn.] 3         l u.z.X.&.%.%.%.&.O.r.l.X.&.%.%.%.&.+.q.qXqXqXqX",
"qXqX0XyXeX8XpXQ.~.P.eX9XeXV.9   o o o .   o.V.#.>.:.:.:.>.&.p.c.%.>.:.:.:.>.*.t.qXqXqXqX",
"qXqX0XyXeX7XhXg.9.4.uX8XiXu.  X       o   v N.#.:.;.;.;.:.%.i.c.$.:.;.;.;.:.&.t.qXqXqXqX",
"qXqX0XyXeX7XhXx.F :.pX7XaX5.  o       X   a b.$.:.;.;.;.:.%.i.c.$.:.;.;.;.:.&.t.qXqXqXqX",
"qXqX0XyXeX7XgXc.m.u.tX8XiXu.  X       o   v N.#.:.;.;.;.:.%.i.c.$.:.;.;.;.:.&.t.qXqXqXqX",
"qXqX0XyXeX9XwX3X2X1XqX0XeXV.8   O o o X   X.V.$.,.:.:.:.>.&.p.c.%.>.:.:.:.>.*.y.qXqXqXqX",
"qXqX0XyXrXwXwXrXtXtXwXwXtXn._ ,         g y.l...%.$.$.$.%.X.r.k...%.$.$.$.%.o.0.qXqXqXqX",
"qXqX0XuX8X<X2X1X1X1X2X1X4XU.v.b.-.( [ w.m.S.I.z.b.v.v.v.b.x.D.P.z.b.v.v.v.b.x.S.0XqXqXqX",
"qXqX0XuXqX4X6X6X6X6X6X5X8XF.0.i.f.g.g.s.w.c.S.q.u.y.y.y.u.w.b.A.q.u.y.y.y.u.e.x.0XqXqXqX",
"qXqX0XyXrXqXwXwXwXwXwXqXyXv.o.*.$.$.$.%.O.e.x.o.*.%.%.%.&.O.t.l.o.*.%.%.%.&.+.q.qXqXqXqX",
"qXqX0XyXeX0XqXqXqXqXqX0XrXm.$.>.:.:.:.:.&.u.b.%.>.:.:.:.>.&.p.c.%.>.:.:.:.>.*.t.qXqXqXqX",
"qXqX0XyXeX0XqXqXqXqXqX0XrXm.$.:.;.;.;.:.%.y.v.$.:.;.;.;.:.%.i.c.$.:.;.;.;.:.&.t.qXqXqXqX",
"qXqX0XyXeX0XqXqXqXqXqX0XrXm.$.:.;.;.;.:.%.y.v.$.:.;.;.;.:.%.i.c.$.:.;.;.;.:.&.t.qXqXqXqX",
"qXqX0XyXeX0XqXqXqXqXqX0XrXm.$.:.;.;.;.:.%.y.v.$.:.;.;.;.:.%.i.c.$.:.;.;.;.:.&.t.qXqXqXqX",
"qXqX0XyXeX9XqXqXqXqX0X0XrXm.%.,.:.:.:.>.*.u.b.%.,.:.:.:.>.*.p.v.%.,.:.:.:.>.*.y.qXqXqXqX",
"qXqX0XyXtXwXeXeXeXeXeXwXuXc...%.$.$.$.$.o.q.z...%.$.$.$.$.X.e.k...%.$.$.$.%.o.0.qXqXqXqX",
"qXqX0XuX6X;X>X>X>X>X>X>X<XT.c.m.n.m.n.m.v.F.Y.c.m.n.m.n.m.v.G.U.c.m.n.m.n.m.v.F.0XqXqXqX",
"qXqXqXwX7X3X4X3X3X3X4X2X8XeXrXrXrXrXrXrXyX8X3XyXrXrXrXrXrXyX8X4XyXrXrXwXrXrXtX9X8XwXqXqX",
"qXqXqXqXwXeXeXeXeXeXeXqXiXeX9X0X0X0X0X0XqX5X1XwX0X0X0X0X0XwX5X2XwX9XrXfXqX0XqX6X8XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqX0XyXeX0XqXqXqXqXqXwX6X1XwXqXqXqXqXqXwX5X2XwXrX-X,.2XeXqX7X8XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqX0XyXeX0XqXqXqXqXqXwX6X2XeXqXqXqXqXqXwX5X2XwXrX;X~ *XtXqX7X8XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqX0XyXeX0XqXqXqXqXqXwX6X2XeXqXqXqXqXqXwX5X2XeX8XfX7.@XyXqX7X8XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqX0XyXeX0XqXqXqXqXqXwX6X2XeXqXqXqXqXqXwX5X2XeX9XuX8.%XyXqX7X8XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqX0XyXeX0XqXqXqXqX0XwX5X1XwX0XqXqXqX0XwX5X2XwX0XqX4X9XqXqX6X8XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqX0XyXrXwXeXeXeXeXeXtX8X3XtXeXeXeXeXeXtX7X4XtXeXeXtXrXeXrX9X8XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqX0XuX4X-X>X:X:X:X:X>X-X*X>X:X:X:X:X:X>X=X*X>X:X:X:X:X:X>X-X8XwXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXwX7X4X4X4X4X4X4X4X5X5X4X4X4X4X4X4X4X5X5X4X4X4X4X4X4X4X5X0XqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXwXeXeXeXeXeXeXeXeXwXeXeXeXeXeXeXeXeXwXeXeXeXeXeXeXeXeXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXwXwXwXwXwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqX0X8X8X7X8X9X8X0XqXqXqXqXqX0X0XqXqXqXqXqX0X0XqXqXqXqXqX0XqXqX",
"0XtXqX6X9XtX8X7X0XB.8.r.e.e.0.k.m.9.r.e.r.0.l.n.9.r.e.r.0.k.0XqX",
"0XtXeXwX7X|.9XwXtXh.O.*.&.*.@.0.s.+.*.&.*.@.w.p.+.*.&.*.@.0.qXqX",
"0XtXqXpX_.] G.aXwXl.%.>.:.>.*.r.g.&.>.:.>.*.t.d.&.>.:.>.*.r.qXqX",
"0XtXqXpX(.Z W.pXwXk.$.:.;.:.&.e.f.%.:.;.:.&.t.d.%.:.;.:.&.e.qXqX",
"0XtXwXyXXXi.'.uXwXl.%.>.:.>.*.r.g.&.>.:.>.*.y.d.&.>.:.>.*.r.qXqX",
"0XrXrXqXrXpXeXqXyXg.X.%.#.$.O.9.a.o.&.%.&.O.q.i.o.&.%.&.+.9.qXqX",
"0XtX9X3X4X2X4X4X6XS.i.z.z.x.d.v.C.i.d.d.d.p.m.V.i.d.d.d.p.n.0XqX",
"0XtX0X5X8X9X8X5X8XC.w.] V L ,.v.m.q.y.t.t.q.z.m.q.y.t.t.w.l.0XqX",
"0XtXeXeX7X<X4XeXrXl.w         %.g.o.*.&.&.+.q.p.O.*.&.*.@.0.qXqX",
"0XtXqXpX).6.F.iXuX1.  O X +   c z.%.>.:.:.&.t.d.&.>.:.>.*.e.qXqX",
"0XtXqXaX(.J b.aXpX .  o   .   r d.%.:.;.:.&.t.d.%.:.;.:.&.e.qXqX",
"0XtXwXyX.XC.^.tXiX1.  O o +   x z.%.>.:.>.*.y.d.&.>.:.>.*.r.qXqX",
"0XrXrXqXrXuXtXqXtXk.8         @.g.X.&.%.&.O.q.i.o.&.%.&.+.9.qXqX",
"0XtX9X3X4X3X3X4X6XF.a. .D T 5.V.C.a.g.f.g.a.M.C.a.g.f.g.s.m.0XqX",
"0XtX0X6X7X7X6X6X9XN.9.s.a.s.e.h.m.9.r.e.r.0.l.b.9.r.e.r.0.k.0XqX",
"0XtXrXqXwXwXwXqXtXh.O.&.%.%.+.0.s.+.*.&.*.@.w.p.+.*.&.*.@.0.qXqX",
"0XtXeX0XqXqXqX0XrXl.%.>.:.:.*.r.g.&.>.:.:.&.t.d.&.>.:.>.*.e.qXqX",
"0XtXeX0XqXqXqX0XrXk.$.:.;.:.&.e.f.%.:.;.:.&.t.d.%.:.;.:.&.e.qXqX",
"0XtXeX0XqXqX0X0XrXl.&.,.:.>.*.r.g.&.>.:.>.*.y.f.&.>.:.>.*.r.qXqX",
"0XtXrXwXeXeXeXwXyXg.X.&.$.%.O.8.p.o.%.$.%.O.0.i.o.%.$.%.O.8.qXqX",
"0XtX6X<X1X1X1X1X3XH.g.l.k.l.h.B.D.g.l.k.l.h.V.S.g.l.j.l.h.B.0XqX",
"qXwX7X4X5X5X5X4X8XeXrXrXrXrXtX9X6XyXrXrXrXtX9X6XtXrXaXrXtX0X8XwX",
"qXqXwXeXwXwXeXwXyXeX0X0X0X0XqX6X4XwX0X0X0XqX6X4XwX8X.X9XqX7X9XwX",
"qXqXqXqXqXqXqX0XtXeX0XqXqXqXwX6X4XwXqXqXqXwX6X4XtX,X@.4XeX7X9XwX",
"qXqXqXqXqXqXqX0XtXeX0XqXqXqXwX7X4XwXqXqXqXwX6X4XqXuXp.>XtX7X9XwX",
"qXqXqXqXqXqXqX0XtXwX0XqXqX0XwX6X4XwX0XqX0XwX6X4XqXeXK.3XeX7X9XwX",
"qXqXqXqXqXqXqX0XtXrXwXeXeXeXrX8X5XrXeXeXeXrX8X6XrXwXiXeXeX9X9XwX",
"qXqXqXqXqXqXqX0XtX5X,X1X<X<X1X>X;X1X<X<X<X1X>X;X1X<X,X<X1X,X9XwX",
"qXqXqXqXqXqXqXqXwX7X5X6X6X6X5X6X6X5X6X6X6X5X6X6X5X6X6X6X5X6XqXqX",
"qXqXqXqXqXqXqXqXqXwXeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"wX9X8X6X7X9X6X2X3X3X2X3X3X2X3X3X3X4X3X3X3X2X4XqX",
"tX0X9XyXwXrX(.,.6.5.1.s.s.1.5.5.5.c.5.5.6.<.g.wX",
"rXeX8Xk.}.gX!.+.-.=.$.w.w.$.=.=.=.f.=.=.-.#.y.wX",
"rXrX4XR L.kX!.$.>.:.*.r.r.*.:.;.:.h.:.:.>.&.i.wX",
"rXrX7XN.XXfX!.@.-.=.$.e.e.%.;.-.-.g.-.-.;.$.u.wX",
"tXqX0XuX0XyX/.=.6.8.,.y.i.:.1.1.1.l.1.1.2.;.s.wX",
"tX6X3X5X4X8X'.g.6.$.e.V.n.s.g.f.g.S.g.g.g.a.V.qX",
"rXeX0X2X4XiX_.v     . %.y.@.=.*.=.f.*.*.=.@.t.wX",
"rXrX3X>.J.lXL.    +   z p.&.:.;.:.h.:.:.>.&.i.wX",
"rXrX4X*.G.xXD.  O +   s u.*.:.:.:.h.:.:.>.&.i.wX",
"rXeX0X3X5XpX(.4       ! u.O.*.&.*.d.&.&.*.+.r.eX",
"tX7X5X7X5X9X].w.~ A | M.v.u.a.p.a.C.a.a.a.y.M.wX",
"tX0X8X8X6XrX(.3.t.t.0.d.d.4.8.7.7.v.7.7.8.3.j.wX",
"rXwXqXwX0XpX~.O.*.&.@.q.w.#.=.*.=.f.*.*.=.@.t.wX",
"rXwXqXqX9XuX^.$.>.:.*.r.r.*.:.;.:.h.;.:.>.&.i.wX",
"rXwXqXqX0XiX^.$.>.:.*.r.r.*.:.;.:.h.;.;.:.%.i.wX",
"tXqX9X9X8XyXQ.+.-.-.$.w.w.$.-.=.=.f.=.*.=.#.y.wX",
"eX3X<X1X1X2X:XoXOXOXOX+X+XOXOXOXOX+XOX@X$XoX#X0X",
"qXwXwXwXwXeXuXtXyXyXuX0X0XuXyXyXyX6XiX7X<XpXqX9X",
"qXqXqXqXqXwXrX9X0X0XqX6X6XqX0X0X0X2XiX`.k.sX5X9X",
"qXqXqXqXqXwXrX0XqXqXwX6X6XwXqXqXqX3XrX;XD.iX6X9X",
"qXqXqXqXqXwXtXwXeXwXrX8X8XrXwXeXwX4XeX0X4XrX9X9X",
"qXqXqXqXqXwXqX1X3X2X3X<X<X3X2X3X2X>X2X3X4X2X2X9X",
"qXqXqXqXqXqX0X6X7X7X7X7X7X7X7X7X7X7X7X7X6X7X7XqX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qX0XwXqX9X7X7X8X8X7X7X8X7X7X8XqX",
"wXwX,XwX'.4.9.i.a.7.0.h.q.7.s.8X",
"qXsXt..X{.X.$.2.6.$.&.w.=.#.7.7X",
"wXtX{.5X_.*.3.8.9.-.:.t.,.=.q.7X",
"eX7XyXyX[.,.| p.j.w.r.z.t.w.h.8X",
"wXyXR.>X!.@   k w.*.;.r.:.&.0.7X",
"qXpXc.$XL.    > 5.%.*.w.-.$.7.7X",
"eX9X9XtX'.A 0 ..g.5.9.g.0.5.a.8X",
"eX0X6XrX_.6.9.p.u.4.6.d.7.3.i.8X",
"eXeX0XpX(.@.=.4.8.*.-.r.:.&.9.7X",
"eXwX9XiX~...#.<.3.+.$.0.%.o.4.7X",
"wX6X3X7X=X^.(._._./.(.`.).`.`.9X",
"qXqXqXqXyXiXiXrXeXpXuXrX6XXXaX9X",
"qXqXqXqXeX0XqX8X7XqX0X8X2X_.eX8X",
"qXqXqXqXqX6X7X4X4X7X6X3X7X8X5X0X",
"qXqXqXqX0X7X7X7X7X7X7X7X7X7X8XqX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
