#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXzXxXcXcXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXcXcXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXcXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXcXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXfX6X,X1XtXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjX0X<X<X0XhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXtX1X,X6XfXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXaX3X<XgXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXzXfX.XK 3 t t.0XzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkX,Xo.7 7 ..>XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXqXi.t 3 H {.qXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXyX8XH.l q <XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXxX6XP =   . w s.lXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXsX+.2     2 o.aXgXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXzXg.e .   # 6 0 q q q q q q q q q q q q q q q q q q q q q q q q q q q q q 0 2 o = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXcX,X5         X.tX9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X6Xm         b 5X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9XtX+.                                                                            = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXcX1Xu X     @ ;.dXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXrXJ O     O F wXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXdX,.#                                                                           = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXzXtXu.r   @ R /.zXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXC.n X . v B.gXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXzX).K     = #.w.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.r.0.' : % :XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkX0Xf.X.;./.gXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXpXS.#.@.Z.pXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXlX0.    7 3XmXNXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXNXvX-X7.@.9XxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXzXzXtXfXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXpXiXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXNXi.    9 rXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXkXeXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXxXbXnXnXbXcXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXxXvXnXnXnXvXzXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXzXhX#Xy.O.X.9._.hXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXzX<Xc.$.| ,.H.aXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXzXgXOX) 2 = % < I L.zXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXjX5X:.w & % = n x.dXzXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXxX7X6.+ f *.1.n # R 0XkXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXzXdXm.1 4 ] 5.I & j :XjXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXvX#XM - z.uXBXn.0 h /.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXzXpX2.f 1.1XVX'.f < L.aXzXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXbXXXu : |.jXbX^.Z y S.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXgX`.Z.%XfXbX#XE < v.uXzXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXbX.Xy : XXaXjX/.F t C.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXhXfXjXlXvX[.m 2 G.pXzXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXbX.Xt : .Xg.V.C.H t C.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpXl.$ y ;XjXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXbX.Xt :  XS T e.K t C.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXP.h , 3.uXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXbX.Xt :  XC E t.K t C.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXbX'.I * T :XjXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXbX.Xt : XXL.~.G.H t C.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXcX-X .- m !.zXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXbX.Xt : oXvXNX_.D t C.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXwX3.2 a m.lXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXbXOXg ; E.gXNXI.z p L.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXaXc.e 6 p.gXvXcXzXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXvX;X~ & @.[.:X,.: N @XkXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXgX'.g   / (.,X:X<XiXkXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXzXuXS.6 % h f , 3 ;.hXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXzXuX .; + s D S A R /.sXzXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXrXN.V 2 , x u.6XlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXzXuX} 2 # = - - = w H.pXzXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXkXuX<X&X&X>XeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXjX4X*X$X$X$X$X$X*XtXjXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXzXcXvXvXcXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXcXvXvXvXvXvXvXvXzXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXdX6XrXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX0X9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXu.    8 wXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXpX5XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjX,XO.n G V.pXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXwXw.B B 0.eXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXbXhX5.    6 *XjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXfX].Q C 4XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXxX0X+.2   X v Z.zXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXfXe.y     8 J R R R R R R R R R R R R R R R R R R R R R R R R R R R R R R I u     & ..6XkXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXxX XY # & :XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXcX<X9 .     . @.iXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwX9XC                                                                               . 6 XXtXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXpXB.$   = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXcX<X9 .     . @.iXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwX9XC .                                                                               6 XXtXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXiXB.%   = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXxX0Xo.3   o v C.zXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXfXw.8     < F I I I I I I I I I I I I I I I I I I I I I I I I I I I I I U J a O   <  .6XkXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXxX XL   = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXhX>XO.v F B.pXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXJ     F eXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXvXsXZ.G v X.:XhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhXL.. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXsX5XeXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXeX5XsXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbX'.. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXzXvXmXMXmXbXzXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXxXiXoXD.m.A._.uXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXdXI.Y > @ - N A.tXxXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXzXXXG . f Q n * u '.zXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXxXj.i Z T.fX=Xm $ g.rXxXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXzX'.s.H.eXxXwX#.- 2.4XcXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXpXqXuXkXxXqX] * 7.6XxXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXzXxXzXzXjXOXp $ S.dXzXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcX2Xo.$ F #XcXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXvX0Xu.< r F.iXxXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXxXpXB.u 2 6.tXxXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXzXjXT.C * ` 0XlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXoX~ O J :XjXzXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlX9XO.o z T.iXsXsXhXkXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXxXk.u . y ) { { { U.tXzXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXxX5.<   X % $ $ $ t.8XxXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXzX+XD.n.n.b.b.b.b.+XaXzXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXvXmXMXMXMXMXMXMXvXzXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXgX9XuXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXR     I cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXuX9XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXzXxXtXfXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXR     U vXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXgXtXzXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX].. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkX0Xf.O.:.(.lXNXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXhXI     J sXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXgX).>.O.d.qXnXNXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXNXmX!.. = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXzXtXi.w   + J 0.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.5.u     p C.gXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXzX_.W +   8 *.t.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.i.r._   = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXcX1Xu .                                                                             O F eXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXfX,.@                                                                           = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXcX,X5 .                                                                               b 4X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8XtX+.                                                                            = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXxX6XK #     = 7 9 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 6 * .   1 X.aXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXlXg.0     o 3 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 8 9 8 1 o - >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXzXfX{.6     #.3XrXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwX*Xo.7 6 ..:XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXqX=.    3 _.0XeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXrX7XG.l 0 ,XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXqX0     w.mXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXjX7XXXXX7XhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnXt.    8 0XxXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXpX-X}.sXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.NXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXyXtXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXNXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX0XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXzXcXvXvXcXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXkXiX1X&X%X>XeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXyXS.S 4 , z u.7XlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXzXsXW.0 $ f f , 6 2.lXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXcX4X=.% ! ).:X;.= S <XkXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXxXwXF.8./.sXBXA.y l |.kXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXhXwX5XaXvXcXp.> m ,XkXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXxXxXlX_.d.m 4 2.fXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXjX` #   G ].xXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXjX$.g < C P.hXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXlXgX&X .$ D 1XkXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXkXgXfXkXlXzXW.C t V.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXxX0XD.B.wXlXcXOXQ 7 s.hXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXvX&XU f J.sXBXP.k t C.jXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXcX4X&.X z -.4.A % H ,XkXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXzXdX|.~ 1 = & , F S.kXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXzXhXXXt.o...5.~.dXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXxXbXnXnXbXcXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXtXq     r.MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXeXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXi.    8 eXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXdX7XhXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXzXyXq     r.NXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXpXpXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXNXi.    9 rXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXlXrXjXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlX8X0     0.mXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXbXhX XN.N.|.hXbXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXmXr.    8 7XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkX8XP.m.yXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXzXaXJ.2     / Q.].].].].].].].].].].].].].].].].].].].].].].].].].].].].].'.P.P # # K L.'.].].].].].].].].].].].].].].].].].].].].].].].].].].].].].!._     1 G.pXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXzX8Xd.7 - :XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXcX3Xx O       . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .         . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . . .       o k =XfXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXsXkXI.8   = >XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXcX<Xe - = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = - 0 }.0X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7XrXM.: = 6 ,XcXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXgX<X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X,XsXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXyX>X>X,XgXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXcXcXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXjXgXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXfXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXfXjXlXlXlX",
"lXlXzXjXmXJXGXzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXZXKXAXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXFXKXNXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXvXLXMXjXlXlX",
"lXlXjXMX-Xx.V.aXcXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX/.j.R.bXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXhXS.l.@XPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXUX0Xf.&XNXjXlX",
"lXjXmX;Xv     $.hXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXMXK.:   # M.MXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxX3.    p 1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.4.J   a.PXfXlX",
"lXgXJXc.  * O   ;XrX9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X4XxXD   &   j kX5X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9XqX8X$   @                                                         c.JXgXlX",
"lXgXGXZ.  O   ; 5XsXyXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXqXmX~   o   D bXwXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXiXyX8   .                                                         z.JXgXlX",
"lXkXzXaX&.  ; G.cXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXkXcX<XN   h &XvXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXbXU.    D ;X%X&X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X*X&X&X;Xt.  l.LXfXlX",
"lXlXkXcXjX;X5XcXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXiX*XtXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXeX    | UXvXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXBXxX:XwXvXkXlX",
"lXlXlXkXxXrXdXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXqXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { PXaXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXxXuXpXxXlXlX",
"lXlXlXlXlX9XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX6XfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXjXfXdXfXjXlXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXhXdXdXfXkXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXjXcXJXUXKXbXjXzXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXjXMXPXUXGXlXkXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXbX5Xp.=.w.=XMXhXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXzXcX X5.;.j.iXcXkXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXxX5Xv       p |.VXhXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXbX/.;       W aXvXkXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXjXNX<.  6.wXx.  #.cXlXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXkXvXaXN . D.eX^   W.nXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXhXCXS @ wXLX8Xu A rXvXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXcXsXp.m.kXPXG.X t.cXzXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXhXCXA + tXxX5Xk N wXbXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXzXzXdXAXj.  x.vXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXhXCXA * &X[ T.v m wXbXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXzXjXcXaXn   ,XmXkXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXhXCXZ > [.  p.B b wXbXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXjXlXbX@.  e.zXzXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXhXCXA & =X5.(.x M wXbXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXkXkXmXj.  T dXbXkXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXhXCXS O pXJX8Xk B wXbXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXjXMX~.  i 3XxXfXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXhXVXY @ @XUX>X: Y iXcXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXkXmX:X6 7 <XPXCXnXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXkXnXA.  k w.G   i.CXhXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXcXsX^   H i.q.8.OXzXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXkXt.%   X ,.uXcXkXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXkXnX0X0           j.cXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXxXzXqX4X9XkXvXkXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXkX0X4X3X2X3X2XiXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXkXzXnXMXnXxXkXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXzXnXmXMXMXMXMXcXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXlXlXhX4XwXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXsX1XpXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkX6XtXcXkXlX",
"lXlXlXjXNXxXMXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXCXlXCXjXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXzX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmXnXhXzXlXlX",
"lXlXjXmXJ.A Q <XbXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzX7.M ;.cXHXFXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXIX3X    _ FXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX[.x I.DXhXlX",
"lXhXCX/.>     M uXlXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXaXBX8.      i d d d d d d d d d d d d d d d d d d d d d d d f w     * G.BXsXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXfXbX$Xy   g.LXfXlX",
"lXfXKXl.  % o   &XqX6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X1XkXB   +                                                       . @   =.kX1X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X4XaXF.    z.JXgXlX",
"lXhXAXE.%     h rXjXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXBX>.    X 2 6 5 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 6 ,     o B.BXpXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXsXbXoX8   x.KXgXlX",
"lXlXjXbXN.j D &XbXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXcXi   2 kXVXBXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXAX4XP f g.vXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXAXz.  n.KXgXlX",
"lXlXlXkXMXkXbXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXHXd   6 VXfXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXxXmXjXNXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJXS.  m.KXgXlX",
"lXlXlXlXjX5XeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXFXd   5 BXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXtX4XhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXHXZ.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXlXlXhXgXgXhXlXlXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXlXzXBXDXDXBXzXlXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXjXvX0X*.t i &.pXzXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXkXzXsXQ   d t   E NXjXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXhXVX}.< ) fXMXc = ;XxXkXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXkXvXqXI.>XxXvX&.* /.nXjXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXxXmXcXhXnXn = 2XxXkXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXkXjXdXCXM.  E BXhXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXlXgXBX[.; 8 2XxXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXjXbX3Xj   !.NXkXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXkXzXfX!   c.BXkXlXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXkXjXnX5.  >.mXbXcXzXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXhXCX/.$   v S n P -XcXkXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXhXCX`.k r r w 7 j $XcXkXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXkXvXSXDXDXDXFXSXcXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXkXgXgXgXgXgXgXkXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXlX0XuXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXpX8XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJXA.  m.KXgXlX",
"lXlXlXlXzXqXpXzXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXfXGXd   6 VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXaX0XlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXfXHXA.  m.KXgXlX",
"lXlXkXxXcX8XyXbXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXzXIXf   6 AXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXpX7XxXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXxXUXF.  m.KXgXlX",
"lXkXlXhX3.@ 5 U.eX9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X3Xw   , 3XxXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXvX].w O +.9X8X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X8XiX9.  b.KXgXlX",
"lXgXFXD.                                                            .   L nXrXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXaXiXe                                                         O   l.KXgXlX",
"lXgXJXz.  @ .                                                       @   f hX4X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X9X7X@   X                                                         x.JXgXlX",
"lXjXMX#Xa     D | { { { { { { { { { { { { { { { { { { { { { { { _ =   X g.MXgXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXzX#.    9 { { { { { { { { { { { { { { { { { { { { { { { { | m   s.PXfXlX",
"lXlXdXPX1.    ;XUXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXFXH.=.V.vXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX9X    { UXHXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXUX3X*.[.CXjXlX",
"lXlXdXPX1.    %XvXaXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXfXVXlXVXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX8X    { HXtXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXsXbXnXhXzXlXlX",
"lXlXdXPX1.    &XBXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXsX1XaXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkX6XtXcXkXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXlXzXnXMXmXxXkXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXzXxXwX4X9XjXcXkXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXcXh.;   . <.pXcXkXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXkXbXR.  y w.F   k.AXhXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXjXnXv.H ~.UX=X% { jXzXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXzXsXeXgXLX{.  $.mXkXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXzXbXuXe.g > ].BXhXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXjXmX<X    ' dXxXkXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXzXxXgX&X#.  j.BXjXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXlXlXlXZX4Xp b wXbXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXjXmXz.5.hXSXfXF u 2XmXjXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXjXBX .  p.qXZ.  / fXxXkXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXkXxX,Xz       9 `.VXhXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXnX<Xi.*.0.$XmXjXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXjXvXJXUXLXnXjXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXlXjXfXdXfXhXlXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    *XBXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX7XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXwXuXcXlXlX",
"lXlXdXPX1.    &XBXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfX4XdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX9X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX9XyXcXlXlX",
"lXlXdXPX1.    %XnXfXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXhXmXsXnXjXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXfXxX8X    { IXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXkXdXzXlXlX",
"lXlXdXUX4.    <XUXGXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXHXJXDX$XD.oXAXJXHXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXHXUXiX    | UXsXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXiXG.:XmXkXlX",
"lXjXvX0XJ   . ,.G.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.Z.A.n.y   6 z.S.Z.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.F.9.O   m 2XbXkXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXvXiX$.  h.LXfXlX",
"lXfXLXg.                                                                                                                          &.nX6XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XjXG.    s.LXfXlX",
"lXjXMX*Xa.c.l.b.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.n.x.l.x.n.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.b.l.x.d.{.hXtXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXyXdX:Xj.s.%XMXjXlX",
"lXlXjXMXPXJXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXJXPXCXzXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXzXmXLXLXMXjXlXlX",
"lXlXlXjXfXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXfXjXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXfXjXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXgXfXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXfXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXfXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXlXlXlXlX",
"lXlXlXzXSXJXNXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXAXJXVXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXZXJXCXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXZXGXlXlXlXlX",
"lXlXzXyXX.n B.bXkXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXxXdX*.b k.vXlXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXzXjX2.v y.vXcXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXvXxX7.L vXlXlXlX",
"lXgXSXO.    + /.vXiXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXyXMX>.      L.nXuXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXyXNXe.    . 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5 5   + vXlXlXlX",
"lXfXJXM   ;   b.gX5X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X4XzXH   :   y.kX5X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X3XxX(   $                                                   7 vXlXlXlX",
"lXjXNXV.#   b 3XvXhXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXgXNXL.-   f =XnXhXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXgXMX^.,   q 1.<.<.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.1.<.1.<.4   bXlXlXlX",
"lXlXlXbX(.b.3XmXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX[.v.>XmXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXJXn   Q UXGXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLX+XV.xXlXlXlX",
"lXlXlXkXvXhXbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXgXbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXv   E GXuXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXfXnXfXlXlXlXlX",
"lXlXlXzXiX6XjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXaX5XhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXFXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfX6XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXhXgXgXjXlXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXhXgXgXjXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXxXZXGXFXMXlXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXxXCXGXFXNXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXjXbX9X$.g B H.vXkXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXjXvXyX,.g b N.vXkXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXkXzXdXR   F i   L.VXhXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXkXzXjX)   S s   Z.ZXhXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXhXVX.X  4.LX7X& ] zXzXkXlXlXlXlXlXzXfX8XkXlXlXlXlXlXjXmX5Xk ;.FXuX= / zXlXkXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXhXZX'.  D.UXiXc J gXxXkXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXzXgX;XrXvXuXh L gXxXkXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXhXZX'.  D.T.'.n J gXxXkXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXzXnXlXNXXX  4.CXhXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXhXZX'.  K.u :.A G gXxXkXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXgXcXuXa 6 :XmXjXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXhXZX'.  F.5.S.M H gXxXkXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXkXlXxX~   L.ZXgXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXhXZX'.  D.UXaXc J gXxXkXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXjXNX9.  w.BXgXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXhXVX X  8.PX9X- ' zXzXkXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXhXNXK.  $.HXZXMXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXkXzXsXP   Y h   G.VXhXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXjXnX3X9   U ` I h.kXlXkXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXjXbX6X .t x C.cXlXkXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXjXmX,XV s i i 3 ;.jXlXkXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXxXCXDXSXMXlXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXkXxXAXSXSXSXDXBXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXjXhXhXkXlXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXhXhXhXhXhXjXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXlXuX4XhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXpX3XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXFXb   E LXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdX4XlXlXlXlX",
"lXlXlXxXNXxXNXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXBXxXBXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXsXFXb   W PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXVXkXkXlXlXlX",
"lXlXzXdX:.G K.mXkXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXzXjX6.D V.AXVXVXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXVXBXAXl   I SXhXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXkXvXa.Q cXlXlXlX",
"lXhXAX=.    * ].vXpXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXiXNX7.    # p i i i i i i i i i i i i i i i i i i i i p y #   O A.MXiXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXiXMXM.  + bXlXlXlX",
"lXfXJXm   :   v.gX5X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X3XzXG   $                                                   *   :.lX3X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X3XzX#.  8 vXlXlXlX",
"lXjXBXz..   f :XbXgXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXfXNXC.#   w X. . ................................... ...{ :   4 [.mXfXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXfXMX).- ; bXlXlXlX",
"lXlXlXvXP.y.-XmXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXZXp   X.UXGXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXJX/.r. XMXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXPXA o mXlXlXlX",
"lXlXlXlXnXkXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXi    .GXyXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXfXmXkXmXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXKXC o mXlXlXlX",
"lXlXlXlXiX5XjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXi    .PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXsX4XfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXKXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXlXlXhXfXfXhXlXlXlXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXlXzXCXLXKXBXkXlXlXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXkXxXgXd.S K Z.bXkXlXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXxX<.  d q   n.AXgXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXkXbXrXz ( bXdX< L kXlXkXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXzXgX@X7XbXhXC M iXcXkXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXzXmXxXnX3X  | BXhXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXlXhXlXzXF # {.BXhXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXkXjXMX;.  h.ZXhXlXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXhXBXm.  ..nXhXlXlXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXjXMX{.o R ZXFXBXlXlXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXkXvXtXx   ! =.{ z.gXzXkXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXkXnX6Xb 6 5 4 $ _ dXzXkXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXzXMXMXMXMXNXnXlXlXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXlXkXkXkXkXkXkXlXlXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXzXsX9XlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXi   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgX8XjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXLXZ o mXlXlXlX",
"lXlXlXlXuX4XhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXi    .PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXaX3XdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXfXKXC o mXlXlXlX",
"lXlXlXzXBXcXNXfXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXsXBXp   ..PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXBXxXBXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXiXJXZ o mXlXlXlX",
"lXlXlXjXw./ ~.JXDXFXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXFXFXAXy   { JXgXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXkXvXz.! A.FXFXFXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXFXSXUXB O mXlXlXlX",
"lXhXZX3.    > n v b b b b b b b b b b b b b b b b b b b b l #   ; ^.nXaXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXaXNXx.    $ b b b b b b b b b b b b b b b b b b b b b b v @ > bXlXlXlX",
"lXfXJXn   $                                                   *   r.jX4X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X2XzX^   &                                                   5 vXlXlXlX",
"lXhXCXi..   q Q E E E E E E E E E E E E E E E E E E E E W I +   4 |.nXfXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXdXNXS.%   1 E E E E E E E E E E E E E E E E E E E E E E E $   bXlXlXlX",
"lXlXlXcX5   1.UXGXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXPXSXS.:.[.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXFXb   E UXGXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXKXT.8.xXlXlXlX",
"lXlXlXcX5   <.GXuXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXfXdXhXMXzXMXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXFXb   E GXuXfXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXfXdXfXNXkXkXlXlXlX",
"lXlXlXcX5   <.LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXpX3XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXFXb   E LXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdX4XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXlXlXkXgXdXfXjXlXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXlXlXlXAXPXKXmXkXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXkXcXfXk.~ | ].mXjXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXkXkXcX&.  q & - [.BXhXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXjXnX5Xk ( vX&X  ,.mXkXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXzXfX;XqXIXqX. =.MXkXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXlXzXvXbXH.G * {.NXhXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXlXkXgXmXp   E gXxXkXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXlXzXvXlXtXg.  g.NXjXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXzXgX0XfXbXdXB m sXcXkXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXjXBX#Xl I.UXzXx N aXcXkXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXjXbX7Xe & 3.^   a.NXjXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXjXnX#XV # , 4.fXxXkXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXlXlXvXvXlXzXbXxXkXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXlXlXkXlXzXzXlXlXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXvX5   1.LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXfX8XkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhX9XlXlXlXlX",
"lXlXlXcX5   <.LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXpX3XgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXFXb   E LXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXdX4XlXlXlXlX",
"lXlXlXvX5   1.GXuXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXhXNXxXNXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXiXSXb   E LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXlXkXlXlXlX",
"lXlXlXxX6   <.UXGXKXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXKXPXAXm.@.(.PXKXKXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXLXKXJXUXv   E KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXJ.,.cXlXlXlX",
"lXhXZX8.    1 A C Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z C Z M     = A C Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z Z C Z B @   $ Y.MXsXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXsXNXK.    bXlXlXlX",
"lXgXGXP + 3 = X o o o o o o o o o o o o o o o o o o o o o O < 5 ; o o o o o o o o o o o o o o o o o o o o o o O > 5   8.kX4X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X4XkX1.  h vXlXlXlX",
"lXlXlXvXvXvXbXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXbXvXbXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXbXvXbXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXbXvXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlX",
"lXlXlXkXlXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXlXfXgXgXgXgXgXgXgXgXgXgXgXgXgXfXhXvXlXlXlXlX",
"lXlXkXcXzXwXbXzXzXzXzXzXzXzXzXzXzXzXzXzXlXxXcXwXcXxXlXzXzXzXzXzXzXzXzXzXzXzXzXzXbXwXxXKXHXHXHXHXHXHXHXHXHXHXHXHXHXJXZXtXjXlXlXlX",
"lXlXlXzX'   i.nXdXhXhXhXhXhXhXhXhXhXhXgXfXcX:.  ;.cXfXgXhXhXhXhXhXhXhXhXhXhXdXnXi.  Y s.r.t.t.t.t.t.t.t.t.t.t.t.t.p.-.7 qXbXkXlX",
"lXkXvXeXX   d fX0XwXwXwXwXwXwXwXwXwXwXwXeXeX1   < wXeXwXwXwXwXwXwXwXwXwXwXwX0XfXh                                       qXbXkXlX",
"lXlXkXbXp.f R.mXjXlXlXlXlXlXlXlXlXlXlXlXjXmXB.a N.mXjXlXlXlXlXlXlXlXlXlXlXlXhXVXZ.  { &X].}.}.}.}.}.}.}.}.}.}.}.{.XXL.D eXvXkXlX",
"lXlXlXzXnXgXMXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXmXfXmXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX+X  p.UXMXCXCXCXCXCXCXCXCXCXCXCXCXCXZXgXhXzXlXlX",
"lXlXlXzXfXqXjXlXlXlXlXlXjXjXjXjXlXlXlXlXlXlXhX0XhXlXlXlXlXlXjXjXjXjXlXlXlXlXhXCX|.  w.DXsXhXhXhXhXhXhXhXhXhXhXhXhXhXjXwXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXlXlXkXmXZXCXNXkXlXlXlXlXlXkXeXkXlXlXlXlXkXnXZXCXBXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXlXjXMX).v l P.MXjXlXlXlXlXkXeXkXlXlXlXjXnX+XZ s n.MXkXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXkXxXsXt 4.p.4 wXvXkXlXlXlXkXeXkXlXlXlXkXnXG [ M.> :XnXkXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXkXnX5X1 aXkXp  XNXjXlXlXlXkXeXkXlXlXlXlXkX$XxXnXt (.BXjXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXkXnX3Xp y.1.b |.NXjXlXlXlXkXeXkXlXlXlXlXlXcXGXs.q gXxXkXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXkXnX3Xi h.w.b }.NXjXlXlXlXkXeXkXlXlXlXlXhXVX[.+ E.VXjXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXkXnX6X: fXnXq oXNXjXlXlXlXkXeXkXlXlXlXkXbXwXu B.UXzXkXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXkXzXlXC S T f dXzXkXlXlXlXkXeXkXlXlXlXkXmXZ   q.3.5XvXkXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXlXkXbX5X*.+.;XnXkXlXlXlXlXkXeXkXlXlXlXzXjXt.@.} ..1XbXkXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXlXlXkXvXJXKXnXkXlXlXlXlXlXkXeXkXlXlXlXlXlXFXJXKXKXvXkXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXkXgXgXkXlXlXlXlXlXlXkXwXkXlXlXlXlXlXhXfXgXgXkXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXrXhXzXlXlX",
"lXlXlXlXgXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXeXgXgXgXgXgXgXgXgXgXgXgXgXgXgXdXMX{.  w.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXrXhXzXlXlX",
"lXlXlXxXcXrXmXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXnXeXNXFXDXDXDXDXDXDXDXDXDXDXDXDXZXUX*X  p.KXgXlXlXlXlXlXlXlXlXlXlXlXlXlXMXuXgXzXlXlX",
"lXlXlXcX:.< N.mXgXjXjXjXjXjXjXjXjXjXjXjXhXnXu., 1.U.F.G.G.G.G.G.G.G.G.G.G.G.D.Y.5.  _ bXhXjXjXjXjXjXjXjXjXjXjXjXgXMXT.i wXbXkXlX",
"lXkXbXwX    a fX0XwXwXwXwXwXwXwXwXwXwXwXwXwX<                                         -XuXqXwXwXwXwXwXwXwXwXwXwX8XzXH   tXbXkXlX",
"lXlXlXcX:.< N.mXgXjXjXjXjXjXjXjXjXjXjXjXgXNX1.  X.Y.A.D.D.D.D.D.D.D.D.D.D.D.S.K.r.2 *.zXjXjXjXjXjXjXjXjXjXjXjXjXgXNXH.X wXbXkXlX",
"lXlXlXxXcXeXmXlXlXlXlXlXlXlXlXlXlXlXlXlXhXFXI.  Y.UXCXDXDXDXDXDXDXDXDXDXDXDXDXFXCXwXcXcXlXlXlXlXlXlXlXlXlXlXlXlXkXmX5X@ qXbXkXlX",
"lXlXlXlXgXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXF.  A.CXsXgXgXgXgXgXgXgXgXgXgXgXgXgXhXrXgXlXlXlXlXlXkXhXgXhXlXlXlXlXjXMX>X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXlXkXcXFXJXVXkXlXlXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXkXcXtX+.V C.mXkXlXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXjXCX .k a.: XXMXjXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXlXcX'.9XUXx n.AXjXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXlXlXbXDX`.; >XmXkXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXlXjXvXrX3 0.ZXjXlXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXkXzXmXH o.UXvXkXlXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXjXCX-.  k.v.1XvXkXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXkXbX5.L I S |.mXjXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXlXkXZXFXFXHXbXkXlXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXhXeXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXG.  D.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXeXhXzXlXlXlXlXhXgXhXgXkXlXlXlXkXMX,X@ qXbXkXlX",
"lXlXlXzXfXqXhXhXhXhXhXhXhXhXhXhXhXhXhXhXdXZXD.  S.DXgXlXlXlXlXlXlXlXlXlXlXlXlXlXjXqXdXjXhXhXhXhXhXhXhXhXhXhXhXhXgXbX:X@ qXbXkXlX",
"lXlXlXzXmXgXCXCXCXCXCXCXCXCXCXCXCXCXCXCXMXUXY.  K.FXgXlXlXlXlXlXlXlXlXlXlXlXlXkXMXgXMXZXCXCXCXCXCXCXCXCXCXCXCXCXBXJX9X@ qXbXkXlX",
"lXlXkXbXi.g Z.+X|. X X X X X X X X X X X{.*X5.  r.CXhXlXlXlXlXlXlXlXlXlXlXlXjXMXE.f q.#X}. X X X X X X X X X X X}.#XC.+ qXbXkXlX",
"lXkXvXwX.                                       2 wXeXwXwXwXwXwXwXwXwXwXwXwX0XgXg                                     o qXbXkXlX",
"lXlXlXcXY   { p.w.e.e.e.e.e.e.e.e.e.e.e.w.p._   *.cXfXgXgXgXgXgXgXgXgXgXgXgXdXMXw.  A a.q.e.e.e.e.e.e.e.e.e.e.e.w.u.*.4 0XbXkXlX",
"lXlXfXKXs.  &XUXDXHXHXHXHXHXHXHXHXHXHXHXHXKXbX;XxXcXlXzXzXzXzXzXzXzXzXzXzXzXjXZX#X  a.UXSXHXHXHXHXHXHXHXHXHXHXHXHXJXAX1XfXzXlXlX",
"lXlXgXHXr.  ].MXsXgXgXgXfXaXaXdXgXgXgXgXgXgXjXuXjXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX|.  q.SXpXgXgXgXgXgXgXgXgXgXgXgXgXfXjXiXhXzXlXlX",
"lXlXgXHXt.  }.CXhXlXlXkXvXJXKXbXkXlXlXlXlXlXjXwXjXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXrXhXzXlXlX",
"lXlXgXHXt.  }.CXhXlXkXbX9X:.o.;XnXkXlXlXlXlXkXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXgXHXt.  }.CXhXkXlXvXF n E l hXzXlXlXlXlXkXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXgXHXt.  }.CXhXlXzXhXP.BXeX< 8XbXkXlXlXlXkXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXgXHXt.  }.CXhXlXlXjXGX[.= %.CXjXlXlXlXlXkXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXgXHXt.  }.CXhXlXlXkXZX=XZ E zXlXlXlXlXlXkXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXgXHXt.  }.CXhXlXxXdX.XKXmXw ).VXjXlXlXlXkXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXgXHXt.  }.CXhXkXcXpXi 9.k.6 <XnXkXlXlXlXkXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXgXHXt.  }.CXhXlXjXmXQ.v k D.NXjXlXlXlXlXkXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXgXHXt.  }.CXhXlXlXkXMXZXCXNXkXlXlXlXlXlXkXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXgXHXt.  }.CXhXlXlXlXjXjXjXjXlXlXlXlXlXlXkXeXkXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X  e.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXzXtXhXzXlXlX",
"lXlXgXHXt.  {.VXgXkXkXkXkXkXkXkXkXkXkXkXjXkXgX9XgXkXjXkXkXkXkXkXkXkXkXkXkXkXgXBX}.  w.HXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXqXhXzXlXlX",
"lXlXfXJXp.  +XJXbXMXMXMXMXMXMXMXMXMXMXMXMXmXBXxXBXmXMXMXMXMXMXMXMXMXMXMXMXMXbXJX#X  u.JXfXlXlXlXlXlXlXlXlXlXlXlXlXkXmXcXjXlXlXlX",
"lXlXhXZX-.  V.0X:X,X,X,X,X,X,X,X,X,X,X,X>X5XH.H G.5X>X,X,X,X,X,X,X,X,X,X,X,X:X9XC.  &.AXjXzXzXzXzXzXzXzXzXzXzXzXkXmX&X( tXvXkXlX",
"lXkXvXtX5 o @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ .   . @ @ @ @ @ @ @ @ @ @ @ @ @ @ @ + o 4 1XiXeXrXrXrXrXrXrXrXrXrXrX0XxX)   rXbXkXlX",
"lXlXlXjXqXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXtXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXfXhXhXhXhXhXhXhXhXhXhXhXhXhXjXtXrXkXlXlXlX",
"lXlXlXlXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXvXbXlXlXlXlX",
"lXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXhXkXlXlXlXlXlXlXlXlXlXlXlXhXkXlXlXlXlXlXlXlXlXlXlXlXhXjXlXkXkXkXkXkXkXkXkXkXkXhXlXlXlXlX",
"lXlXlXzXAXbXkXlXlXlXlXlXlXlXlXlXzXAXbXkXlXlXlXlXlXlXlXlXlXzXZXmXzXxXxXxXxXxXxXxXxXzXxXVXzXlXlXlX",
"lXlXzXhXT.5XbXlXzXzXzXzXzXzXzXxXjXR.3XbXlXzXzXzXzXzXzXzXzXkXY.<XcXhXjXjXjXjXjXjXjXkXfX`.gXzXlXlX",
"lXhXAXR.  R vXeXyXyXyXyXyXyXeXzXP.  I cXeXyXyXyXyXyXyXrXlXI.  o = & & & & & & & & = X + sXxXkXlX",
"lXkXbX5XE H.nXfXhXhXhXhXhXhXgXxX5XW D.nXfXhXhXhXhXhXhXgXxX5X$ #.Q.F.J.J.J.J.J.J.H.K.A.*.sXxXlXlX",
"lXlXkXbXvXmXlXzXzXkXzXlXlXzXzXlXbXvXmXzXzXzXkXzXlXlXzXlXzXmX> K.UXCXSXSXSXSXSXSXSXSXFXxXjXlXlXlX",
"lXlXlXlXrXfXzXlXkXmXzXvXbXkXlXlXlXrXfXzXlXkXMXxXcXbXkXlXzXxX; N.ZXdXhXhXhXhXhXhXhXhXjXtXjXzXlXlX",
"lXlXlXzXuXhXzXjXMX.XG ~ 7XbXkXlXzXuXhXzXjXNX[.A ~ 7XvXjXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXlXlXzXuXhXzXgXGX` T.q.i.FXhXlXzXuXhXzXjXBXH.+X1.i.GXgXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXlXlXzXuXhXzXhXAX%.5. .k.AXhXlXzXuXhXzXlXjXNXZXF `.VXjXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXlXlXzXuXhXzXhXDX} H.0.i.DXhXlXzXuXhXzXlXjXSX;.s.LXgXlXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXlXlXzXuXhXzXhXDX6.@.! G.ZXjXlXzXuXhXzXhXAXc.: V.>XbXjXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXlXlXzXuXhXzXkXxXgXd.C.cXlXlXlXzXuXhXzXjXmX(.p.q.%XnXjXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXlXlXzXrXgXzXlXlXzXGXSXlXlXlXlXzXrXgXlXlXjXBXGXHXnXjXkXlXxX; V.FXhXlXlXlXlXlXlXlXlXzXyXjXzXlXlX",
"lXlXlXxXzXxXlXlXlXkXgXhXlXlXlXkXzXzXcXzXzXzXkXhXhXlXzXzXxXvX: C.DXgXlXlXlXlXlXlXlXkXxXlXkXlXlXlX",
"lXlXzXjXP.5XbXlXzXzXzXzXzXzXzXzXlXK.1XbXlXzXzXzXzXzXzXlXxXlX: B.FXjXzXzXzXzXzXzXzXxXjX~.dXzXlXlX",
"lXhXAXR.  E vXeXyXyXyXyXyXyXrXzXK.  + ; = = = = = = = = - -   L xXeXyXyXyXyXyXyXrXzXK.& gXxXkXlX",
"lXkXbX4XU D.nXfXhXhXhXhXhXhXfXxX2X+ #.Y.Z.S.S.S.S.S.S.S.D.S.T N.nXfXhXhXhXhXhXhXgXcX>Xh pXcXkXlX",
"lXlXkXbXvXmXzXzXzXzXzXzXzXzXlXzXbX; Y.UXCXDXDXDXDXDXDXDXDXFXcXmXzXzXzXkXlXlXlXzXlXxXkXZ tXcXkXlX",
"lXlXlXlXrXfXzXlXlXlXlXlXlXlXkXzXlX= Z.CXdXhXhXhXhXhXhXhXhXjXrXfXzXlXkXMXvXvXbXkXlXxXdXB yXcXkXlX",
"lXlXlXzXuXhXzXlXlXlXlXlXlXlXlXzXzX= S.DXhXlXlXlXlXlXlXlXlXzXuXhXzXjXMX XF ~ 7XbXkXxXfXB tXcXkXlX",
"lXlXlXzXuXhXzXlXlXlXlXlXlXlXlXzXzX= S.DXhXlXlXlXlXlXlXlXlXzXuXhXzXjXBXH.|.3.t.GXgXxXfXB tXcXkXlX",
"lXlXlXzXuXhXzXlXlXlXlXlXlXlXlXzXzX= S.DXhXlXlXlXlXlXlXlXlXzXuXhXzXlXjXMXFXJ ^.VXjXxXfXB tXcXkXlX",
"lXlXlXzXuXhXzXlXlXlXlXlXlXlXlXzXzX= S.DXhXlXlXlXlXlXlXlXlXzXuXhXzXlXjXDX1.t.LXgXlXxXfXB tXcXkXlX",
"lXlXlXzXuXhXzXlXlXlXlXlXlXlXlXzXzX= S.DXhXlXlXlXlXlXlXlXlXzXuXhXzXhXAXN.; C.,XvXkXxXfXB tXcXkXlX",
"lXlXlXzXuXhXzXlXlXlXlXlXlXlXlXzXzX= S.DXhXlXlXlXlXlXlXlXlXzXuXhXzXjXMX(.y.8.@XnXjXxXfXB tXcXkXlX",
"lXlXlXzXrXgXlXkXlXlXlXlXlXlXkXzXlX= S.DXhXlXlXlXlXlXlXlXlXzXrXgXlXlXjXBXGXHXmXjXkXzXdXB tXcXkXlX",
"lXlXlXzXzXxXlXzXzXzXzXzXzXzXlXxXxX- D.DXhXlXlXlXlXlXlXlXkXzXzXxXzXzXzXkXhXhXkXzXlXxXgXV tXcXkXlX",
"lXlXzXkXI.5XmXxXcXcXcXcXcXcXxXvXlX- S.FXjXzXzXzXzXzXzXzXzXzXU.3XMXxXcXcXcXcXcXcXxXbXfXV yXcXkXlX",
"lXhXZXY.  # > ; ; ; ; ; ; ; ; : :   T cXeXuXuXuXuXuXuXrXlXU.  @ > ; ; ; ; ; ; ; ; > @ : fXxXkXlX",
"lXjXnX<Xo #.K.N.V.V.V.V.V.V.V.C.B.L N.nXfXhXhXhXhXhXhXfXxX3X@ ..L.N.V.V.V.V.V.V.V.C.b.o.sXxXlXlX",
"lXlXzXcX= Q.UXZXFXSXDXSXDXFXDXDXFXcXmXzXzXzXzXzXzXzXzXzXzXMX> L.UXZXFXFXFXFXFXFXFXDXGXxXjXzXlXlX",
"lXkXxXhX& F.CXdXfXbXcXxXzXgXhXgXjXrXfXzXlXlXlXlXlXlXlXkXzXxX; N.ZXsXhXhXhXhXhXhXhXgXhXtXjXzXlXlX",
"lXkXxXjX& J.SXfXMX.XF ' 0XvXkXlXzXuXhXzXlXlXlXlXlXlXlXlXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXkXxXjX& J.SXfXBXI.|.O.b.DXhXlXzXuXhXzXlXlXlXlXlXlXlXlXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXkXxXjX& J.SXhXgXLX'.e 7XnXkXlXzXuXhXzXlXlXlXlXlXlXlXlXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXkXxXjX& J.SXhXzXtXNX:.b.SXhXlXzXuXhXzXlXlXlXlXlXlXlXlXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXkXxXjX& J.SXdXAXu.1.' v.SXhXlXzXuXhXzXlXlXlXlXlXlXlXlXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXkXxXjX& J.SXgXcXyXr.c.xXlXlXlXzXuXhXzXlXlXlXlXlXlXlXlXzXcX; V.FXhXlXlXlXlXlXlXlXlXzXiXjXzXlXlX",
"lXkXxXjX& H.SXhXkXxXGXSXlXlXlXkXlXrXgXlXlXlXlXlXlXlXlXkXlXxX; V.FXhXlXlXlXlXlXlXlXlXzXyXjXzXlXlX",
"lXkXzXkX= L.FXjXxXzXjXjXzXxXxXzXcXxXcXzXxXxXxXxXxXxXxXzXxXbX> C.DXhXlXlXlXlXlXlXlXkXxXlXkXlXlXlX",
"lXkXxXfXo V.BXaXfXfXfXfXfXfXfXgXsXK.>XkXdXfXfXfXfXfXfXdXgXfX@ b.GXhXzXzXzXzXzXzXzXxXhX~.fXzXlXlX",
"lXjXVX).> l Z B B B B B B B B V N , f Z B B B B B B B B V V : o.zXtXiXiXiXiXiXiXtXlX~.i fXxXkXlX",
"lXlXzXgXdXpXtXyXtXtXtXtXtXtXyXtXyXhXpXtXyXtXtXtXtXtXtXtXtXyXfXsXjXjXjXjXjXjXjXjXjXkXfXfXzXlXlXlX",
"lXlXlXzXxXcXcXcXcXcXcXcXcXcXcXcXcXxXcXcXcXcXcXcXcXcXcXcXcXcXxXxXlXzXzXzXzXzXzXzXzXlXzXxXlXlXlXlX",
"lXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlX",
"lXlXlXkXzXzXkXlXlXlXlXlXlXlXlXkXxXkXlXlXlXlXlXlXlXlXkXlXxXgXgXgXgXgXgXgXgXgXgXzXzXlXlXlX",
"lXlXkXcXjXlXcXzXzXzXzXzXzXxXzXbXfXvXzXzXzXzXzXzXzXzXcXlXgXLXJXJXJXJXJXJXJXJXKXkXjXzXlXlX",
"lXkXzXjXy P xXiXaXaXaXaXaXuXcXW.  C.bXuXaXaXaXaXaXuXvXO.2 P H H H H H H H J G p qXvXkXlX",
"lXlXzXzXI $.vXaXdXdXsXdXdXaXcX|.p W.bXaXdXdXsXdXdXpXBXO.% 8.,.<.<.<.<.<.<.<.,.T eXvXkXlX",
"lXlXkXcXcXvXcXzXzXzXmXzXzXzXlXnXzXnXlXxXlXvXbXlXzXjXKXz.m UXGXKXKXKXKXKXKXKXPXcXhXzXlXlX",
"lXlXlXzXiXsXzXkXzXxX4XcXzXlXlXkXtXjXlXkXbXpXqXmXkXgXHXd.l CXsXgXgXgXgXgXgXgXhXiXhXzXlXlX",
"lXlXlXzXaXdXzXjXmXq.K i.NXjXlXlXuXkXkXbX7X~ Y |.NXfXHXf.z DXhXlXlXlXlXlXlXlXzXaXhXzXlXlX",
"lXlXlXzXaXfXzXxXaX! +X/ hXzXlXlXuXkXlXvX4XrXl.w.HXsXHXf.z DXhXlXlXlXlXlXlXlXzXaXhXzXlXlX",
"lXlXlXzXaXfXzXxXpX' q.} fXzXlXlXuXkXlXhXVXfXY 5XbXfXHXf.z DXhXlXlXlXlXlXlXlXzXaXhXzXlXlX",
"lXlXlXzXaXfXzXzXfXW W.^ lXlXlXlXuXkXlXzXkXJ b.MXjXgXHXf.z DXhXlXlXlXlXlXlXlXzXaXhXzXlXlX",
"lXlXlXzXaXfXzXjXMXH.R U.NXjXlXlXuXkXkXmX=XI O.`.NXfXHXf.z DXhXlXlXlXlXlXlXlXzXaXhXzXlXlX",
"lXlXlXzXiXsXzXlXkXNXBXNXkXlXlXkXrXjXkXjXxXVXcXzXkXgXGXf.z DXhXlXlXlXlXlXlXlXzXuXhXzXlXlX",
"lXlXlXzXcXcXlXlXlXjXjXjXlXlXlXxXcXbXvXvXvXxXcXvXvXzXPXk.x FXhXlXlXlXlXlXlXlXxXxXjXlXlXlX",
"lXlXkXbXW.|.nXkXlXlXlXlXlXkXxXuXC.2XtXeXeXeXeXeXeX0XxXe.k CXjXlXlXlXlXlXlXlXlXQ.uXcXlXlX",
"lXkXxXgX  i lXtXuXuXuXuXuXrXxXC.  - < > > > > > > > 1     >XdXyXuXuXuXuXyXfX*X< 9XbXkXlX",
"lXlXkXvXZ.W.nXjXkXkXkXkXkXjXbX2X- W.3X-X;X;X;X;X;X-X2XE.b.lXkXkXkXgXhXkXkXkXzXP 3XnXkXlX",
"lXlXlXzXbXbXlXlXlXlXlXlXlXkXvXtX< 3XDXnXMXMXMXMXMXMXMXmXbXxXlXlXcXGXBXkXzXjXBX~ <XmXkXlX",
"lXlXlXzXuXaXzXlXlXlXlXlXlXkXvXeX> -XnXhXjXjXjXjXjXjXlXsXyXzXkXcXuXl.|.mXjXjXMXQ 1XmXkXlX",
"lXlXlXzXaXfXzXlXlXlXlXlXlXkXvXeX> ;XMXjXlXlXlXlXlXlXzXgXpXzXhXZXb.-.^ 5XbXhXNXQ 1XmXkXlX",
"lXlXlXzXaXfXzXlXlXlXlXlXlXkXvXeX> ;XMXjXlXlXlXlXlXlXzXgXpXzXlXlXhXNXT 7XbXhXNXQ 1XmXkXlX",
"lXlXlXzXaXfXzXlXlXlXlXlXlXkXvXeX> ;XMXjXlXlXlXlXlXlXzXgXpXzXlXjXFX,.S.FXhXjXNXQ 1XmXkXlX",
"lXlXlXzXaXfXzXlXlXlXlXlXlXkXvXeX> ;XMXjXlXlXlXlXlXlXzXgXpXzXhXSXk.e Q.pXxXjXNXQ 1XmXkXlX",
"lXlXlXzXaXfXzXlXlXlXlXlXlXkXvXeX> ;XMXjXlXlXlXlXlXlXzXgXpXzXjXnX[.c.M.aXxXjXNXQ 1XmXkXlX",
"lXlXlXzXiXpXjXgXgXgXgXgXgXfXzX0X> -XMXjXlXlXlXlXlXlXzXdXyXjXgXfXnXAXCXjXgXfXbXW 1XmXkXlX",
"lXlXkXcXvXBXJXHXHXHXHXHXHXGXPXxX1 2XMXlXzXzXzXzXzXzXzXnXnXJXGXHXFXSXDXHXHXFXUX) <XmXkXlX",
"lXlXlXzXo.o.z.d.f.f.f.f.f.f.k.e.  R.mXsXgXgXgXgXgXsXnXg.E l.f.f.f.f.f.f.f.f.h.l 7XbXkXlX",
"lXkXxXgX2 % m l z z z z z z x k   v.vXyXpXpXpXpXpXyXbXE   n z z z z z z z x j e wXvXkXlX",
"lXlXgXLXP 8.UXCXDXAXAXAXDXDXFXCX>XlXxXzXzXzXzXzXzXjXJXl.n UXAXDXDXDXDXDXDXDXGX8XsXxXlXlX",
"lXlXgXJXH ,.GXsXhXMXmXbXhXhXhXjXdXkXlXlXlXlXlXlXlXgXHXf.z AXdXhXhXhXhXhXhXhXjXfXjXzXlXlX",
"lXlXgXJXH <.KXdXMXC.E T.MXjXlXlXyXkXlXlXlXlXlXlXlXgXHXf.z DXhXlXlXlXlXlXlXlXzXpXhXzXlXlX",
"lXlXgXJXH <.KXgXzXK.A._ MXjXlXlXuXkXlXlXlXlXlXlXlXgXHXf.z DXhXlXlXlXlXlXlXlXzXaXhXzXlXlX",
"lXlXgXJXH <.KXgXjXUXX.6.DXhXlXlXuXkXlXlXlXlXlXlXlXgXHXf.z DXhXlXlXlXlXlXlXlXzXaXhXzXlXlX",
"lXlXgXJXH <.KXhXhXXX3X! hXzXlXlXuXkXlXlXlXlXlXlXlXgXHXf.z DXhXlXlXlXlXlXlXlXzXaXhXzXlXlX",
"lXlXgXJXH <.KXfXnX3.I r.mXkXlXlXuXkXlXlXlXlXlXlXlXgXHXf.z DXhXlXlXlXlXlXlXlXzXaXhXzXlXlX",
"lXlXgXJXH <.KXgXxXcX3XcXxXlXlXlXyXkXlXlXlXlXlXlXlXgXHXf.z DXhXlXlXlXlXlXlXlXzXpXhXzXlXlX",
"lXlXgXJXJ <.HXdXjXjXvXjXjXjXjXkXfXkXjXjXjXjXjXjXjXfXFXf.x DXhXlXlXlXlXlXlXlXzXgXjXzXlXlX",
"lXlXgXKXF <.UXbXNXNXMXNXNXNXBXbX*XxXBXMXNXNXNXNXNXbXUXh.j GXjXzXzXzXzXzXzXzXvX3XsXxXlXlX",
"lXkXzXhXj a ) W Q Q Q Q Q Q ! Y 7 L ~ Q Q Q Q Q Q W ) l e 8XdXiXpXpXpXpXiXfX3XM 0XbXkXlX",
"lXlXzXhXwX8X<X1X1X1X1X1X1X1X<X2XqX3X<X1X1X1X1X1X1X1X<X7XwXsXjXhXhXhXhXhXhXjXsX0XlXlXlXlX",
"lXlXlXzXvXbXmXmXmXmXmXmXmXmXmXmXbXnXmXmXmXmXmXmXmXmXmXbXvXxXzXzXzXzXzXzXzXzXxXbXlXlXlXlX",
"lXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXcXlXlXlXlXlXlXlXkXxXzXlXlXlXlXlXlXkXxXlXhXjXjXjXjXjXhXzXzXlX",
"lXzXdXlXzXzXzXzXzXzXxXfXkXzXzXzXzXzXlXcXaXcXCXBXVXVXVXBXCXkXhXzX",
"xXdX2 N.nXuXpXpXpXaXsX0 f.mXyXpXpXpXpXfXV d J S D D D D F a 7XnX",
"lXlXB.>XvXgXkXkXhXjXzXZ.*XvXgXkXkXhXfXZXJ q.;X}. X X X XoXL.yXcX",
"lXzXnXvXkXvXhXgXvXkXzXnXvXkXcXhXfXbXgXJX( R.UXMXVXVXVXBXCXmXkXlX",
"lXzXuXhXxXsX4.<.uXxXlXiXgXzXkXq.*.wXlXFX~ G.AXgXjXjXjXjXkXpXhXzX",
"lXzXaXhXMX=X<.2.+XNXkXaXhXzXdXjX>.&XbXFX~ H.DXhXlXlXlXlXzXdXhXzX",
"lXzXaXhXMX;X-.:.#XMXlXaXhXjXCXV.d.ZXdXGX~ H.DXhXlXlXlXlXzXdXhXzX",
"lXzXaXjXzXhXr.0.dXzXzXaXhXzXjX] q.uXkXGX~ H.DXhXlXlXlXlXzXdXhXzX",
"lXlXsXjXlXxXvXvXxXkXzXsXgXhXhXxXsXgXdXSX~ H.SXhXlXlXlXlXzXdXhXzX",
"kXxXdXzXzXzXlXlXlXzXvXpXmXFXSXSXDXDXCXUX] P.FXjXzXzXzXzXcXdXgXzX",
"xXfX0 C.nXuXaXaXaXsXpXB m R I I I I P ~ . 9.NXyXaXaXaXpXgX] 2XmX",
"zXkXf.*XvXgXhXhXhXgXmXm w.}.Q.~.~.~.!.).j..XbXgXhXjXgXfXMXO.-XNX",
"lXzXMXvXlXzXzXzXzXhXFXR }.UXVXZXZXZXZXAXNXvXlXxXcXlXbXhXSX9.=XNX",
"lXzXuXhXzXlXlXlXlXhXSXI Q.VXgXjXjXjXjXkXiXfXlXcXp.&.0XzXZX5.=XNX",
"lXzXaXjXlXlXlXlXlXhXSXI ~.ZXjXlXlXlXlXzXsXhXxXdXdX2.{.MXCX5.=XNX",
"lXzXaXjXlXlXlXlXlXhXSXI ~.ZXjXlXlXlXlXzXsXhXkXVX!.r.VXfXAX5.=XNX",
"lXzXaXjXlXlXlXlXlXhXSXI ~.ZXjXlXlXlXlXzXsXgXlXvX[ 2.tXlXZX5.=XNX",
"lXlXaXfXhXgXgXgXgXsXCXP !.ZXjXlXlXlXlXzXsXdXhXgXhXtXdXdXBX4.=XNX",
"kXcXfXZXJXGXGXGXGXSXUX~ ).AXkXzXzXzXzXcXgXBXJXGXHXKXHXSXUXt.*XNX",
"xXsXV J ( ~ ~ ~ ~ ~ ] . j.MXuXaXaXaXaXgXT Z _ ~ ~ ~ ~ ~ ) p 3XmX",
"lXcXd q.R.G.G.G.H.H.P.0..XvXfXhXhXgXdXBXZ $.Q.F.H.H.H.H.K.j.tXvX",
"hXCXJ ;XUXDXJXJXHXSXFXNXbXlXzXzXzXzXhXJX_ Q.UXZXDXDXDXSXFXNXjXlX",
"jXBXS }.MXdXe.7.pXkXjXuXgXzXlXlXlXlXgXGX~ F.ZXfXhXhXhXhXjXpXhXzX",
"jXVXD  XVXjX@X' rXcXlXaXjXzXlXlXlXlXgXGX~ H.DXhXlXlXlXlXzXdXhXzX",
"jXVXD  XVXfX0X*.1XnXlXaXjXzXlXlXlXlXgXGX~ H.DXhXlXlXlXlXzXdXhXzX",
"jXVXD  XZXpX7.1.wXvXlXaXhXzXlXlXlXlXgXGX~ H.DXhXlXlXlXlXzXdXhXzX",
"jXBXD }.mXkXaXaXxXgXjXaXfXhXhXhXhXhXsXSX~ H.SXhXlXlXlXlXzXsXhXzX",
"hXCXD *XUXVXSXSXZXAXDXjXMXSXAXAXAXAXBXUX) K.FXjXzXzXzXzXcXjXhXzX",
"zXhXk | q.5.5.5.5.5.9.R #.9.5.5.5.5.4.t.p j.NXpXdXdXsXsXjX4.6XnX",
"zXhX9X:X=X=X=X=X=X=X=X,X;X=X=X=X=X=X=X*X3XtXjXhXhXhXhXhXhX6XhXzX",
"lXzXbXMXNXNXNXNXNXNXNXMXMXNXNXNXNXNXNXNXmXvXlXzXzXzXzXzXzXnXzXlX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"hX3XjXlXkXlXlXlX3XdXzXkXlXkXzX9XqXuXyXyXyXuX8XsX",
"3XF 0XgXiXpXdXsXH .XzXiXpXiXbX) Z ..' ] ' } L *X",
"kXqXlXzXMXmXlXzXqXhXzXmXNXhXFX-.^.CXhXkXkXzXiXsX",
"lXgXlXzXn.T.mXkXgXjXnXL.M.jXFX>.(.ZXjXlXlXzXjXhX",
"lXaXbX9X:.r.kXlXsXkXxX7Xw.pXHX:./.ZXjXlXlXzXgXgX",
"lXaXvXyX*.t.cXlXsXhXZXf.z.mXSX:./.ZXjXlXlXzXgXgX",
"lXdXkXvXoX>XbXkXdXhXxX).].fXDX;./.ZXjXlXlXzXgXhX",
"lXsXzXlXNXmXkXxXsXnXMXHXGXvXUX1.(.ZXkXzXlXxXgXgX",
"3XH qXgXiXpXdXsXP Q | ' ' ] +.q A.mXuXiXiXnXd.XX",
"dXXXhXkXkXkXjXnXQ [.9X2X3X2X5XOXwXzXnXVXhXZXM.].",
"zXxXzXlXlXlXkXNX| 9XCXbXnXnXmXcXkXmXOXF.gXSXG.{.",
"kXaXlXlXlXlXjXMX[ 2XbXjXkXkXlXsXgXxX9X6.>XKXS.{.",
"lXsXlXlXlXlXjXMX{ 3XnXkXlXlXzXdXgXBX[.e.xXZXD.{.",
"kXpXhXgXgXgXfXvX] 2XnXkXlXlXzXaXaXbXT.m.iXCXZ.{.",
"zXnXGXFXFXFXDXUX+.5XmXlXzXzXxXcXAXFXUXUXSXUXR.[.",
"9X( -.>.-.;.:.1.q OXxXaXdXaXcX5.[ 2.-.=.;.4.P XX",
"qXZ ^.(.|.[./.).S.qXlXhXhXdXAX[ r..X^././.).U.wX",
"uX..CXDX*XqXFXZXmXxXlXzXzXhXGX1..XUXVXZXZXAXNXkX",
"yX' hXcXM.0.MXhXpXjXlXlXlXgXFX:.^.VXgXjXjXkXdXgX",
"yX] kXcX.Xq.bXkXsXkXlXlXlXgXFX:./.ZXjXlXlXzXgXgX",
"yX' hXhXc.L.xXhXiXgXhXhXhXdXAX;./.ZXjXlXlXzXdXgX",
"uX| ZXDXLXKXAXSXMXZXAXAXAXBXUX4.).AXkXzXzXzXvXlX",
"0XF A.D.A.A.D.F.w.B.F.D.D.A.R.P U.NXsXgXdXvX!.<X",
"dX$X[.{.{.{.{.{.[.{.{.{.{.{.[.XXwXjXgXgXgXkX<XuX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"hXwXlXgXzXtXaXlXjXkXeX0XqXqX9XhX",
"wXD.xXzXnXE.@XmXcXtX#.x.x.x.h.rX",
"lXxXfX`.dXxXbX2X&XfXk.AXmXNXbXkX",
"jXjX9XO.7XjXxX[.H.jXf.cXhXkXdXhX",
"zXmXgX XfXvXHX4XqXNXx.bXkXlXcXlX",
"tXE.xXxXbX{.b.R.Y.m.:.cXgXxX&XwX",
"aX@XlXaXCXn.M.*X.X X@XkXtXNX~.-X",
"zXcXlXjXZXK.=XJXMXBXcXxXS.tXOX>X",
"kXhXcXlXDXK.XXMXhXjXhXzXn.lXXX>X",
"kXyXiXrXvXM. XBXjXkXuXuX4XjX~.:X",
"eX#.l.v.v.:.@XcXgXyX#.j.z.l.t.0X",
"0Xc.VXOXlXvXlXlXcXiXj.BXcXbXcXkX",
"qXz.mXp.1XkXfXjXlXyXj.vXhXkXfXhX",
"0Xn.SXoXxXNXMXNXCXkXk.bXkXzXzXlX",
"wX0.XXoX XQ.(.}.|.~.t.cXfXzX2XyX",
"kX5X:X;X>X:X:X>X>X:X0XkXhXlXyXfX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
