#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9X7XqXqXqXqXqXqXqX0X6X8XqXqXqXqXqX7X9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X7X7X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9X8XqXqXqXqXqXqX8X6X9XqXqXqXqXqXqX7XqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX9XjXaXyXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXiXkX0XqXqXqXqXqXqXyXcXfX0XqXqXqX0XjXpXuXuXuXuXuXuXuXuXuXuXuXuXuXuXyXlXxXyXuXuXuXuXuXuXuXuXuXuXuXuXuXuXyXaXhX9XqXqXqXqX0XdXcXpX0XqXqXqXqXqXjXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX7XjXX.b.!.Y.T.T.T.T.T.T.T.T.T.T.T.T.T.T.T.T.T.T.T.T.T.Y.R.T.T.T.T.T.T.T.T.T.T.T.T.T.T.T.R.K.] tX0XqXqXwXqXeX~.v 9.pX9XqX9XsXX.C.W.Y.T.T.T.T.T.T.T.T.T.T.T.I.(.E A ~.Y.T.T.T.T.T.T.T.T.T.T.T.T.Y.!.b.#.gX8XqXqX9XdXp.v M.sX8XqXqXqX8X} wXqXqXqXqXqXqXqX",
"qXqXqXqXqX9XaXb.OX4X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X<X4XH.-X2X<X<X<X<X<X<X<X<X<X<X<X<X<X2X*Xf 4XqXqXqX0XqX0X<XZ 8 &XtX9X0XeXl {.6X<X<X<X<X<X<X<X<X<X<X<X<X<X3X}.f.3X<X<X<X<X<X<X<X<X<X<X<X<X<X<X9XQ.b pX9XqX8XsXJ.  k :X0X0XqXqXeX*Xj eXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XyX!.4XyXeXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXeXiXY.8XtXrXrXrXrXrXrXrXrXrXrXrXrXrXtXqXQ ).tXeX4X] x.xXcX@.2 }.iX7XtX XW <XiXeXrXrXrXrXrXrXrXrXrXrXrXrXeXuXW.tXeXrXrXrXrXrXrXrXrXrXrXrXrXeXaX&XW $XrX7XiX.X4 h rXcXiXqXqX0XyXR./ rXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXY.<XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXyX8.-.zX9X8Xk + h.j.o S qXqX5XxX8.;.rXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XP.wX0XqXqXqXqXqXqXqXqXqXqXqXqX0XwXwXO.a.lX9X4XH   4.H.n.(.qXqX6XlXX.p.uX0XqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqX0XpX_.S :XrXwX[.h     z '.pX6XrX5XK P.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XgXV.T 8XsX`.$         ^ qX8XuX#XZ oXuX0XqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX3./ fXtX0X1X.XXX2XtX5XrXjXO.+.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X9XaX` >.lX0X X[.{.|.[.%X7XuXtXU y.sX0XqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX0XX.  [ 2XlXpXiXtXwXrXzX7X%.  Q 3XrX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XrX1XP   1.wXMXfXiXyXpXdXxX:X^ O.rXqX0XqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqX0XeX0X .  y R R p.OXuXzXpX$Xh.Q E h   W 3XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX<XL   z T ~ l.&XaXzXyX.Xy.J ;.rXwX0XqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqX9XeXqX .  8 T.jXF.} ~ Y U U ! [ N.gX[.i   W 4XtX9XqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqX9XtX1XP   h  XsXc.] ! U U Y ~  .U.fXqX0XqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqX9XwX0X .  8 R.pX7XfXyX|.E.6.U.}.eXhX7XiX[.p   W 3XrX9XqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqX9XtX1XP   j  XuX8XhXqX{.L.7.!..XuXfX8X0XqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqX9XwX9X .  8 E.pX9X0X8XqXiXhX^.sXaXwX8X0X9XiX{.p   W 2XrX9XqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqX9XrX<XP   j .XiX9X0X8XwXsXiX/.kXuXqX8XqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqX0XeX0X .  7 R.pX9XqXqXqXqX9XqXL.7X0X0XqXqXqX9XiX[.p   W 3XrX0XqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqX0XtX<XP   h  XiX9XqXqXqX0XqX4XP.eX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqX0XeXqX .  7 T.pX9XqXqXqXqXqXqXeXP.9XwXqXqXqXqXqX9XiX[.i   W 4XtX0XqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqX0XtX1XP   h |.iX9XqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqX9XwX0X .  8 R.pX8XqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqX8XiX[.p   W 4XrX9XqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqX9XtX1XP   h |.uX8XqXqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqX9XwX9X .  8 E.pX9XqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqX8XiX{.p   W 3XrX9XqXqXqXqXqXqX0XP.wXqXqXqXqXqXqX8XrX<XP   j  XiX8XqXqXqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqX0XeX0X .  8 R.pX9XqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqX9XiX{.p   W 2XrX9XqXqXqXqXqX0XP.wXqXqXqXqXqX9XtX<XP   h  XiX9XqXqXqXqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X9XtXI.4XwX0XqXqX0XeXqX .  7 T.pX9XqXqXqXqXqXqXqXqX0X0XwXP.8XqX0XqXqXqXqXqXqXqXqX9XiX[.i   W 4XtX0XqXqXqXqX0XP.wXqXqXqXqX0XtX1XP   h  XiX9XqXqXqXqXqXqXqXqX0XwX5XI.rX9X0XqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXiXtXpXU.8XuXiXyX9XwXqX .  8 R.pX8XqXqXqXqXqXqXqX0XtXiXtXyXI.wXyXiXyX0XqXqXqXqXqXqXqX8XiX[.p   W 4XrX9XqXqXqX0XP.wXqXqXqX9XtX1XP   h |.uX8XqXqXqXqXqXqX0X0XyXiXuX9XU.iXtXiXrX0XqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaX2XB.{ N u b / f.#XdX9X .  8 R.pX8XqXqXqXqXqXqXqX0XsX,Xb.` m u m _ l.=XsX0X0XqXqXqXqXqXqX8XiX{.p   W 3XrX9XqXqX0XP.wXqXqX8XtX<XP   j  XiX8XqXqXqXqXqXqX0XqXsX%Xg.~ v u V | N.2XaX9XqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXP.P Y S.6XgX2XK.[ S f.+.  8 R.pX9XqXqXqXqXqXqXqX0XaXA.H Q L.8XgX>XF._ D n.pX0XqXqXqXqXqXqXqX9XiX{.p   W 2XrX9XwX0XP.wXqX9XtX<XP   j .XiX9XqXqXqXqXqXqX0XqXuXh.A ] ~.wXfX&XM.R P L.aX9XqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXb.v F.cXOXr.0.W.fXjX XA   u Y.pX9XqXqXqXqXqXqXqX9XaXs.n T.vX'.q.q.(.hXjX(.C 9.pX9XqXqXqXqXqXqXqX9XiX[.i   W 3XtX0X0XP.wX9XtX<XP   h  XiX9XqXqXqXqXqXqXqX0XuX>.D |.xXR.8.t.XXjXhXG.b v.aX9XqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaXP.v .XxXY.=     $ z.iXtXtXF } zX7XqXqXqXqXqXqXqX9XdXB.M &XlXm..     ; Z.iXiX2XS g.fX8XqXqXqXqXqXqXqX8XiX[.p   W 4XtX8XP.qXtX1XP   h |.iX9XqXqXqXqXqXqXqX8XfXq.L 7XgXq.      7 W.tXfXXXb L.aX9XqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX2XP F.jX9X( - R.-X6 c qX7XuX@XP /.sX9XqXqXqXqXqX0XyX=XH R.jX2Xx w .XOX$ D rX5XsX].F XXpX0XqXqXqXqXqXqXqX8XiX[.p   W 4XeXH.yX<XP   j  XiX8XqXqXqXqXqXqXqX9XsX_.F oXjXOX, V ;XQ.  ' tX5XhXF.P 2XtXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqX0XiXB.R kX7XqX(.(.sXnXB p 5XwX5XxX,.;.pXqXqXqXqXqXqX0XpXg.` xX7X8XB.!.aXuXH g :XrX4XcX+.9.pXqXqXqXqXqXqXqXqXqX9XiX{.p   Q ,XE.<XL   j .XiX9XqXqXqXqXqXqXqXqXqXpX:.<.zXtX].  y.VXqXb N 5XeX5XkXR N.iX0XqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XeX0X0X0X0X0X0X0X0X0X0X0X0X0X9XtX| B.pX9XqXrXaXXXe.o %.dX8X9XiX`.~ &XtX9X0X0X0X0XqX9X` J.pX9XqXiXtXwX6X< S rX0X8XpXW./ 1XeX0X0X0X0X0X0X0X0X0X8XuX].u   Q V.U   g |.uX8X0X0X0X0X0X0X0X0X9XtX*X~ `.yXiX].  u.*XXXN m 4XrX8XpXB.| tXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXY.4XiXtXtXtXtXtXtXtXtXtXtXtXtXtXtXpXZ +XrX0XqX4XxX..  0 #XyX9X0X0XwXG .XgXrXtXtXtXtXuX9XV :XwX0XqX0X8XfX&.  l.gX7X0XqX6XA ;XsXtXtXtXtXtXtXtXtXtXtXeXdX Xa   p   l oXdXeXtXtXtXtXtXtXtXtXtXrXfXXXF eX8XaX].  j.H =.D n 4XrX9XrX+XZ eXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXR.H.Y.I.I.I.I.I.I.I.I.I.I.I.I.I.I.U.s 4XwXqXqXwXtX#Xg.% ' iX9X0X7XkXA a.!.I.I.I.I.I.Y.D.g rX0XqXqX8XfXc.  _ uX9XqXqX8XdXb v.E.I.I.I.I.I.I.I.I.I.I.I.L.R.Z.r   9 z.!.J.I.I.I.I.I.I.I.I.I.I.I.!.d.V kX5XaX].  h.P <.S n 4XrX0XwX4Xl wXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.-X8X5X5X5X5X5X5X5X5X5X5X5X5X5X4X8XM &XeXqXqX7X7XyXpX| > }.uX8X9XuXF (.rX4X5X5X5X5X7X>Xm 2XwXqX8XpX~.+ h 2XqX0XqX0X0X0XV oX0X5X5X5X5X5X5X5X5X5X5X5X5X3XwX8X0   W =X8X3X5X5X5X5X5X5X5X5X5X4XeX_.S uX7XaX].  y.aX:XN m 4XrX0XeX&XN eXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.2XtXwXeXeXeXeXeXeXeXeXeXeXeXeXwXuX/ P.yXqX9X) 0.jXcX;.: ^.pX7XtX+XW $XpXwXeXeXeXwXrX0XQ ~.yX8XyX=Xy q 3XcXaXwXqX0XyX{.W <XyXwXeXeXeXeXeXeXeXeXeXeXeXeXqXyXh.p   ! 4XyXqXeXwXeXeXeXeXeXeXwXiX%XE OXeXpX[.  5.ZXeXi D 7XeX9XyXI.( rXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqX0XiXg.[ kX7XeXK   1.t.@ m 0XqX6XxXy.+.rXwXqXqXqXqXqXqXuXw.#.zX7X0X(   [ c.i.F.8XwX6XcX2.,.yXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XW.{.i   W 4XtX0XqXqXqXqXqXqXqXqXwXrX@.t.zX9X1Xz * y.#.  2.sX9X6XzX{ f.iX0XqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXyX#XS  XiX0X&XJ     b '.iX6XtX6XI F.fX9XqXqXqXqXqX0XiX[.D $XsX-Xr   .     N 3X9XrX,XJ E.sX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XJ.pX].p   W 4XrX9XqXqXqXqXqXqXqX9XfXG.P 5XeXeX(.g     ] ,XrX6XaX|.A #XyX0XqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XdXf.A tXiX9X8X;X;X7XrX5XtXfXO.X.aX0XqXqXqXqXqXqXqX8XfX7.I aXyX=X%X&X=X&X:X6XyXgX` $.gX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.0XiX{.p   W 3XrX9XqXqXqXqXqXqXqX0XaXX.o.dXtX0X6X-X>XqXwX5XaX9XG g.sX0XqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX9X+.  D @XzXpXtXwXqXrXxX6XO.E 5XeX0XqXqXqXqXqXqX0XeX5X`   T =XmXdXtXeXyXaXcX1X]   I :XtX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wX9XiX{.p   W 2XrX9XqXqXqXqXqXqX0XeX6XW o.5XzXuXtXwXqXuXcX@XI ;.yXqX0XqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqX0XeXqX .  u } P ,._.wXkXuXOXy.I X.5XtX0XqXqXqXqXqXqX0XrX6X^   g { P 3.[.eXkXtX X0.U { m   H >XyX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqX9XiX[.i   W 3XtX0XqXqXqXqXqXqX0XtX6XX.P t.OXyXkXwX`.1.G 0.uXqX0XqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqX9XeXqX .  8 Y.zX/.-.~ H Z F E +.F.aXeX0XqXqXqXqXqXqX9XrX7X^   y (.lXE.&.! G Z F W #.L.jXOXl   H >XyX9XqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqX8XiX[.p   W 4XrX9XqXqXqXqXqXqX0XeXaXG.+.W F Z G ~ -.(.fX0X0XqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqX9XwX0X .  8 R.pX7XsXpX*X.Xa.(.$XrXgX0X0XqXqXqXqXqXqX9XeX6X^   u _.pX7XdXuX%X}.p.'.%XtXfX7XuX+Xz   H :XtX8XqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqX8XiX[.p   W 3XrX9XqXqXqXqXqXqX0X0XfXrX$X(.a. X&XpXsX8XqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqX0XwX9X .  8 R.pX9XqX9XqXtXgX~.rXpXwX9XqXqXqXqXqXqXqX9XeX5X^   u _.pX9XqX9XqXyXsXQ.iXuXqX9XqX9XuX+Xz   H :XtX9XqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqX9XiX{.p   W 2XrX9XqXqXqXqXqXqXqX9XwXpXrX!.fXtXqX9XqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqX0XeX0X .  7 R.pX9XqXqXqXqX9XrXI.4XwXqXqXqXqXqXqXqXqX0XrX6X^   y ).pX9XqXqXqXqX0XwXP.8XqXqXqXqXqX0XuXOXl   H :XyX0XqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqX9XiX[.i   W 3XtX0XqXqXqXqXqXqXqXqXwX5XP.rX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqX9XeXqX .  8 T.pX8XqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqX9XrX7X^   y ).iX9XqXqXqXqXqXqXeXP.9XwXqXqXqXqXqX9XuXOXl   H >XyX9XqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqX9XiX[.p   W 4XtX9XqXqXqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqX9XwX0X .  8 R.pX8XqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqX9XeX6X^   u ).iX8XqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqX8XuXOXz   H >XtX8XqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqX8XiX[.p   W 3XrX9XqXqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqX9XwX9X .  8 E.pX9XqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqX9XeX5X^   u _.pX9XqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqX9XuX+Xz   H :XtX9XqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqX9XiX{.p   W 2XrX9XqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqX0XeX0X .  7 R.pX9XqXqXqXqXqXqXqXqX0XtXI.5XwXqXqXqXqX0XrX6X^   y ).pX9XqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqX9XuX+Xl   H :XyX0XqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqX9XiX[.p   W 3XrX0XqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXR.2XtXqX0XqX0XeXqX .  7 T.pX9XqXqXqXqXqXqXqX0X0XqXuXY.7XrXqX0XqX0XrX7X^   y ).iX9XqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqX9XuXOXl   H >XyX0XqX0XqXwXqXU.rXwXqX0XqXqXqXqXqXqXqX9XiX[.i   W 4XtX9XqX0XqXrX8XY.uXqX0X0XqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX9XiXK.*X0XyXpX9XwX0X .  8 R.pX8XqXqXqXqXqXqXqX9XyXpX9X9XD.>X0XuXpX8XeX6X^   u ).iX8XqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqX8XuXOXz   H >XtX8XiXiX9X3XS.6X9XiXuX9XqXqXqXqXqXqXqX8XiX[.p   W 4XrX8XiXuX0X,XD.9X9XpXuX9XqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX7XkX) a Q 7._.dX0X .  8 E.pX9XqXqXqXqXqXqXqX9XdX=Xg.` M p n Q q.[.fX5X^   u _.pX9XqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqX8XuX+Xz   H ;XhX.Xy.Q v a M ( p.#XdX0X0XqXqXqXqXqXqX8XiX{.p   W 2XgX{.w.Q c a V ` f.=XdX9XqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXwX8XcXuX/.-.S 3.X.  8 R.pX9XqXqXqXqXqXqXqX0XaXB.H _ F.9XMX7X~.#.D 8.`   y _.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqX9XuX+Xz   Y 0.G  .`.dXmX7XP.{ F z.pX0X0XqXqXqXqXqXqX9XiX{.p   ( 7.F @.!.aXbX,XJ._ H N.aX0XqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX9XsXa.z.sXzX>X(   y T.pX9XqXqXqXqXqXqXqX0XaXs.M R.zXkXm. .@XpXxX%XU   g (.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqX9XuXoXN   C oXvXK.@.&.W.hXzX`.A 8.pX0XqXqXqXqXqXqXqX9XiX].l   I $XvXiX8.,.4XaXxXW.N a.aX0XqXqXqXqXqXqXqXqX",
"qXqXqXqXqX6XcXV   0.iXeXfX[ E jX7X0XqXqXqXqXqXqX0XsXA.m *XdX0Xs.    I.tX5XuXaXR { lX7XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7XkX>.Z rXfXq.  % . = D.uXpX2XA l.dX9XqXqXqXqXqXqXqX7XlX .Y pXyX6Xo.  & &XqX4XgX=XM A.sX9XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXwX8Xf w 2X9XrX2XR F.fX8XqXqXqXqXqXqXtX,XH Y.dXeXK.= z : Y.yX0X8XuX=XP E.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqX0XpX].J oXfX;Xi n 1X+Xo E tX5XsX_.F #XuX0XqXqXqXqXqX9XdXW.P =XtXuX7.= g t *XeX0X6XgXT.H >XtXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX0XdXX.5 |.yX5XzXp.} yXqXqXqXqXqXqX0XiXb.~ lX6XuXoXI.k.o T.uX0XqX6XxX4.&.uXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXiX7.$.xX8X6XG.}.aX0Xn m 3XeX5XcX{ p.iXqXqXqXqXqXqXqXuX=.4.xX4XaXW._...4 =XeX0XqX6XlX! v.iX0XqXqXqXqXqXqX",
"qXqXqXqXqXqX0XuXd t 7XqX8XyX+X~ |.iX9XqXqXqXqX0XtX[ S.iX9X0X0XvXd.o T.uX0XqX9XuX{.! %XyX0XqXqXqXqXqXqXqXqXqXqXqXqX0XwXP.9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX1X~ ^.uX9XwXiXrXtX=X. / iX9X8XiXU.( 8XwX0XqXqXqX0XyX&X! {.uX9X0XtXlX' 5 =XeX0XqX9XiXA.] tXqXqXqXqXqXqXqX",
"qXqXqXqXqX8XfX9.  7.gX8X0X9XpXU E.hXqXeXeXeXeXwXyXV #XrX0XqX7XdXf.o T.uX0XqX0X0XrXG }.sXwXeXeXeXeXeXeXeXeXeXeXeXeXwXtXI.qXeXeXeXeXeXeXeXeXeXeXeXeXeXwXiX-XC 7XqX0XqX9X0XiXW   J.dX8X0XwX,XV 5XtXeXeXeXeXwXsX XD rX0X0XqX8XaX' 5 =XeX0XqX0XrX#XC eXqXqXqXqXqXqXqX",
"qXqXqXqXqX6XvXk N tXqXqXqX7XxXY 6.^.L.P.P.P.P.P.I.s 4XwXqXqX7XgXf.o T.uX0XqXqX7XkXA p.Q.P.P.P.P.P.P.P.P.P.P.P.P.P.P.I.Z.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.R.b.x sX8XqXqX8XdX7.  ,.sX8XqXqX0XtXj A.Y.P.P.P.P.P.Q.s.V kX7XqXqX9XdX' 5 =XeX0XqXqXwX4Xl wXqXqXqXqXqXqXqX",
"qXqXqXqXqX8XhX@.].tX0XqX0X9XaXU U.sX7X9X9X9X9X8XwXB $XrXqXqX7XgXf.o T.uX0XqX0X0XtXG '.iX8X9X9X9X9X9X9X9X9X9X9X9X9X9XqXP.7X9X9X9X9X9X9X9X9X9X9X9X9X9X9XrX%XV 9X0X0X8XsXZ.  L qX9X0XqX0XwX1XB 1XqX9X9X9X9X8XuX[.D tX9X0XqX9XdX' 5 =XeX0XqX0XeX%XV eXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX0XuXkXfXwXqX0XtX%X~ }.aX0XwXwXwXwXqXyX_ H.uX0XqX7XgXf.o T.uX0XqX9XyX.XQ %XuXqXwXwXwXwXwXwXwXwXwXwXwXwXqXeXP.9XwXqXwXwXwXwXwXwXwXwXwXwXwXqXtX1XQ _.yX7XiX[.: n iXzXaXqXqX9XuXE.^ 8XeXqXwXwXwXqXuX&XW .XyX9XqX9XdX] 5 =XeX0XqX0XuXH.` rXqXqXqXqXqXqXqX",
"qXqXqXqXqX9XaXm.:.f.2XwX6XzXg.[ eXwX0XqXqXqXqX0XiXl.) lX7XqX7XgXd.  T.uX0XqX6XcXq.$.yXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXuX3.;.xX8X3XZ   { r.<.V.9XqX6XxXX.t.iXqXqXqXqXqXqXqXtX%.0.cX6XqX9XdX` 3 =XeX0XqX6XzX) l.iX0XqXqXqXqXqXqX",
"qXqXqXqXqX6XxXD   s %XwXwX7XQ N.gX8XqXqXqXqXqXqXyX=XD (.dX6X8XgXh.$ R.uX0X8XyX<XL P.fX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX).F %XgXOXr @ # @   T 7X8XiXXXG  XiX0XqXqXqXqXqX9XdXI.K <XyX8X9XdX} 0 =XeX0X6XdX).F *XyX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXwX7X4X5X6XrXjX%.R gX7X0XqXqXqXqXqXqX0XsXb.V 2XdX6X9X8X5X9X0X6XyXpX] &.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX5.R tXiX3X3X4X5X5X5X6XiXyXS 9.jX8XqXqXqXqXqXqXqX9XsX&.' pXuX6X0X7X6X0X9X6XdX3XC b.sX0XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX0XeXuXxX5XO.  g _.iX9XqXqXqXqXqXqXqX0XiX8.A '.cXpXwX0XqXyXcX,X_ ` 0XwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXrXo.R %XnXpXeXqXrXpXcX+XD   Y ;XtX9XqXqXqXqXqXqX0XwX0X` ( >XcXyXqX0XqXpXcX[.D 8.iX0XqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX0XsXeX X8.K @.^   u `.iX9XqXqXqXqXqXqX0XqXpXf.F +.E.6XdXqX[.2.H :.0XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXrX5.F ;._.9XdX7X^.%.K :.M   H >XyX0XqXqXqXqXqXqX0XeX0X:.G 1.[.qXdX6XW.+.F f.pX0X0XqXqXqXqXqXqXqXqX",
"qXqXqXqXqX7XjX..l E -.I.dX6X!   i `.iX9XqXqXqXqXqXqXqX9XfXXX9./ A v V E >.W.sXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXdX(.2.Q C v Z ~ 5.'.lXoXz   H >XyX9XqXqXqXqXqXqX0XwXsXQ.,.E V v A / 8..XfX9XqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX9XpXC.{.<XrXdX9XeX5X~   i `.iX8XqXqXqXqXqXqXqX8XpXpX1X;Xv.oX<XyXsX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X9XaXuX<X$Xc.*X<XiXaX7XuX+Xz   H :XtX8XqXqXqXqXqXqX0X0XsXyX<XOXv.;X1XpXpX8XqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXW.6XiXqX9XqX9XrX6X~   u _.iX8XqXqXqXqXqXqXqX0XqXeXaXE.0XyXqX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XqXtXtXR.iXrXqX0XqX9XuX+Xz   H :XtX9XqXqXqXqXqXqXqX9XqXyXqXE.aXeXqX0XqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXY.<XeXqXqXqXqX0XrX6X~   u _.iX9XqXqXqXqXqXqXqXqX0XtXI.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XP.wX0XqXqXqXqX9XuXOXl   H >XyX0XqXqXqXqXqXqXqXqXwX5XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqX9XrX5X~   i `.pX9XqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqX8XuXOXl   H >XyX9XqXqXqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqX9XeX5X~   i `.iX8XqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqX8XuX+Xz   H :XtX8XqXqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqX9XrX6X~   i _.iX8XqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqX9XuX+Xz   H :XtX9XqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqX0XrX6X~   u _.iX9XqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqX9XuXOXl   H :XyX0XqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqX0XrX5X~   i `.pX9XqXqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqX9XuXOXl   H >XyX9XqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqX9XeX5X~   i `.iX9XqXqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqX8XuXOXz   H >XtX8XqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqX9XrX6X~   i `.iX8XqX0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqX9XuX+Xz   H :XtX9XqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqX0XrX6X~   u _.iX9X0XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX+Xl   H :XyX0XeX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX5X~   u `.iX8XtXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XuXOXl   H >XyXqX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XeX5X~   i `.uXeXI.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XuXOXz   H >XuX3XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XrX6X~   i _.fXL.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XuX+Xz   H >X0XP.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XrX6X~   y {.T.3XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XuX+Xl   K %XI.rX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.1XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0XrX6X~   p Z.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0XP.eXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XiXOXl   D /.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXE.3XyX8X9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X8XwX3X!   e 9XyX8X9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XqXP.8X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X8XP.qX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X7XtX.Xv   U gX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX6XxXZ % i.W.K.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.L.L.!.!   9 f.W.K.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.I.Z.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.Z.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.H.^.p.O 5 lX7XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX7XlX^   w W.aX0XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqX0XbXU   a '.pX0XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrXI.0XeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeXqXP.rXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwX0XpX{.g   ! fX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX9XuXR./   8 E.pX9X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XtXK.R   u _.iX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXP.9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XP.wX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XiX[.p   U (.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXR.,X..  9 W.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXT.,X^   i `.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XiX{.a   W ;XI.rX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXU.2XwX}   0 W.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXL.7X6X~   i `.iX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XiX{.s   R 3X9XP.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.,XtX0X}   0 E.pX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXU.3XtX6X~   i _.iX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XiX{.a   R 3XyX3XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.1XwXeXqX}   9 E.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XqXrX6X~   u _.iX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XiX[.a   R 3XtXqX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrX0XeX0X|   9 W.pX9XqXqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XeX0XrX5X~   i `.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqXqX9XiX{.a   R 2XtX0XeX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqX9XwX9X}   0 W.pX9XqXqXqXqXqXqXqXqXqXqXqX0XtXI.5XwXqX9XeX5X~   i `.iX9XqXqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqXqX8XiX}.s   R 1XrX9XqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqX9XwX0X}   0 W.pX8XqXqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqX9XrX6X~   i `.iX8XqXqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqXqX8XiX{.a   R 3XrX9XqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqX0XeXqX}   9 E.pX9XqXqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqX0XrX6X~   u _.iX9XqXqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqXqX9XiX[.a   R 3XtX9XqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqX0XeX0X|   9 E.pX9XqXqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqX0XrX5X~   u `.iX9XqXqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqXqX9XiX{.a   R 2XtX0XqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqX0XwX9X|   0 W.pX9XqXqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqX9XeX5X~   i `.iX9XqXqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqXqX9XiX}.s   R 1XrX9XqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqX9XwX0X}   0 W.pX8XqXqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqX9XeX6X~   i `.iX8XqXqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqXqX8XiX{.s   R 2XrX9XqXqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXT.<XrXqXqXqXqXqXqXqX9XeXqX}   9 E.pX8XqXqXqXqXqX0XtXI.5XeXqXqXqXqXqXqXqX9XrX6X~   u _.iX9XqXqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqXqX8XiX[.a   R 3XtX9XqXqXqXqXqXqXqXwX6XI.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XuXY.<XeX0XqXqXqXqXqXqXqX0XeX0X}   9 E.pX9XqXqXqXqX9XrXI.4XwXqXqXqXqXqXqXqXqX0XrX6X~   u `.iX9XqXqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqXqX9XiX{.a   R 2XtX0XqXqXqXqXqXqXqXqXwX5XI.rX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX0XyX!.9XaXwX9X0XqXqXqXqXqXqX0XeX9X|   9 W.pX9XqX9XqXtXfX!.eXiXwX9XqXqXqXqXqXqXqX9XrX5X~   i `.pX9XqXqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqXqX9XiX}.a   R 1XrX9XqXqXqXqXqXqXqX9XwXiXrX!.fXtXqX9XqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX9XaXb.Q.%XwXgXqX9XqXqXqXqXqXqX9XwX9X}   0 W.pX7XsXpX=XoXd._.%XrXfX0X0XqXqXqXqXqXqX9XeX5X~   i `.iX8XqXqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqXqX8XiX{.s   R 2XrX9XqXqXqXqXqXqX0X0XfXrX%X_.d.XX*XiXsX8XqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX7XjXO.z E O.C.uXrX9XqXqXqXqXqXqX9XeXqX}   9 R.lX(.:.~ A m A E @.G.pXeX0XqXqXqXqXqXqX9XrX6X~   i _.iX8XqXqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqXqX8XiX[.a   R 3XtX9XqXqXqXqXqXqX0XeXaXH.@.Y B m S ~ ;.).fX0X0XqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXwX7XVXbX$Xa.Y ] <XyX0XqXqXqXqXqXqX0XeXqX}   i | P >._.hXJXsXOXt.P X.6XtX0XqXqXqXqXqXqX0XrX6X~   u _.iX9XqXeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wXqX9XiX{.a   R 3XtX0XqXqXqXqXqXqX0XtX6Xo.P t.,XNXGXaX_.<.F q.uXqX0XqXqXqXqXqXqXqXqX",
"qXqXqXqXqX8XhX%.:.eXxX0X-.L <XrX0XqXqXqXqXqXqX0XeX9XO.  S +XvXgX4.n [.iXxX5Xo.W 6XeX0XqXqXqXqXqXqX0XrX5X~   i `.pX9XeXP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.wX9XiX{.a   R 1XrX9XqXqXqXqXqXqX0XeX6XW ..8XgXw.C J A.fXxX+XP :.uXqX0XqXqXqXqXqXqXqX",
"qXqXqXqXqX7XlX!    .uXqXhX,.( uX0X0XqXqXqXqXqXqX9XdXf.Z rXiX4X=.    U.tX6XtXdXO.X.aX0XqXqXqXqXqXqXqX9XeX5X~   i `.iX0XP.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XP.0XiX{.s   R 2XrX9XqXqXqXqXqXqXqX0XaXX.X.dXtX}   p 4   M.uXuX9XF h.sX0XqXqXqXqXqXqXqX",
"qXqXqXqXqXqX0XaXF 4 $XwXwXqXQ v.hX8XqXqXqXqXqXqXyX$XS |.uXyXF.2 H - Y.uX0X8XtX5XP G.fX9XqXqXqXqXqXqXqX9XrX6X~   i _.aXK.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XJ.pX[.a   R 3XtX9XqXqXqXqXqXqXqX9XfXH.P 3XfX|.+ _ dX=X* E wX7XpX}.A $XyX0XqXqXqXqXqXqX",
"qXqXqXqXqXqX0XfX<., (.iX5XzXx.] qXwX0XqXqXqXqX0XiXg.[ lX6XtX*X.Xx.X T.uX0XqX6XxXt.+.rXwXqXqXqXqXqXqXqXqX0XrX6X~   u '.Y.7XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XW.}.p   R 3XtX0XqXqXqXqXqXqXqXqXwXrX#.t.lXyX].  y.NX7XM m 4XrX6XzX[ f.iX0XqXqXqXqXqXqX",
"qXqXqXqXqX0XrX%X%.< (.iX7XrX=XQ {.sXqXwXwXwXwXwXuX/ P.yX0X0X0XcXs.o T.uX0XqX0XtX+XE $XpXwXwXwXwXwXwXwXwXeXqXtX6X^   i F.tXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXtXj.d   W 3XyXqXeXwXwXwXwXwXwXwXwXiX%XE +XeXpX].  p.E.!.B m 4XeX9XuXP./ rXqXqXqXqXqXqXqX",
"qXqXqXqXqX8XdXu.] 4 (.iX8X9XsXU L.iX4X6X6X6X6X5X9XM &XeXqXqX7XdXf.o T.uX0XqX0X9XuXF (.rX5X6X6X6X6X6X6X6X6X6X4X8X,XW   6 8X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X9X1   Y ;X9X3X6X6X6X6X6X6X6X6X6X5XrX_.S uX7XaX].  l.l  .F n 4XrX0XeX*XN eXqXqXqXqXqXqXqX",
"qXqXqXqXqX9XiXP.X.2 (.iX9X7XxXY 7./.P.I.I.I.I.I.U.s 4XwXqXqX7XgXf.o T.uX0XqXqX7XkXA a.!.P.I.I.I.I.I.I.I.I.I.I.P.P.).W y Y.U.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.T.a R ).I.P.I.I.I.I.I.I.I.I.I.I.I.!.d.C kX5XaX[.  f.*.d.Z m 4XrX0XwX4Xl wXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX0XdX1., /.iX8X0XuXY !.kXeXtXtXtXtXrXiXZ +XrX0XqX7XgXf.o T.uX0XqX0X0XwXH  XfXrXtXtXtXtXtXtXtXtXtXtXtXrXrXfXkXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXjXfXtXrXtXtXtXtXtXtXtXtXtXtXtXrXfXXXF wX8XaX].  y.MX7XN m 4XrX9XrX+XZ eXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX9XlXQ 2 XXtX7XuXXX^ .XuX9X0X0X0X0X9XtX| B.pX9XqX7XgXf.O T.uX0XqX9XiX`.^ *XtX9X0X0X0X0X0X0X0X0X0X0X0X0X0X8X8X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X8X8X0X0X0X0X0X0X0X0X0X0X0X0X0X9XtX=X~ `.yXuX|.  #.vX5X4 P 9XwX8XpXB. .tXqXqXqXqXqXqXqX",
"qXqXqXqXqX8XhX=.  Y pX9X6XxXy. .iXqXqXqXqXqXqX0XiXN.R kX6XqX7XgXa.  U.uX0XqX6XcX1.-.pXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXpX:.<.xX7X8XT   T n   d.dX8X6XkXR M.iX0XqXqXqXqXqXqX",
"qXqXqXqXqX7XlXQ Q ,XrX7XuX:XJ U.fX8XqXqXqXqXqXqXrX2XP G.hX5X8XdXn.r ^.yX0X7XpX@XG (.sX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XsX).F +XiXqX*X` 7 u y.qXqX5XhXG.P 1XtXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX0XaXaXwX6XiXtX^ ;.fX8XqXqXqXqXqXqXqX0XaXL.v XXhX7X8XtXdXeX9X7XaX9XI 0.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfX0.P 9XpX9XpXdXfXuX0X6XhXoXb L.sX9XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX0XqXtXlX#XU O.rXqX0XqXqXqXqXqXqXqXqX9XaXc.v F.kXpXeX0XeXuXzX|.G ;.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XuX:.D }.lXtXqX0XeXpXkXG.b c.aX9XqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX8X=XT.X.Z y.rXwX0XqXqXqXqXqXqXqXqXqXqX9XaXL.P R N.@X4X*XP.{ A g.yXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXyXh.A [ P.*X4X+XB.R P L.aX9XqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqX7XjX} h ^ i.oXsXqX0XqXqXqXqXqXqXqXqXqXqXqXqX9XsX2XN.| Z k N / d.$XsXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXsX$Xf.( N k Z } M.1XsX9XqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwXeXrXuXuX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XtXiXtXeXwXeXrXiXyX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XyXiXrXeXwXeXtXiXtX9XqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXqXqXqXqX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XqXqXqXqXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqX0XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqXqXqXqXqXqX9X0XqXqXqXqX0XqX0X0X0X0X0X0X0X0X0X0X0X9X0XqX0X0X0X0X0X0X0X0X0X0X0X0X0XqXqXqXqX0X9X0XqXqXqXqX0X0XqXqXqX",
"qXqX0XrXaXrXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXrXtXtXtXtXtXtXtXtXtXtXtXtXyXiXqXqXqXqXqXeXdXtX0XqXqXeXiXtXtXtXtXtXtXtXtXtXtXtXtXgXaXrXtXtXtXtXtXtXtXtXtXtXtXuXyX0XqXqX0XwXdXyX0XqXqX0XyXrX0XqXqX",
"qXqXrX>X'.:X*X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X:X=X=X=X=X=X=X=X=X=X=X=X=X&X.XwXqXqX9XqX4XW.:XrX0XeX3X X;X*X=X=X=X=X=X=X=X=X*X;XP.`.:X*X=X=X=X=X=X=X=X=X*X-X+X&XrX0X0XeX0X!.&XtX0X0XtX&X<XrXqXqX",
"qX0XaX'.y.$X].{.{.{.{.{.{.{.{.{.{.{.{.{.{.{.}.{.K.}.{.{.{.{.{.{.{.{.{.{.|.`.I qXqXqXiXrX2Xz ! aX8XdXK.] ;X'.{.{.{.{.{.{.{.{.[.+X>.r.$X].{.{.{.{.{.{.{.{.[.%Xg.%.lX7X9XgX .# [.yX9X7XlX*.H.hX9XqX",
"qXqXrX:X$XdXyXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXyX).iXuXuXuXuXuXuXuXuXuXuXuXiX+.OXuX6X%.].PX>.k eX0XaXz.f.vXrXuXuXuXuXuXuXuXuXuXaXwX#XdXyXuXuXuXuXuXuXuXuXyXjX|.&.rX8XfXk.;  XAXeX0XqXrX=._.aX0XqX",
"qX0XtX*X].yX8X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9X^.0X0X0X0X0X0X0X0X0X0X0X8XsXr.d.kX0XA 5 o.# 6.sX6XiX[ ].yX9X0X0X0X0X0X0X0X0X9XrX&X'.yX8X0X0X0X0X0X0X0X0X9X0XqX[ {.hX{.  8 -.[ `.rXuXoX[ qXqX0XqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X^.wXqXqXqXqXqXqXqXqXqXqX0XtX%X{ 1XfX;X#.D w.9X8XzXS.,.iX0XqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqXqXqX9XsXA.;.bX[.W E L G R.uXgX#.M.fX9XqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X^.wXqXqXqXqXqXqXqXqXqXqX9XqXsXS c ,XzXvXbXjXaXjXL.% f.jX8XqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqXqXqX8XiX%X, *.gXAXvXcXnXxXiX3.;.pX0XqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X^.wXqXqXqXqXqXqXqXqXqX0XwXyX[   U { y.{.2X>XE.-.} j   B.dX9XqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqXqX8XiX&Xp = `  .b.#X4X#XV.[ 5.tXwX0XqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X^.wXqXqXqXqXqXqXqXqX9XwXtX}   &.gX*Xp.@.E ( ;.V.uX<Xj   V.dX8XqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqX8XiX*Xa . F.lX^.6.} T } 5.^.dXqX0XqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X^.wXqXqXqXqXqXqXqX0XwXyX}   -.iX0XtXsXdX].>XdXdX0XyX>Xk   V.dX8XqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqX8XiX*Xa . G.dX8XaXaXrX^.rXaXaX9XqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X^.wXqXqXqXqXqXqX9XwXyX}   -.iXqX0X0X8XyX].;XrX9XqX8XuX>Xl   V.dX8XqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqX8XiX*Xa . G.dX8XqX0X0XqX^.0X0X0XqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X^.wXqXqXqXqXqX9XwXyX}   -.iXqX0XqXqX0XuX].;XtXqXqXqX8XuX>Xk   V.dX8XqXqXqXqX0XtX-X[.uX0XqXqXqXqX8XiX*Xa . G.dX8XqXqXqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X^.wXqXqXqXqX0XwXyX}   -.iXqX0XqXqXqX0XuX].;XtXqXqXqXqX9XuX>Xl   V.dX9XqXqXqX0XtX-X[.uX0XqXqXqX8XiX*Xa . G.dX8XqXqXqXqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X8X~.0X0XqXqX9XwXyX}   -.iXqX0XqXqXqXqX9XtX'.=XeX0XqXqXqXqX8XuX>Xl   V.dX8XqXqX0XtX-X[.uX0XqXqX8XiX*Xa . G.dX8XqXqXqXqXqX0X9X~.9X0XqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0X8XyXdX XgXtX8X9XwXyX}   -.iXqX0XqXqXqXqX8XqXkX#X8XdX9X9XqXqXqXqX9XuX>Xk   V.dX9XqXqXtX-X[.uX0XqX8XiX*Xa . G.dX8XqXqXqXqX0X8XtXfX XfXtX8X0XqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqXqX9XtXgX*XL.0.Y.-XfXuXtX}   -.iXqX0XqXqXqX0X0XgX6X(.y.M.XXpXpX9XqXqXqXqX8XuX>Xl   V.dX8X0XtX-X[.uX0X8XiX*Xa . G.dX8XqXqXqXqX9XrXgX=XI.0.U.=XgXrX9XqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqXqX9XpX:X>...q.y.<.{ 3.;X .  -.iXqX0XqXqXqX0XeXyXl.] 4.u.6.O...(.dX9XqXqXqXqX8XuX>Xk   V.dX8XtX-X[.uX7XiX*Xa . G.dX8XqXqXqXqX9XiX<X<. .q.y.<.} <.,XiX9XqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqX9XpX}.T M.<XE.Q.wX4Xb.j   ;.iXqX0XqXqXqX0XwXqX+.:.;X'.P.>XyXW.! n.sX9XqXqXqXqX8XuX>Xl   V.sXwX-X[.rXuX*Xa . G.dX8XqXqXqXqX9XiXXXR v.:XE.W.wX7Xx.E .XiX9XqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqX0XtX:XT _.hXJ + & M 8XzX^.v 1XtX9XqXqXqXqX0XaX-.0.nXr.o < ; W.cX6X~ P.sX9XqXqXqXqX8XuX>Xk   V.jX*X`.gX%Xa . G.dX8XqXqXqXqX0XrX1XE ~.hXR @ = l 3XxX^.E <XrX0XqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqX8XgX,.c.nX[.V '.>X+ H.uXhXz.6.gX8XqXqXqX9XsXU...gX9XG q.zXc ~ iXiXOX/ 8XwXqXqXqXqXqX9XuX>Xl   S.4XXX>Xp . G.dX8XqXqXqXqXqX8XhX3.g.VXH.o }.<X* z.iXjXz.1.gX8XqXqX",
"qX0XtX=X}.uX0XqXqXqXqXqXqXqXqX0XyX*X .3XeX9X0XyXS.> '.uXeX;X| ,XtX0XqXqX0XpX,.L.fX7X2X8XlXJ Q sX6XdX<.H.sX9XqXqXqXqXqX8XuX>Xk   l.R.f   H.dX8XqXqXqXqXqX0XtX:X .:XkXB.: 6X7Xk 0.fXqX1X| -XtX0XqX",
"qX0XtX=X{.yX9X0X0X0X0X0X0X0X0X8XdXU.>.dX9X7XhXs.  ` dX9X9XaX&.~.aX9X0X0XqX9X[ <XeXqXqXdXQ.. C.fX7XsXZ.6.kX7X0X0X0X0X0X0X8XyX:Xh O u & S.sX7X0X0X0X0X0X0X9XsXW.=.iXdXN.q 9.O.b 0.fX7XsX;.R.dX9XqX",
"qX0XrX:XK.).^.^.^.^.^.^.^.^.^.~. Xe.1.zX7XrXaX>X9.5 '.uX6XlX=.a.|.~.^.^./.E.R eXqX9XtX;X, _ aX9X9XdXY.` OXQ.^.^.^.^.^.^.^.!._.~.n   @.OXW.^.^.^.^.^.^.^.~.|.u.;.hXsXN.9 p.,.b 0.fX5XlX>.J.gX9XqX",
"qX0XtX=X}.iX0XwXwXwXwXwXwXwXwX0XfXT.:.aXeX$XI.kXkXg <.hX7XpX&./.dX0XwXwXwX0X{ >XwXwXrXM V gXiX0X0XsXV.9.lX8XwXwXwXwXwXwXwXwX9XpX4Xe # B.fX9XwXwXwXwXwXwX0XdX~.=.uXfXB.= aXjXd q.fX7XaX;.E.dX9XqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqX0XtX-X} :XfXT.# j.N.# V.aXeX;X| 1XrX0XqXqX0XpX1.D.dXtXo.  S.^.XXeX8XsX;.L.aX9XqXqXqXqXqXqXqXqX0XwX>XT.v   V.dX8X0XqXqXqXqX0XrX,X| -XdX).$ r.M.. J.pXwX,X| :XrX0XqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqX8XfX3.b.jX0X2.> > #.eX7XlXp.0.hX8XqXqXqX9XsXT.O.fX5Xh ; 0 # &.rXiXOX] 8XwXqXqXqXqXqXqXqXqXqX0XtX*XXX4Xj   V.dX8XqXqXqXqXqX8XhX7.d.kXeXe., : &.wX7XlXg.5.hX8XqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqX9XuX;Xj ^.lXdX6X3XyXyXlXL.~ 6XeXqXqXqXqXqX8XkX! <.kXtX3X,X<X8XfX7XN M.kX7XqXqXqXqXqXqXqXqXqX0XtX;X'.fX;Xk   V.dX9XqXqXqXqXqXeX4XQ I.zXdX7X3XyXyXlXT.Q 3XeXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqX9XwXtX .  c z.=XdXxXiX-Xp.~ &XuX9XqXqXqXqX8XdXB.$ 2 <. XyXxXkX7XP.!   k %XiX8XqXqXqXqXqXqXqXqX0XtX-X[.rXyX>Xl   V.dX8XqXqXqXqX9XuX$XQ a.-XsXxXiX;Xd.! @XuX9XqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqX0XwXyX}   ;.1X6.| &.=.&.| 0.6XuX9XqXqXqXqX8XdXV.  k =XV.[ $.=.*.o.+.XXL.  a &XiX8XqXqXqXqXqXqXqX0XtX-X[.uX7XuX>Xk   V.dX9XqXqXqXqX9XuX5X8.| &.=.&.| 7.4XuX9XqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqX9XwXyX}   -.iXtXgX,X~.p./.<XhXeX9XqXqXqXqX8XdXV.  l :XiXdX0X Xj.F.%XsXuXsXH.. s &XiX8XqXqXqXqXqXqX0XtX-X[.uX0X8XuX>Xl   V.dX8XqXqXqXqX9XeXhX<X/.p.^.,XhXeX9XqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqX9XwXyX}   -.iXqX9X8XtXaX|.dXrX8XqXqXqXqXqX8XfXV.  k :XuX8X9X0XjX@X7XsX9X9X8XdXH.. a &XiX8XqXqXqXqXqX0XtX-X[.uX0XqX8XuX>Xk   V.dX8XqXqXqXqXqX8XrXsX|.sXrX8X0XqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqX0XwXyX}   -.iXqX0XqXqX0X9X~.0X0XqXqXqXqXqX8XdXV.  l :XuX8XqXqX9XyX'.-XrX0XqXqX8XdXH.. s &XiX8XqXqXqXqX0XtX-X[.uX0XqXqX8XuX>Xl   V.dX8XqXqXqXqXqX0X0X~.9X0XqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqX9XwXyX}   -.iXqX0XqXqXqXqX0X^.wXqXqXqXqXqX8XfXV.  l :XuX8XqXqXqX0XuX].;XtXqXqXqXqX8XdXH.. s &XiX8XqXqXqX0XtX-X[.uX0XqXqXqX8XuX>Xl   V.dX8XqXqXqXqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqX0XwXyX}   -.iXqX0XqXqXqXqXqX0X^.wXqXqXqXqX8XdXV.  l :XuX9XqXqXqXqX0XuX].;XtXqXqXqXqXqX8XdXH.. a &XiX8XqXqX0XtX-X[.uX0XqXqXqXqX9XuX>Xk   V.dX9XqXqXqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X|.uX8X0X9XwXtX}   -.iXqX0XqXqXqXqX9X0XqX/.wX0X9XqX8XdXV.  l :XuX8XqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqX8XdXH.. s &XiX8X0X9XrX;X{.uX8X0XqXqXqXqX8XuX>Xl   V.dX8X0X9X0XwX/.qX0X9XqXqXqXqXqXqXqX",
"qX0XyX&X`.iXsXyXqXyX}   -.iXqX0XqXqXqX0X0XsXpX8XE.0XpXsX8XdXV.  k :XuX9XqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqX8XdXH.. a &XuXqXfXpX&X).iXsXuX9XqXqXqXqX9XuX>Xk   V.dX8XsXpX0XE.9XpXsX9XqXqXqXqXqXqX",
"qX0XiXXXU o.e.%XsX[   -.iXqX0XqXqXqX0XwXaXU.>.] E { <.T.kXB.  l :XuX8XqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqX8XdXH.. p -XeXz.$._ W X.w.#XdX9XqXqXqXqX8XuX>Xl   B.jXY.,.[ E [ ,.Y.sXwX0XqXqXqXqX",
"qXqXqXwXeX*Xs.{ S   &.iXqX0XqXqXqX0XeXqX-...I.5X0X>XF.+.! $ k :XuX8XqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqX8XdXG.@ i _ 7.|.4XrX=Xj.~ B.dX9XqXqXqXqX8XuX:Xk $ Q +.J.4X0X,XK. .:.wXeX0XqXqXqX",
"qX9XsX(.7 Q.mX<Xv Y gX0X0XqXqXqXqX0XyX+.q.gXdXJ u 4XhXsX1.3 =XiX8XqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqX7XkXh.: ^.pX_ - r U.MX>X( V.dX9XqXqXqXqX8XiX=X2 3.fXgXY w 1XhXsX0.$.uX0XqXqXqX",
"qX0XwXwXH a 8XaX<X{ *XtX0XqXqXqX8XgXl.;.jXrX( # y :X0X9XkX<.V.dX9XqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqX0XyX*.K.ZX3.- U.W e 6XaX,X~ $XuX0XqXqXqX9XdXM.2.jXyX] $ w =XqX9XkX=.c.gX8XqXqX",
"qXqX7XzXV.8 =XqXjXu.p.sX8X0X0X9XqX6X[ $XyX9X~.s.t ,XrX8XiX|.{ 0X0X9X0X0X0X0X0X0X0X0X8XyX].-XeX9X0X0X0X0X0X0X0X0X8XuX/...pXeX`.).BXG.6 $XqXjXh.r.sX8X0X0X9X0X9X[ XXuX0X~.j.e -XrX9XuX@X[ 9XwX0XqX",
"qXqX0XpXP c aX9XyX X+.sXyXuXuXtXkX_.-.uX0X8XbXn.0 <XrX0X0XrX$. XjXyXuXuXuXuXuXuXuXuXyXfX}.1XsXyXuXuXuXuXuXuXuXuXrXbXu.b.sX9XuXrXgXQ h iX9XtXOXO.pXuXuXuXtXjX{.&.tX0X8XvXZ.7 ;XrX0X0XtX*.(.sX9XqX",
"qX9XsX/.X !.pX9XwX6XE ].].].].'.$Xp.1.lX7X8XfXc.q <XrX0X8XkX=.j.@X'.].].].].].].].].].}.U.^.{.].].].].].].].].]._.*X] T.dX0X7XfXk.  Y.aX9XqX0XW _.[.].].'.@Xg.;.lX7X8XdXB.8 ;XrX0X8XlX>.K.gX9XqX",
"qX0XsX^.e.jX8XqXeX<X) >X;X;X;X=X8XN.,.hX8X8XgXv.q <XrX0X8XgX=.F.7X-X;X;X;X;X;X;X;X;X-X1X^.oX,X;X;X;X;X;X;X;X;X;X*XeX%.K.sX7XsX^.X r.hX9XqXwX4X) =X:X;X;X-X7XS.-.hX8X8XfXV.8 ;XrX0X8XhX:.I.fX9XqX",
"qXqXqXqXiXtXqX9XaXE.;.dXrXtXtXeXdXXX@.0XwX8XgXb.r <XrX0XeX6XO.%XsXrXtXtXtXtXtXtXtXtXeXsX{.,XpXrXtXtXtXtXtXtXtXtXwXlXc.u.sXqX:X0 } zXrXqX9XpX^.=.aXrXtXtXeXsX#XO.7XwX8XfXC.q ;XrX0XwX8X+.XXiX0XqX",
"qX9XpX}.2 J 1X8XjX-.V.dX9XqXqX0X9XpX..Q.dX5XjXj.: ,XrX6XgXP.#.sX8X0XqXqXqXqXqXqXqXqX9XyX].;XrX0XqXqXqXqXqXqXqXqX0XrX&X/ 7XjXO.  i e A ,X9XjX<.n.dX9XqXqX0X9XaX+.Y.fX4XhXn.= =XtX7XfXR.o.aX9XqXqX",
"qX0XrX>Xs.Z.5XcXL.} uX0XqXqXqXqX9XpX(.! 8XpXwX@XD.6X9XsX2XW }.iX0XqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqX9XfXy.:.vX].b.z.h.B.4XxXT.' tX0XqXqXqXqX0XiX].W 4XaXwX$XD.5X9XaX6XQ `.pX0XqXqX",
"qXqX0XyXCXnXpXS.% g :XuX8XqXqXqXqX9XsXn.~ +XdXjXmXdXdX XQ Z.sX9XqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXtX&.;.uXNXNXVXmXaXH.- p =XuX8XqXqXqXqX9XsXB.Q XXdXjXmXdXdXoX! N.dX9XqXqXqX",
"qXqXeX3XG.j.[ ,.h.. g ;XuX8XqXqXqXqX9XsXP./ <.C.P.V.:.) E.sX9XqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqX0XwXtXi.~ w.D.K.k.{ ;.l.+ p &XiX8XqXqXqXqX9XsXT.( >.V.P.C.>.( U.sX9XqXqXqXqX",
"qX0XiX X' f.'.iXkXZ.  h ;XuX8XqXqXqXqX9XsX8XH.7.` 9.K.0XaX9XqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqX0XqXfX*Xb.*.} s.`.uXkXG.. a &XiX8XqXqXqXqX9XaX0XK.8.` 7.J.9XsX9XqXqXqXqXqX",
"qXqXtX;X;XvXyX0X8XfXA.  j -XuX8XqXqXqXqX9XwXsXkXOXzXaXwX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XrXlXwX=XbXyX0X7XdXH.. s &XiX8XqXqXqXqX9XwXsXlXOXkXsXwX9XqXqXqXqXqXqX",
"qX0XtX*X'.rX9XqXqX8XdXA.  j ;XuX8XqXqXqXqXqX9X7XQ.8X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX&X`.rX9XqXqX8XdXH.. a &XiX8XqXqXqXqXqX9X8XQ.7X9XqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqX8XfXA.  j -XuX8XqXqXqXqXqX0X^.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqX8XdXH.. s &XiX8XqXqXqXqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqX8XdXA.  j ;XuX8XqXqXqXqX0X^.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqX8XdXH.. s &XiX8XqXqXqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqX8XfXA.  h ;XuX8XqXqXqX0X^.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqX8XdXH.. a &XiX8XqXqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqX8XdXA.  j ;XuX8XqXqX0X^.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqX8XdXH.. s &XiX8XqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqX8XdXA.  h ;XuX8XqX0X^.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqX8XdXH.. a &XiX8XqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqX8XdXA.  j -XuX8X0X^.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqXqX8XdXH.. s &XiX8XwX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqX8XdXA.  j ;XuX8X^.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqXqXqX8XdXH.. a &XiX9X^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqXqXqXqXqXqXqXqX8XfXA.  j ;XuX!.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqXqXqXqX8XdXH.. s &XiX!.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX*X[.yX9X0X0X0X0X0X0X0X0X0XqX0X8XdXZ.  j -X_.9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XyX].;XrX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XrX-X[.yX9X0X0X0X0X0X0X0X0X0XqX0X8XsXG.  a &X`.9XqXqXqXqXqXqXqXqXqX",
"qX0XtX=X+XaXeXtXtXtXtXtXtXtXtXtXtXtXtXwXjXG.. j ^.pXwXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXeXsX{.,XpXrXtXtXtXtXtXtXtXtXtXtXtXtXtXtXrXpX>X}.sXeXtXtXtXtXtXtXtXtXtXtXtXtXwXjXP.O p T.rX0XqXqXqXqXqXqXqXqX",
"qX0XyX$XS.6X-X=X;X-X-X-X-X-X-X-X-X-X-X-X*X6Xz.  x 5X>X*X;X-X-X-X-X-X-X-X-X-X-X-X-X-X=X<X^.XX>X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X>XXX^.<X=X-X-X-X-X-X-X-X-X-X-X-X-X-X*X5Xm.@ M sX9XqXqXqXqXqXqXqXqX",
"qX9XsX/.  ! XX{.].[.[.[.[.[.[.[.[.[.[.[.[.`.$XJ.  7 Y.XX`.[.[.[.[.[.[.[.[.[.[.[.[.[.].|.Y./.}.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.}.^.Y.|.].[.[.[.[.[.[.[.[.[.[.[.[.[.`..X~.9 6 sX9XqXqXqXqXqXqXqXqX",
"qX0XrX>XI   >.gXuXyXuXuXuXuXuXuXuXuXuXuXuXuXeXzXr.. v 1XfXrXuXuXuXuXuXuXuXuXuXuXuXuXyXfX}.1XsXyXuXuXuXuXuXuXuXuXuXuXuXuXuXuXyXsX<X|.fXyXuXuXuXuXuXuXuXuXuXuXuXuXrXfX2Xx   h.uX9XqXqXqXqXqXqXqXqX",
"qX0XtX-XXX@.  %.uX0X8X0X0X0X0X0X0X0X0X0X0X0X0X6X{.A.  g =XyX7X0X0X0X0X0X0X0X0X0X0X0X8XyX].-XeX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XeX=X].yX8X0X0X0X0X0X0X0X0X0X0X0X7XyX-Xg   Z.{.9XqXqXqXqXqXqXqXqXqX",
"qX0XtX&X|.dX .  &.iXqX0XqXqXqXqXqXqXqXqXqXqXqX0X!.fXA.  j -XuX8XqXqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqXqXqXqX8XuX;Xh   Z.fX!.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X[.uXtX..  &.iXqX0XqXqXqXqXqXqXqXqXqXqX0X^.9XdXA.  j ;XuX8XqXqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqXqXqX8XuX;Xh   Z.dX9X^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X}.yXqXyX..  &.iXqX0XqXqXqXqXqXqXqXqXqX0X^.wX8XfXA.  h ;XuX8XqXqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqXqX8XuX;Xh   Z.dX8XqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX8XwXyX..  &.iXqX0XqXqXqXqXqXqXqXqX0X^.wXqX8XdXA.  j ;XuX8XqXqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqXqX8XuX;Xh   Z.dX8XqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0X0XwXyX..  &.iXqX0XqXqXqXqXqXqXqX0X^.wXqXqX8XdXA.  h ;XuX8XqXqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqXqX8XuX;Xh   Z.dX8XqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqX9XwXyX..  &.iXqX0XqXqXqXqXqXqX0X^.wXqXqXqX8XdXA.  j -XuX8XqXqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqXqX8XuX;Xh   Z.dX8XqXqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqX0XwXyX..  &.iXqX0XqXqXqXqXqX0X^.wXqXqXqXqX8XdXA.  j ;XuX8XqXqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqXqX8XuX;Xh   Z.dX8XqXqXqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX=X{.uX0XqXqXqX9XwXyX..  &.iXqX0XqXqXqXqX0X^.wXqXqXqXqXqX8XfXA.  j -XuX8XqXqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqXqX8XuX;Xh   Z.dX8XqXqXqXqXqXqX^.qXqXqXqXqXqXqXqXqXqX",
"qX0XtX*X[.yX9XqXqXqXqX0XqXyX..  &.iXqX0XqXqX0X9X~.0X0XqXqXqXqXqX8XdXA.  j ;XuX8XqXqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqXqX8XuX;Xh   Z.dX8XqXqXqXqXqX0X0X~.9X0XqXqXqXqXqXqXqXqX",
"qX0XtX-X%XjX0X9XqXqXqXqX0XwXyX..  &.iXqX9X8XtXsX|.dXrX8XqXqXqXqXqX8XfXA.  h ;XuX8XqX0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0XqX8XuX;Xh   Z.dX8XqXqXqXqX0X8XrXdX|.sXtX8X0XqXqXqXqXqXqX",
"qX0XuXOXs.|.qXfX0X0XqXqXqX9XwXyX..  &.uXyXgX:XE.t.!.>XhXeX9XqXqXqXqX8XdXA.  j ;XuX8X0XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX0X8XuX;Xh   Z.dX8XqXqXqXqX9XeXhX:XE.t.W.:XhXrX9XqXqXqXqXqX",
"qX0XtX-X1.%.{ B.pXwX0XqXqXqX0XwXyX..  =.>X4.{ <.8.=.| 7.4XuX9XqXqXqXqX8XdXA.  h ;XuX7XuX].;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.uX7XuX;Xh   Z.dX8XqXqXqXqX9XuX3X5. .6.9.;.} 5.2XiX9XqXqXqXqX",
"qXqXeX2XOXpX.X+.>.tXqXqXqXqXqX9XwXtXo.  c v.8X>X[.iX>Xd.! $XuX9XqXqXqXqX8XdXA.  j -XyXrX[.;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-X[.rXyX;Xh   Z.dX8XqXqXqXqX9XuX@XW k.-X/.).eX3Xg.W OXiX9XqXqXqX",
"qX9XaX`.  6.lXdX<.6.dX9XqXqXqXqX9XuX-Xk (.cX[.= % >XuXkXU.! 5XeXqXqXqXqXqX8XdXA.  j =XfX`.;XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX;X`.fX-Xh   Z.dX8XqXqXqXqX0XeX3XW R.kX^ + % b 5XxXE.W 2XrX0XqXqX",
"qXqX8XhX8.4 >XrXuX' (.aX0XqXqXqX8XfX2.m.jX0X/ z g >XeX6XlXa.8.hX8XqXqXqXqXqX8XfXA.  g 2X.X=XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX*XXX2Xg   Z.dX8XqXqXqXqXqX8XhX6.s.VXJ.o `.-X% x.iXjXj.4.hX8XqXqX",
"qXqX9XdXH.q XXrXfXC.6.aX0XqXqX0XtX=X| 1XeX9X0XM.q <XrX9XtX;X| <XrX0XqXqXqXqXqX8XdXA.  c W.3XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX<XT.c   Z.dX8XqXqXqXqXqX0XrX>X .;XlXB.; 8X9Xj 0.fXwX<X| ;XtX0XqX",
"qX0XtX-X=.p XXyXwX*X} rXqXqXqX9XfXY.>.dX9X8XlXc.q <XrX0X9XaX&.^.sX0XqXqXqXqXqXqX9XfXA.  w ,XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX&X< X Z.fX9XqXqXqXqXqXqX0XdX!.=.iXdXN.0 w.#.b 0.fX7XsX;.E.dX9XqX",
"qX0XtX:X:.p XXyX0X8XT ^.^.^.^.~. Xe.1.lX7X8XfXv.q <XrX0X7XlX=.a.|.~.^.^.^.^.^.^.^.!.}.g.4 C.'.~.^.^.^.^.^.^.^.^.^.^.^.^.^.^.~.'.V.6 h.{.!.^.^.^.^.^.^.^.~.|.u.;.hXsXN.0 y.-.b 0.fX5XlX>.J.gX9XqX",
"qXqX8XjXU.8 oXyXwX*X} rX0XqXqX9XdXY.:.dX9X8XgXv.q <XrX0X9XaX*.^.sX9XqXqXqXqXqXqXqXqX9XuXdXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXdXuX9XqXqXqXqXqXqXqXqX9XsXQ.=.iXfXB.= pXgXf 0.fX7XsX;.E.dX9XqX",
"qXqXqXtX~ e 8X9XfXZ.6.aX0XqXqX0XtX=X .2XeX8XgXc.9 ,XrX9XtX:X .,XrX0XqXqXqXqXqXqXqXqXqX9X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X9XqXqXqXqXqXqXqXqXqX0XtX:X| ;XfX(.# s.S.. G.aXwX<X .;XtX0XqX",
"qX9XsX(., D.iX9XpX[ ^.aX0XqXqXqX8XgX<.x.lX4XfXm.i <XeX6XlXd.7.hX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX4.h.kXwX7.- - O.qX7XkXl.2.gX8XqXqX",
"qXqXwX8X4XuXuXhX2.5.dX9XqXqXqXqX0XrX,XR ^.kXrX6X,X9XrXlXT.! 4XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX2XW E.zXaX2X>XtXtXkX!.W 1XrX0XqXqX",
"qXqX0XtXxXeXoX#.;.tXqXqXqXqXqXqXqX9XiX XR z.1XdXcXsX,Xg.Q @XuX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XiXOXE h.>XfXvXaX<Xl.W oXiX9XqXqXqX",
"qX0XyX%X&.*.[ M.iXwX0XqXqXqXqXqXqXqX9XiX<X1.| ;.:.;.} 5.3XuX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XiX2X4.} -.:.;.| 2.1XiX9XqXqXqXqX",
"qX0XrX<XH._.qXfX0X0XqXqXqXqXqXqXqXqXqX9XrXgX-XR.J.E.:XhXeX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XrXhX:XE.J.E.;XgXrX9XqXqXqXqXqX",
"qXqX0XrXhXaXqX9XqXqXqXqXqXqXqXqXqXqXqXqX0X8XtXdXgXdXtX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X8XtXdXgXdXtX8X0XqXqXqXqXqXqX",
"qXqXqXqX9X0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X9X9X9X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X9X9X9X0XqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqX9X9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9X0XqXqXqXqXqX7X0XqXqXqX9X0X0X0X0X0X0X0X0X0X0X0X8X8X0X0X0X0X0X0X0X0X0X0X0X9X9XqXqXqXqX8X9XqXqXqXqX9XqXqXqXqX",
"qXqX0XaXpXtXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXtXsXiX0XqX0X0XeXlXuX0XqX0XdXuXyXyXyXyXyXyXyXyXyXtXfXhXtXyXyXyXyXyXyXyXyXyXtXaXiX0XqXqX0XkXdX0XqXqX0XsXeXqXqXqX",
"qX9XaXG.T. X[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.].oXA./.pX9XyXrX;X;._.iX8XyXM.(.}.[.[.[.[.[.[.[.].OXh.t.OX].[.[.[.[.[.[.[.[.XXF.W.aX9XqXuX5.c.iX0X0XuXZ.1XrXqXqX",
"qX9XpXT.OX4X<X<X<X<X<X<X<X<X<X<X<X<X<X<X2X*X~.4X,X<X<X<X<X<X<X<X>XtXk.e.hX0XOX5XzXK / gX8XqX' $X3X<X<X<X<X<X<X<X<X4X}.A.6X,X<X<X<X<X<X<X<X>XrXM.5.hX6XjXq., .XaX9X0XtX{ =XtXqXqX",
"qX0XtX X4XyXeXrXrXrXrXrXrXrXrXrXrXrXrXeXyX5X{.iXeXrXrXrXrXrXrXrXwXaX.X-.eXfX/ Y *Xk &.dXyX[.>.iXeXrXrXrXrXrXrXrXrXtXqX XuXeXrXrXrXrXrXrXrXeXpX$X*.0XpXH.  g.&X*XqXuXOX-.wXqXqXqX",
"qX0XyX[.<XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X].tX0XqXqXqXqXqXqXqXqX9XuX=.).zX).z 2 H ;XqXlXw.Z.dX9XqXqXqXqXqXqXqXqXwX4X`.tX0XqXqXqXqXqXqXqXqX9XpX,.R.BX| & g < t.yXkX0.b.gX9XqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X].yX0XqXqXqXqXqXqXqXqX7XhXE.k %XbXaX4XuXdXlXh.M uXwX0XqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqXqXqXqX8XfX_.g oXkXqX3X4XtXzXM.+.tXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X].yX0XqXqXqXqXqXqXqX8XiX:Xh : ] k.#XtX7X(.8.H   %.aXqX0XqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqXqXqX8XuX2Xb = _ j.#XtXqX[.5.$.5XrX0XqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X].yX0XqXqXqXqXqXqX8XuX>Xa = }.5Xp.*.] ..,.D.dXe.  &.aXqX0XqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqXqX8XyX3Xz @ ).8Xd.=.[  .>.Z.yXrX0XqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X].yX0XqXqXqXqXqX8XuX>Xa ; [.aXwXdXiX_.=XaXsX0XfXr.  &.aXqX0XqXqXqXqXqXwX5X'.tX0XqXqXqXqXqX8XyX3Xz $ /.sXwXdXiX].%XaXdXqX0XqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X].yX0XqXqXqXqX8XuX>Xa ; [.sX8X0X8XyX X,XeX9X0X9XfXr.  &.aXqX0XqXqXqXqXwX5X'.tX0XqXqXqXqX8XyX3Xz $ /.dX8X0X8XyXXX;XrX8XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X].yX0XqXqXqX8XuX>Xa ; [.sX8XqXqX0XyX}.>XrXqXqX0X9XfXr.  &.aXqX0XqXqXqXwX5X'.tX0XqXqXqX8XyX3Xl $ /.dX8XqXqX0XyX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX3X].yX0XqXqX8XuX>Xa ; [.sX8XqXqXqX0XyX}.>XrXqXqXqX0X9XfXr.  &.aXqX0XqXqXwX5X'.tX0XqXqX8XyX3Xl $ /.dX8XqXqXqX0XyX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqXqXqXqX9XwX3X].tX8X0X8XuX>Xa ; [.sX8XqXqXqX0X8XyX}.>XeX9XqXqXqX0X9XfXr.  &.aXqX0XqXwX5X'.tX0XqX8XyX3Xz $ /.dX8XqXqXqX0X8XyX.X-XrX9XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqXqXqX9XaXdX3X`.pXdXeXuX>Xa ; [.sX8XqXqXqX9XeXdXsX[.>XfXsX0X0XqXqX0X9XfXr.  &.aXqX0XeX5X'.tX0X8XyX3Xz $ /.dX8XqXqXqX9XeXdXsX|.-XfXsX0X0XqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqX0XqXsX!.5.$.{ *.s.1X1Xi ; [.sX8XqXqXqX9XiX5Xj.>. .X.2.I.pXwX0XqXqX0X9XfXr.  &.aXqXqX5X`.tX8XyX3Xl $ /.dX8XqXqXqX9XiX8Xz.>.....1.J.iXeX0XqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqXqXqXuX9.$.^..X-X-Xk...e 3 '.sX8XqXqXqX9XpX}.' z.|.OX2X).=.<.wXwX0XqXqX0X9XfXr.  &.aXwX4X'.wXtX3Xz $ /.dX8XqXqXqX9XiXOX] f.{.oX2X'.>.-.9XeX0XqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqX9XsX9.7.jX-.> 3 l.MX-Xj n.lX7XqXqXqX0XyX$X^ +X+Xs , B 6XxXs.:.pX0XqXqXqX0X9XfXr.  &.dX5X(.aX2Xz $ /.dX8XqXqXqX0XtX;X/ {.,Xz , c ;XvXl.%.yX0XqXqXqX",
"qX0XyX[.<XeXqXqXqXqXqXqXqXqX9XaX!.@.lX@Xc _.h.7 4XgXXX$.eX0XqXqXqX9XaX*.I.BX..( 5Xy 5.dXhX,.F.dX9XqXqXqX0X9XfXr.  *.wX X6Xl $ /.dX8XqXqXqXqX9XdX,.S.SXT Z rXh +.sXjX5.N.gX9XqXqX",
"qX0XyX[.2XyXeXeXeXeXeXeXeXeXwXdX6.R.dX5X9XtX:.M tX8XaX,.^.dXqXeXwXaXXX=.yX0X1X8XvXN ,.fXuX].:.iXeXeXeXeXeXwXqXhXy.  $.~.x $ ).gX0XeXeXeXeXwXiX$X%.0XkXV ;.CX} / aXyXXX*.eXqXqXqX",
"qX0XyX[.*X5X3X3X3X3X3X3X3X3X3X4Xo.1XeX7XhX2.  l.hX6XfXn.s.iX<X3X<XyXm.a.gX9X0XhXC.* |.iX9X0XO.=X5X3X3X3X3X3X2X1XtX5.  6 4 I.eX<X3X3X3X3X3X1XtXS.e.sXgXG ` } U ' sX8XrX#.;XtXqXqX",
"qX0XyX[.~.{.].].].].].].].].].'.` 9XqXeXaX0X6.k 4XqXfXZ.>.%X_.].`.$X0.g.jX6XiX.X% u.fX8X9XuX} E.}.].].].].].].'._.$Xi.  E $X`.'.].].].].].`.#Xu.y.gXgXD X.A.^ _ sX7XaX+.*XyXqXqX",
"qX0XyX[.4XiXtXyXyXyXyXyXyXyXtXaX=.+XdX[.<.bX&X4 [.yXaXf.C.zXeXyXeXkXT.q.aXqX7Xj :.DXyX9XeX,X&.qXuXtXyXyXyXyXyXyXtXeXjX$.  =.hXtXrXyXyXyXyXrXjX/.6.uXjXC @.UXQ ) fX0X4X%.1XrXqXqX",
"qX0XyX[.,XeX0X0X0X0X0X0X0X0X8XdXs.j.cXoX6 Z d D eX9XtXX.$XrX9X0X9XwX1X| 1XhX]   _ E G.rXfXS.7.sX8X0X0X0X0X0X0X0X0XqX1XOXy.  %.pX0X9X0X0X0X9XqX6X..:XhXg.: Y - C.iXdXU.2.sX9XqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqX0XeX1X..;XxX|.*.4.;XrXxXs.w.fX9XqXqXqX8XdXv.e.MXN.;.*...U.hX8X..%XtX0XqXqXqXqXqXqXqXqXeX5X_.kXe.  &.aXqX0XqXqXqX9XfXn.,.kXyXm.X.S.eXiX0X[ |.iX9XqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqX8XuX1Xe j .XjXAXAXgXrXs.@.qXwX0XqXqX0X9XgXs.  q.fXCXSXDXzX&XS > +XpX8XqXqXqXqXqXqXqXqXwX5X`.eXdXr.  &.aXqX0XqXqXqX0XiX4.2.8XnXFXnXsX&X{ C.dX9XqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqX8XuX>Xi 3 n.$.:.x.B.d.X.w.qXrX0XqXqXqX9XfXd.  ..h.[ t.N.v.1.O.B.p 1 oXaX8XqXqXqXqXqXqXqXwX5X'.rX8XfXr.  &.aXqX0XqXqXqXwXuXj.} t.M.m.7.| Y.dX9XqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqX8XuX>Xa ; '.lXeX/.s.:.C.$XfXwX0XqXqXqX9XfXf.   .iXgX=XD.<.y.W.0XlX%Xw 3 oXaX8XqXqXqXqXqXqXwX5X'.tX9X9XfXr.  &.aXqX0XqXqX0X0XfX>XG.2.e.R.0XsX9XqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqX8XuX>Xa ; [.sX7X0XdXiX%XzXrX9X0XqXqX0X9XfXf.   .iXqX8XeXzX-XeXgXqX7XpX*Xw 3 oXaX8XqXqXqXqXqXwX5X'.tX0X0X9XfXr.  &.aXqX0XqXqXqX9XwXzX:X0XhXqX9XqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqX8XuX>Xa ; [.sX8XqXqXqX<X_.eX9XqXqXqXqX9XgXf.   .iXqX0XqX9XrX].-XwX0XqX8XiX*Xw 3 oXaX8XqXqXqXqXwX5X'.tX0XqX0X9XfXr.  &.aXqX0XqXqXqX9XrX{.&XeX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqX8XuX>Xa ; [.sX8XqXqXqXeX3X].yX0XqXqXqX9XfXf.   .iXwX0XqXqX0XyX}.>XrXqXqXqX8XiX*Xw 3 oXaX8XqXqXqXwX5X'.tX0XqXqX0X9XfXr.  &.aXqX0XqXqX0XyX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX].>XwXqXqX8XuX>Xa ; [.sX8XqXqXqXqXwX<X`.eX9XqX0X9XfXf.   .iXqX0XqXqXqX0XyX}.>XrXqXqXqXqX8XpX*Xw 3 oXaX8XqXqXqX3X).eX9XqXqXqX0X9XfXr.  &.aXqX0XqX9XrX}.*XeX0XqXqXqXqXqXqXqX",
"qX0XtXoXtXaX9X7XiX>Xa ; [.sX8XqXqXqX0X9XaXyX$XkXwX8X9XfXf.   .iXqX9XqXqXqXqX0XyX}.>XrXqXqXqXqXqX8XiX*Xw 3 oXaX7X9XiXpX#XkXeX9XqXqXqX0X9XfXr.  &.aXqX8XqXkX;X9XfX9X0XqXqXqXqXqXqX",
"qX9XsXC.h..XuXhX:Xa ; [.sX8XqXqXqX9XyXaXXXv.7.T.1XdXgXd.   .iXwX0XqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqX8XiX*Xw 3 XXhXpXoXn.5.I.,XfXqX0XqXqX0X9XfXr.  &.aXfX7X!.q.j.[.yXpX9XqXqXqXqXqX",
"qX0XyX Xh.=.-.E.h = [.sX8XqXqXqX9XpX$X*.%.b.B.0.| v.s.   .iXqX0XqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqX8XpX*X0 7 U.<.-.V.S.y. .s.rXeX0XqXqX0X9XfXr.  -.D.} 9.A.k.>.+.'.sX9XqXqXqXqX",
"qX9XsXD.K.gX_.k : }.aX8XqXqXqX9XiX}./ Y.zXb.m.jX4Xr.  ..iXqX0XqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqX8XiX-Xw 0 (.+X>.8.4XwXq.*.eXwXqXqXqX0X9XfXt.  $.6X7X4.%XgX]._ U.sX9XqXqXqX",
"qX8XgXj.  Q.bX$X] 5XwX0XqXqX0XeX5X' {.vX9.  M yXqXxXw.h.gX8XqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqX0XeX| |.tXq V j N uXzXy.r.fX9XqXqXqX8XdXJ.&.zX,Xb   b.aXaX<X_ #XuX0XqXqX",
"qXqX8XxXV 1.aXhXz.p.dX8X0X0X8XdXk.d.lX7Xc.[ P iX9XqXqX| -XeX9X0X0X0X0X0X0X0X9XtX}.:XeX9X0X0X0X0X0X0X0X8XsXn.r.vX+Xe.fX X6 @XtXtX..#XrX9X0X9X0X9X..*XdX{.i.z n.dX5XjXF.6.fX9XqXqX",
"qX0XrX-X1 V.sXeX$X*.iXyXyXyXyXsX;.oXyX7XBX0.Z pX0X8XdXp.D.xXrXyXyXyXyXyXyXyXtXdX.X2XaXyXyXyXyXyXyXyXyXtXgX,.[.uXwXuXlXq.t wX9XdXj.M.xXrXyXtXjX`.4.pX8XtXfXg b.fX8XeX2X%.3XeXqXqX",
"qX7XcXO.b uXqX0XeX[ `. X}.}.}.{.' 8XqX8XhX4.A pX0X8XgXZ.<.-X].}.}.}.}.}.}.}.}..XR.). X}.}.}.}.}.}.}.}.{.XX` 3XeX8XiX'.$ b.dX7XdXK.=.-X].}.[.&Xa.y.jX8XqX9Xf b.fX9X9XpX+.*XyXqXqX",
"qX9XdXx.OXdX9XqX7XX.=X,X>X>X>X>X..3XwX8XkX5.S pX0X9XfXM.y.eX-X>X>X>X>X>X>X>X:X2X).+X<X:X>X>X>X>X>X>X>X:X3X..:XwXyX3Xe -.cX9X9XdXD.9.eX-X>X;X0XB.e.gX8XwXwXg b.fX9X0XtX#.-XtXqXqX",
"qXqXwX2X+X1X0XpX).,.aXeXrXrXeXfX3.!.aX6XkX3.C pX0X8XdX5.Q.gXwXrXrXrXrXrXrXrXeXaX X<XiXrXrXrXrXrXrXrXrXeXgX9.I.dXqXS h ;X$X9X9XdX9.P.hXwXrXeXsX+X=.rX0XwXwXs v.fX8XyX#X*.qXwXqXqX",
"qX7XkX8.+ m.uXjX8.D.sX9XqXqX9XsXI.-.jX6XgX9.L iX6XaX+X .wXqX0XqXqXqXqXqXqXqX9XyX}.:XrX0XqXqXqXqXqXqXqX9XaX!.@.cX].* q 9 b =XaX>XX.5XwX0XqX0X9XaX*.R.hX7XqXv M.sX5XzXt.z.gX9XqXqX",
"qXqXwX2X=XeXxXh.G sX0X0XqXqXqX0XaX,.s.kXaX6X2XrXhX4X' !.aX9XqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqX9XsX6.r.gXwX:X=X1XfXeXJ j.zX7XqXqXqX0XuX@X( @XlXrX1X7XiXzXD...wXqXqXqXqX",
"qXqX0XiXyX{.w.N   0.dX9X0XqXqX0XwXwX;.,.].qXaX,XD.' H.sX9XqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXwXrX1.-.[.wXdX4XH.+.3 q .XaX8XqXqXqX9XaX_._ b.=XpXrXXXw.o.1XtX0XqXqXqX",
"qX9XdXm.` :.C.iX=.  q.dX9X0XqXqX0XwXpXF.:.O.{ %.8.+XsX9XqXqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqX0XwXaXK.:.O.{ $.5.+X-X0 3 oXaX8XqXqXqX9XpX,Xy.*.} X.-.b.eXtX0XqXqXqXqX",
"qX0XuX(.$XiXdXqXsX=.  q.dX9X0XqXqX0X0XdXiX=XE.qXsXuX9XqXqXqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqX0X0XdXiX:XR.0XsXyXiX*Xw 3 oXaX8XqXqXqX9XtXdXrX/.oXuXfXqX0XqXqXqXqXqX",
"qX0XyX}.3XeX9X0X0XsX=.  q.fX9X0XqXqXqX9XeX5X}.uX8X0XqXqXqXqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqX9XwX7X[.yX8X0X8XiX*Xw 3 oXaX8XqXqXqX0X8XuXoX>XtX8XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqX0X0XsX=.  q.fX9X0XqXqXqXeX3X].tX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X`.tX0XqXqX8XiX*Xw 3 oXaX8XqXqXqX0XyX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqX0X0XsX=.  q.dX9X0XqXqXeX3X].yX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqX8XpX*Xw 3 oXaX8XqXqX0XyX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqX0X0XsX=.  q.fX9X0XqXeX3X].yX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqX8XiX*Xw 3 oXaX8XqX0XyX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqX0X0XsX=.  q.fX9X0XeX3X].yX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqX8XiX*Xw 3 oXaX8X0XyX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqX0X0XsX=.  q.dX9XwX3X].yX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqXqX8XiX*Xw 3 oXaX7XuX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqX0X0XsX=.  q.dXqX2X].yX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqXqXqX8XpX*Xw 3 oXpXeX.X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqX0X0XsX=.  q.hX1X'.yX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqXqXqXqX8XiX*Xw 3 XXhX{.-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqXqXqXqXqXqXqX0X0XsX=.  e.rX`.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX}.>XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X`.tX0XqXqXqXqXqXqXqXqXqX8XiX*Xw 1 $X$X&XtX0XqXqXqXqXqXqXqX",
"qX0XyX{.1XrXwXwXwXwXwXwXwXwXwXeXqXwXdX;.  5.$XeXqXeXwXwXwXwXwXwXwXwXwXwXwXwXqXiX|.,XyXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX6X'.yXwXwXwXwXwXwXwXwXwXwXeX9XaX=Xe 7 K.3XeXqXqXqXqXqXqXqXqX",
"qX0XyX].1XwX3X5X5X5X5X5X5X5X5X5X5X4X4XtX$.  u.jX1X5X5X5X5X5X5X5X5X5X5X5X5X5X4X0X].*X8X5X5X5X5X5X5X5X5X5X5X5X5X5X5X6X<X).9X4X5X5X5X5X5X5X5X5X5X5X5X2XeXXXi 7 -XyX0XqXqXqXqXqXqXqX",
"qX7XxX#.< T. X).'.`.'.'.'.'.'.'.`.'.`._.#X:.  @.oX_.`.'.'.'.'.'.'.'.'.'.'.'.`.[.Y.^.].`.'.'.'.'.'.'.'.'.'.'.'.'.`.'.).I.].`.'.'.'.'.'.'.'.'.'.'.'.'./.&X6.  (.sX9XqXqXqXqXqXqXqX",
"qX9XsXD.# g <XsXwXtXtXtXtXtXtXtXtXtXtXrXrXgX/   r.jXeXrXtXtXtXtXtXtXtXtXtXtXrXaX X1XiXrXtXtXtXtXtXtXtXtXtXtXtXtXtXyX9X].pXrXtXtXtXtXtXtXtXtXtXtXtXwXkXS.. J 4XeX0XqXqXqXqXqXqXqX",
"qX0XrX+X~., u ;XuX7X0X0X0X0X0X0X0X0X0X0XwX<XoX,.  0.dX8X9X0X0X0X0X0X0X0X0X0X9XtX}.:XeX0X0X0X0X0X0X0X0X0X0X0X0X0X0XwX4X`.rX9X0X0X0X0X0X0X0X0X0X0X7XdXC.  Q .X:XrXqXqXqXqXqXqXqXqX",
"qX0XyX`.0X.X: p ;XiX8XqXqXqXqXqXqXqXqXqXeX2X'.hX*.  q.fX9X0XqXqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqXqXqXqXqX8XfXZ.  U pXoX=XtX0XqXqXqXqXqXqXqX",
"qX0XyX{.:XfX}.> i ;XiX8XqXqXqXqXqXqXqXqXeX3X'.tXaX=.  q.fX9X0XqXqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqXqXqXqX8XgXZ.  T wXpX}.-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XqXaX}.: i ;XiX8XqXqXqXqXqXqXqXeX3X].tX9XsX=.  q.dX9X0XqXqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqXqXqX8XfXZ.  T eXwXtX.X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrX7XsX}.: p ;XiX8XqXqXqXqXqXqXeX3X].yX9X0XsX=.  q.dX9X0XqXqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqXqX8XfXZ.  T eXeX8XuX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqX8XsX}.> p ;XiX8XqXqXqXqXqXeX3X].yX0X0X0XsX=.  q.fX9X0XqXqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqXqX8XfXZ.  T eXeX9X0XyX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqX8XsX}.: i ;XiX8XqXqXqXqXeX3X].yX0XqX0X0XsX=.  q.fX9X0XqXqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqXqX8XgXZ.  T eXeX9XqX0XyX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.<XrXqXqXqX8XsX}.: i ;XiX8XqXqXqXeX3X].yX0XqXqX0X0XsX=.  q.dX9X0XqXqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqXqX8XfXZ.  T eXeX9XqXqX0XyX X-XtX0XqXqXqXqXqXqXqX",
"qX0XyX[.>XeXqXqXqXqX8XsX}.> p ;XiX8XqXqXwX1X`.rX9XqXqXqX0X0XsX=.  q.dX9X0XqX0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqXqX8XfXZ.  T eXeX9XqXqXqX9XtX}.*XeX0XqXqXqXqXqXqXqX",
"qX0XtXXXrXpX9X0XqXqXqX8XsX}.> i ;XiX8X9XiXtX#XjXqX9XqXqXqX0X0XsX=.  q.fX9X0X0XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0XqX8XfXZ.  T eXeX9XqXqXqX9X0XjX-X7XdX9X0XqXqXqXqXqXqX",
"qX9XsXS.b.$XsXyX9XqXqXqX8XsX}.: i -XfXaX$XC.r./.6XfX0XqXqXqX0X0XsX=.  q.fX9X9XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX0X8XgXZ.  T eXeX9XqXqXqX9XsXqX_.i.v.oXpXuX9XqXqXqXqXqX",
"qX0XyX].y.&.;.&XpX9XqXqXqX8XsX|.; d (.3.+.j.z.5...n.iXwX0XqXqX0X0XsX=.  q.dX8XyX}.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.tX7XfXZ.  T eXeX9XqXqXqX0XsXK...r.N.h.=.%..XsX9XqXqXqXqX",
"qX9XpXI.Q.dXL.( }.iX9XqXqXqX8XaX X1 u Y.gXD.D.gX,X<.5.uX0XqXqXqX0X0XsX=.  q.sXtX{.>XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X`.wXdXZ.  T eXeX9XqXqXqX9XsXf.O.-XF.1.W.aX~.) Q.aX9XqXqXqX",
"qX8XhXs.. !.mX{.' 4XrX0XqXqX0XqXwX] '.bXu.  m yXeXkX3.j.fX9XqXqXqX0X0XsX=.  0.lX{.:XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X).kXC.  T eXeX9XqXqXqX9XsXK.X.xXv.; P & B.nX&X_ *XyX0XqXqX",
"qXqX8XcXD =.aXjXh.f.dX8X0X0X8XdXz.p.kX7Xf.( I iX9XwX9X} >XwX9X0X0X0X9X9XaX*.  y.$X;XeX9X0X0X0X0X0X0X0X0X0X0X0X0X0XqX2X+XD.  U wXwX8X0X0X0X9X0XqXX.@XnXB +.UXQ ) pXgXZ.9.fX9XqXqX",
"qX0XeX:XH =.fXeX#X=.iXyXyXyXyXdX:..XyX7XNX0.Z pX0X8XdXi.G.zXrXyXyXyXuXtXyXjX<.  -.rXuXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXiX0.  ! pXpXtXuXyXyXyXtXjX'.3.yXjXS O.].( _ sXqX<X%.4XeXqXqX",
"qX9XpXP.c >.fX8XwX{ ].XX X X.X X] 8XqX8XhX4.A pX0X8XgXC.2.:X{. X X X X X|. X$X{   Y.@X|. X X X X X X X X X X X X X.X|.X A XXoX}..X X X X X}.-Xd.y.fXgXH ) W I ] sX7XpX+.=XtXqXqX",
"qXqX0XuXT %.gX9X8X..%X;X-X-X-X-X .4XwX8XkX5.A pX0X9XfXN.e.0X&X-X-X-X-X-X-X=X-X6X].&X;X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X'.3X>X=X-X-X-X-X-X-X*X7Xm.r.dXhXV -.kX{ / dX8XyX#.-XtXqXqX",
"qX0XeX4Xq e.dXyX].,.aXrXtXtXrXfX2./.aX6XkX4.Z pX0X8XdX7.E.hXeXtXtXtXtXtXtXtXrXeXaXyXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXaXeXrXtXtXtXtXtXtXtXeXdXoX-.wXhX! S uXh #.fXeX%X*.0XwXqXqX",
"qX7XzX:.h 1XqXkX5.Z.dX8X0X0X9XsXJ.,.kX5XhX6.F iX6XiX&X| 0XqX0X0X0X0X0X0X0X0X0X0X9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9X0XqX0X0X0X0X0X0X0X0X9XpX%.!.zX].f > x +XwXlXp.h.gX9XqXqX",
"qXqXeX,X8XsXlXM.$.yXqXqXqXqXqX0XiX=.z.lXpX2X;XeXgX0X{ Y.sX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuX.X( =XcX0X+X8XaXlXI.} 0XwXqXqXqX",
"qXqX9XaXyXoX0.+.5XrX0XqXqXqXqX0XeX8X$.5.XXyXgX4XU.[ C.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XsXQ.) C.1XhXuX$Xa.} ;XyX0XqXqXqX",
"qX9XsXZ.{ -.b.tXrX0XqXqXqXqXqXqX0XeXyXN.*.#.O.%.2.|.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaX*X9.%.O.@.&.h.0XyX9XqXqXqXqX",
"qXqXeX1X=XwXgXqX0XqXqXqXqXqXqXqXqX0X0XfXeX;X*X1XsXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XyXfX4X=X-X0XgXwX0XqXqXqXqXqX",
"qXqXqXrXtXqX9XqXqXqXqXqXqXqXqXqXqXqXqX9XqXtXyXrX9X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X9XeXtXtXwX9XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XqXqXqX0X9XqXqX0X0X0X0X0X0X0X0X0X9X0X0X0X0X0X0X0X0X9XqXqXqX9X0XqXqX0XqXqXqXqX",
"qXqX0XtXuXrXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXrXpXwXqX9XrXdXqX0XyXuXrXtXtXtXtXtXtXdXtXtXtXtXtXtXtXtXpXqXqX0XgXtX0X0XyXeXqXqXqX",
"qX0XtX@X|.*X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X$X&X).5XeXgX-XJ.0XtXoX|.*X$X$X$X$X%X$XF.+X%X$X$X$X$X$X&X).8XqXiXB.$XrXrXXX3XeXqXqX",
"qX0XuX|.OX4X<X1X1X1X1X1X1X1X<X4X|.&X3X<X1X1X1X>XwXi..X7XK.8Xv .XkXa._.7X<X1X1X1X<X3XU.*X2X<X1X1X1X,X9Xe.+XkXf.W iX9XpXp.&XyX0XqX",
"qX0XrX*X4XyXeXrXrXrXrXrXrXrXeXuX%X4XyXeXrXrXrXwXdX~.D.zX! V { yXqXd.wXrXeXrXrXrXeXuX=X7XtXeXrXrXrXwXdXU.T.iX5 D 5.iX;Xu.yX0XqXqX",
"qX0XtX$X<XeX0XqXqXqXqXqXqXqX0XrX#X2XeX0XqXqXqX9XwXiXJ L.dXOXpXuX_ g.vX6XqXqXqXqX0XrX+X4XwX0XqXqXqX9XrX0XF T.<XOX&X3X8. XiX0XqXqX",
"qX0XtX$X1XrXqXqXqXqXqXqXqXqX0XtX#X2XeXqXqXqX0X0XhX` v j.s.H.v.s.5.7 W.hX7XqXqXqX0XrX@X4XeXqXqXqX9XwXsXY C l.k.J.V.q.[.pX9XqXqXqX",
"qX0XtX$X1XrXqXqXqXqXqXqXqXqX0XtX#X2XeXqXqX0X0XhX` g 8XgX-XS./.8XbXv.> !.hX7XqXqX0XrX@X4XeXqXqX9XwXdXU m tXdX%XZ._.wXiX9XqXqXqXqX",
"qX0XtX$X1XrXqXqXqXqXqXqXqXqX0XtX#X2XeXqX0X0XhX` g 8XyX6XpX:XqXrX6XlXn.> !.hX7XqX0XrX@X4XeXqX9XwXdXI M tXrX7XpX-XeXeX9XqXqXqXqXqX",
"qX0XtX$X1XrXqXqXqXqXqXqXqXqX0XeX+X<XwX9X0XhX` g 8XyX8X0XwXoX<XqXqX7XlXn.> !.hX7X0XrX@X4XeX9XwXdXI M tXrX9X0XqX.X2XqXqXqXqXqXqXqX",
"qX0XtX$X1XrXqXqXqXqXqXqXqX0XwXhX:XwXsXqXhX` g 8XyX9X0XwXhX;XeXsX9XqX7XlXn.> !.hX6XtX+X5XqXwXdXI M tXrX9X0XeXgX=XyXpX9XqXqXqXqXqX",
"qX0XtX$X1XrXqXqXqXqXqXqX9XuX5XU.c.c._.sX_ g 8XyX9X0XiX3XU.c.v.'.pXqXqX7XlXn.> !.gX0X@X3XeXsXI M tXrX9X9XpX,XL.z.n.}.aXqXqXqXqXqX",
"qX0XtX$X1XrXqXqXqXqXqX0XuX@Xq.N.r.T.S.H b 7XyX8X0XiXXXq.M.t.Q.z.j.tXqXqX7XlXn.> Q.zX X6XfXI M tXrX9X0XpX].w.M.y.~.g.v.uX0XqXqXqX",
"qX0XtX$X<XeX0X0X0X0X0XwX6X6.<X%.^ ( kXM.c.hX6X0XwX3X7.>X} Y ] lXV.N.sX8X0X6XkXn.; ^.3XqXU m rXeX8X0XrX;X9.:X( !  .vXx.G.sX9XqXqX",
"qX0XtX$X4XuXrXtXtXtXeXhXL.K.dXXX!.G 4XdXi.<XiXwXjXG.Y.pX[.tXm :XaXy.5XuXrXtXqXvXN.4 V.Q B pXiXwXtXeXjXN.{.XXJ 3XS >XtXr.7XwXqXqX",
"qX0XtX$X|.%X#X#X#X#X+X,Xu.OXyXNX} W uXaXn.K.:XOX>Xt.$XrXmXO.$.dXpXc.U.;X@X#X#XOX4Xd.  z >X$X+X$X#X@X;Xq.6X{.H *.U -XfXj.#XyX0XqX",
"qX0XtX$X&X4X2X2X2X2X<XeXk.{.0XV.dXA `.zXx._.9X,XwXh.}.lXk.Y gX9XpXj.[.8X1X2X2X2X:XfXz.3 U.tX>X2X2X<X0Xp.1X[.H >XZ :XdXf.=XtXqXqX",
"qX0XtX$X3XyXeXeXeXeXwXaX_.B.vX' b ] yX6Xw.wXrXwXsX^.S.kXu N =.wX0Xs.wXeXeXeXeXeXeXwX2Xj.1 ^.kX9XeXwXfXU.V.kX) b *.lX&Xy.yX0XqXqX",
"qX0XtX$X<XeX0XqXqXqX9XqXsXH B.fX*XsX9Xq.).pX9X9XwXiXF C.5X*X=X0X~ s.vX6XqXqXqXqX0XrXXXsXM.: Q.hX7XqXqXrXr.W.iX-XgX<X7.oXuX0XqXqX",
"qX0XtX$X1XrXqXqXqX0X0XhX_ b c.i.Z.c.q.).aX9X0XqXfX! N v.f.A.n.d.w.6 P.jX7XqXqXqX0XrX@X1XxXn.> !.hX7XqXeX9Xh.s.A.l.w. XpX9XqXqXqX",
"qX0XtX$X1XrXqXqX0X0XhX` g 7XhX<XJ.).wXpX9X0XqXgXQ x qXgX>XH.`.qXbXC.: U.jX7XqXqX0XrX@X5X9XlXn.> !.hX7X0XwXaX:XF.{.tXiX9XqXqXqXqX",
"qX0XtX$X1XrXqX0X0XhX` g 8XyX6XiX:X9XrX9X0XqXgXQ x wXtX6XiX;X0XeX6XlXA.: U.jX7XqX0XrX@X5XeX7XlXn.> !.hX7XqX8XiX-XwXwX0XqXqXqXqXqX",
"qX0XtX$X>XwX9X0XhX` g 8XyX8X0XwXOX,XwX9XqXgXQ x wXtX9XqXrX+X2XeXqX7XkXA.: U.jX7X0XwXOX2XqXqX7XlXn.> !.hX7X0XqXXX3XqXqXqXqXqXqXqX",
"qX0XtX%X0XdXqXhX` g 8XyX9X0XwXjX;XwXsXwXfXQ x wXtX9XqX0XtX@X3XeXqXqX7XkXA.: U.jXqXgX=XrXsX0XqX7XlXn.> !.hXqXhX*XyXaX9XqXqXqXqXqX",
"qX0XuX[.g.!.pX` g 8XyX9X0XiX3XG.j.k.^.iXQ x wXtX9XqXqX0XtX@X3XeXqXqXqX7XkXA.; Y.5XH.z.x.).pXqXqX7XlXm.: !.3XZ.g.x.'.pXqXqXqXqXqX",
"qX0XuX[.J.P.J v 8XyX8X0XiXoX7.R.m.(.D.D N qXtX9XqXqXqX0XtX@X3XeXqXqXqXqX7XkXA.4 9.N.q.~.x.h.tXqXqX7XkXM.5 0.W.m.'.h.z.uX0XqXqXqX",
"qX9XsXR.G hXJ.j.gX6X0XwX4X5.8XB.-  XBXC.c.gX6XqX0X0X0X9XrX@X3XwX0X0X0X0X0XqX4X2.1X` Q ] cXB.V.sX8X0XwX1X,.iXr.2 1XvXb.S.sX9XqXqX",
"qXqXwXwXB XXlXp.-XpXwXhXK.L.hX+XE ~.uXpXp.,XiXrXtXtXtXrXiX%X6XuXrXtXtXtXeXjXV./.yX+XqXm 3XuXy.7XuXwXhXM._.fX].I OXyXqXy.7XwXqXqX",
"qX8XjXk.} dXaXV.D.:XoX>Xy.+XrXhX/ !.iXaXm.J.;X+X@X@X@X@X%X_..X$X@X@X@X@X+X;Xe.=XrXbX` 2.dXpXl.R.=XOX-Xw.:XrXuXY OXrXpXk.#XyX0XqX",
"qX0XyX.X5XeXaXv.(.qX<XrXz.{.yXiXW !.uXaXx.'.0X2X3X3X3X3X6X.X;X5X3X3X3X3X1XeXg.oXkXr.! jX8XiXf..X8X1XwXd.%XyX9XL OXrXiXf.-XtXqXqX",
"qX9XaXR./ 8XyXs.8XrXqXsX].g.jXiX_ !.kX2Xw.eXeXeXeXeXeXwXuX$X5XtXeXeXeXeXqXdXQ.n.sXt C =.uX4Xf.tXwXqXfXT.m.xX8XQ oXkX$Xu.uX0XqXqX",
"qXqXwX5X:X0X` 3.bX6XqX9XpXj.V.uXrXpX2X9.'.pX9XqXqXqXqX0XrX@X3XeXqXqXqXqXqX0XyXa.D.7X,X,X5XP j.vX6XqX0XtXu.L.iXrXpX=X6.@XuX0XqXqX",
"qX0XyX@Xk.d.j.7 x.lX7XqXqXtXN.y.b.l.e.].pX9XqXqXqXqXqX0XtX@X3XeXqXqXqXqXqX0XwXwXb.s.N.x.f.y.5 P.jX7XqXeXqXx.i.n.j.r.OXiX9XqXqXqX",
"qX0XuX}.).wXvXQ.> v.lX7XqXqXsX5XI.].tXiX9XqXqXqXqXqXqX0XtX@X3XeXqXqXqXqXqXqX0XwXaX2XL.|.eXbXC.: U.jX7X0XwXaX1XK..XuXuX9XqXqXqXqX",
"qX0XrX*X7XrX6XhX^.> v.lX7XqX8XuX;X8XeX9XqXqXqXqXqXqXqX0XtX@X3XeXqXqXqXqXqXqXqXqX8XuX-X0XwX6XlXA.: U.jX7XqX8XuX=XqXwX0XqXqXqXqXqX",
"qX0XtX$X<XeXqX7XhX^.> v.lX7X0XrX@X1XeXqXqXqXqXqXqXqXqX0XtX@X3XeXqXqXqXqXqXqXqXqX0XrX+X4XwXqX7XkXA.: U.jX7XqXeXOX5XwXqXqXqXqXqXqX",
"qX0XtX$X1XrXqXqX7XhX^.> v.lX6XtX#X2XeXqXqXqXqXqXqXqXqX0XtX@X3XeXqXqXqXqXqXqXqXqX0XrX@X4XeXqXqX7XkXA.: U.jX6XrX+X6XwXqXqXqXqXqXqX",
"qX0XtX$X1XrXqXqXqX7XhX^.> v.kXqX#X2XeXqXqXqXqXqXqXqXqX0XtX@X3XeXqXqXqXqXqXqXqXqX0XrX@X4XeXqXqXqX7XkXA.: U.hX0X+X6XwXqXqXqXqXqXqX",
"qX0XtX$X1XrXqXqXqXqX7XhX^.> v.vXOX2XeXqXqXqXqXqXqXqXqX0XtX@X3XeXqXqXqXqXqXqXqXqX0XrX@X4XeXqXqXqXqX7XkXA.: U.zX.X6XwXqXqXqXqXqXqX",
"qX0XtX#X>XeX0X0X0X0XqX6XgX~.; M.5X:XeX0X0X0X0X0X0X0X0X9XrX@X3XwX0X0X0X0X0X0X0X0X9XrX+X4XwX0X0X0X0X0X6XkXZ.- T.<X3XwXqXqXqXqXqXqX",
"qX0XrX;XrXtXrXrXrXrXrXtX0XlX(.3 t.gXwXrXrXrXrXrXrXrXrXrXiX%X6XyXrXrXrXrXrXrXrXrXrXiX$X8XyXrXrXrXrXrXrX0XcXS.4 m.rX0XqXqXqXqXqXqX",
"qX9XdXJ.u.3XoX+X@X@X@X@X@XXX<XZ.1 j.2XXX@X@X@X@X@X@X@X+X$X)..X#X+X@X@X@X@X@X@X@X+X$X)..X#X+X@X@X@X@X@X@X X8Xr.3 eXqXqXqXqXqXqXqX",
"qX9XsXT.@ a.dX1X4X5X4X4X4X5X<XdXU.+ k.sX1X4X5X4X4X4X4X4X8XXX>X6X4X4X4X4X4X4X4X4X4X8X.X,X6X4X4X4X4X4X5X2X8X4XB Q uX0XqXqXqXqXqXqX",
"qX0XwX2XW.4 j.xX9XeXeXeXeXeXwXwX1XU.2 n.xX9XeXeXeXeXeXwXyX#X5XtXwXeXeXeXeXeXeXeXwXyX#X6XrXwXeXeXeXeX0XyXtXn W -X6XwXqXqXqXqXqXqX",
"qX0XtX+XeX[., h.lX7XqXqXqXqX0XtXOXyX(.: v.lX7XqXqXqXqX0XrX@X3XeXqXqXqXqXqXqXqXqX0XrX+X4XwXqXqXqXqX9XrXrXb T hX@X5XwXqXqXqXqXqXqX",
"qX0XtX%X:XjX`., h.lX7XqXqXqX0XtX$X>XkX~.> v.lX7XqXqXqX0XtX@X3XeXqXqXqXqXqXqXqXqX0XrX@X4XeXqXqXqX9XtXrXb T dXtXoX6XwXqXqXqXqXqXqX",
"qX0XtX$X1X0XfX'.< h.lX7XqXqX0XtX#X2X9XhX^.> v.lX7XqXqX0XtX@X3XeXqXqXqXqXqXqXqXqX0XrX@X4XeXqXqX9XtXrXb R dXqXeX+X6XwXqXqXqXqXqXqX",
"qX0XtX$X1XrX7XgX'., h.lX7XqX0XtX#X2XrX7XhX^.> v.lX7XqX0XtX@X3XeXqXqXqXqXqXqXqXqX0XrX@X4XeXqX9XtXrXb T dXwX9XrX+X6XwXqXqXqXqXqXqX",
"qX0XtX$X,XwXqX7XgX'.< h.lX7X9XeX@X<XqXqX7XhX^.> v.lX7X0XtX@X3XeXqXqXqXqXqXqXqXqX0XrX@X4XeX9XtXrXb R dXqX0X0XwXoX4XqXqXqXqXqXqXqX",
"qX0XtX$X8XgXqX0X7XgX'., h.lXwXhX*X0XfXqXqX7XhX^.> v.lX6XtX@X3XeXqXqXqXqXqXqXqXqX0XrX+X5X0XrXrXb T dXwX0X9XtXfX$XrXdX0XqXqXqXqXqX",
"qX0XuX{.s.P.eXrX0X7XgX'., k.3XN.h.f.U.rXeX0X7XhX^.> v.kXqX@X3XeXqXqXqXqXqXqXqXqX0XrX@X2XyXrXb R dXqX0X9XaX#XZ.z.k.W.uXwX0XqXqXqX",
"qX0XiX`.J.J.w.7XeXqX7XgX'.6 :.).l.}.Z.r.9XwXqX7XhX^.> v.vXoX3XeXqXqXqXqXqXqXqXqX0XtXoX8XtXb T dXwX0X9XaXE.y.M.3.(.m.s.rXqXqXqXqX",
"qX9XaX^.B aX^.d.pX9X0XqX7X6.tXb.& }.NXU.j.aX8XqX6XgX~.; m.5X<XwX0X0X0X0X0X0X0X0X0XwX&X7Xn T dXqX9X0XtX#Xe.1XT o.~ vXZ.B.dX9XqXqX",
"qXqXqXqXI (.xXa.*XpXqXhXF.Y.fX-X~ ~.uXpXa.:XiXeXrX0XlX(.4 0.yXrXrXrXrXrXrXrXrXrXwXpX.Xk ! hXtXeXrXwXhXb.oX XL =XG ;XuXy.5XeXqXqX",
"qX0XyX.XD ].zXB.S.-X.X;Xt.+XrXgX^ !.iXaXM.G.-XOX+X+X.X<XM.l |.#XOX+X+X+X+X+X+X+XXX1X,.G :X@XoX+X+XoX*X0.7X{.J ,.U -XgXj.#XuX0XqX",
"qXqXwX9XA ].zXc.`.eX2XuXv.].uXiXE Q.uXaXz.{.wX5X6X6X6X3XrXeX5X6X6X6X6X6X6X6X6X6X6X6X7XiX6X5X6X6X6X4XtXd.:X|.D *XV ,XsXd.;XtXqXqX",
"qX9XfXS.' hX2Xq.eXeXqXpX|.a.hXpX| ^.zX:Xe.tXwXwXwXwXwXeX0XqXeXwXwXwXwXwXwXwXwXwXwXwXwX0XwXwXwXwXwXqXsXQ.x.xX#.z 8.vX.Xp.iX0XqXqX",
"qXqXqXqXgX:X8.[.iX9XqX9XaXb.c.qXiXiX=X7. XiX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuXd.S.pXqXhXoX5.*XyX0XqXqX",
"qX0XyXoXu.y. XpX9XqXqXqXqXuXG.t.k.g.y.oXpX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXrXN.y.x.s.p.*XiX9XqXqXqX",
"qXqXeX3X&XyXiX9XqXqXqXqXqX0XsX8X#X=XyXuX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXdX4X@X;XiXyX9XqXqXqXqX",
"qXqXqXeXyX0X0XqXqXqXqXqXqXqX9XwXyXtX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XeXuXtX0X0XqXqXqXqXqX",
"qXqXqXqX0XqXqXqXqXqXqXqXqXqXqXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqX0XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0XqXqX0X0XqX0XqX0X0X0X0X0X0X0X0X0XqX0XqXqX0X0XqX0XqXqXqXqX",
"qXqXqXeXtXeXrXrXrXrXrXrXrXrXrXrXrXrXrXtXqX8XyXrXqXyXrXrXrXrXrXuXrXrXrXrXeXtXeX9XyXrX0XrXwXqXqXqX",
"qXqXeX<X&X,X:X:X:X:X:X>X:X:X>X:X:X>X:X%X0XhX*X:XqX#X>X:X:X:X:X{.:X>X:X:X,X$X,XdX%X:XyX>X5XwXqXqX",
"qX0XtX&X%X5X2X2X2X2X2X4X;X#X5X2X2X2X4XM.9XJ.+.S.qXB.0X1X2X2X4X`.,X3X2X1X9X~.).<XB ^.kXA.=XtXqXqX",
"qXqXeX,X5XtXeXeXeXeXeXtX6X>XyXwXeX0XhX/.M.U.f.0Xp.=XpXqXeXeXtX>X0XrXeXeXqXaXg.J.8.R.XXZ.yX0XqXqX",
"qX0XrX:X2XeX0XqXqXqX0XwX3X;XeX0X9XrXrX~ ,.!.!.L. .$.hX0X0X0XeX*X8XqXqX6XlXS.H F./.I.Z.7XeXqXqXqX",
"qX0XrX:X2XeXqXqXqXqXqXeX3X;XrX8XrXyXY u.vX:X~.7XkX@.O.jX0X0XeX*X8XwX7XlXA.Z 2XaX`.oXpXwX0XqXqXqX",
"qX0XrX:X2XeXqXqXqXqXqXqX5X,XwXeXyXY i.xX6XwX1XeX8XkX#.O.jX0XwX*X8X7XlXA.Z 3XuX0X5X8XqX0XqXqXqXqX",
"qX0XrX:X2XeXqXqXqXqXwXpX>XXXpXtXY i.xX7XiX7X|.0XyX8XkX#.O.jXwX*X4XzXA.Z 3XuXqXiX#X&XpXwX0XqXqXqX",
"qX0XrX:X2XeX0XqXqXqXqXP.g.v.K.E p.zX6XyX(.z.k.Z.|.yX8XkX#.o.lX$XhXS.Z 2XuXqX1XD.f.B.H.9XwXqXqXqX",
"qX0XrX>X4XtXwXeXqXpXP.I.3.;.OX8.iXqXpX'.H.u. .'.A.%XuXqXzX$.+.iXN.D 4XaX0XwXD.B...a. XA.uX0XqXqX",
"qX0XrX:X;X6X3X3X6X=XC.hX.XQ pX].!.0X6XB.3XfX,.Q.3XS.wX1X2XiX#.C ! &X0X<X0X).[.B.,.%.uXG.;XtXqXqX",
"qX0XrX:X#X>X;X;X<X|.G.9X^.} =X XL.4X-Xv.fXb.=.fX>XN.3X-X-X=XyX' / yX*X=X4XU.oXM.$.O.uXP.%XyX0XqX",
"qX0XrX>X5XyXeXrXwXpXJ.oX8.t.eXN.<XtXaX^.'.,.-.4XY.OXpXeXrXeXrX0X#.@.zXwXtX4XC.@X*.D.8Xn.wXqXqXqX",
"qX0XrX:X2XwX0X8XeXtXE 9. X XB.`.uX7XlX,.' [.`.T.U l.zX6XqX0XwX&XfX#.o.jX8XyX}.B.|.[.b.*XyX0XqXqX",
"qX0XrX:X2XeX9XrXyXY p.iXQ.L.<XuX7XzX>.[ yX}.G.&X7XK l.zX7XqXeX&X7XlX#.O.jX9XyX2XI.W.8XyX0XqXqXqX",
"qX0XrX>X2X0XrXyXY i.zXqX0X4XtX7XzX>.] fXeXtX1XyXyXqXJ z.xX6XqX*X6X9XkX#.O.jX8XrX5X9XeX0XqXqXqXqX",
"qX0XrX;X3XhXrXY i.xX6XaX4X=XsXlX>.] fXqX0X9X%XwX8XyXqXJ l.cXuX&XwXuX8XkX#.O.hXsX-X3XaX0XqXqXqXqX",
"qX0XtX%XA.(.~ u.xX6XyX].J.B.^.,.[ fXqX0XwX9X*XwXqX9XyX0XI a.(.B.G.OXyX8XkX#.@._.F.B.).yX0XqXqXqX",
"qX0XiX].z.V.>.cX6XpX~.I.<.B..X` yXeX0XwXwX0X*XeXqXwX9XaX=XX.j._ I.A.XXyX0XdX..P.o.].T.T.iX9XqXqX",
"qX0XuXoX' lXJ.,XeX5XM.jXe.i.CX!.|.tX9X9X0X8X&XqX9X9X8XyX!.+X8Xz.9.aXM.eXeXOXQ.kX .Q.xXN.2XeXqXqX",
"qX9XaX/.Y.lXD.(.2X'.D.vXL.a.cX`.H.1X%X*X*X&X}.=X*X*X%X<XN.-XeX=.$XiXn.+X1XP.!.nXi.I.zXP.$XyX0XqX",
"qX0XuXXXD.sXJ.7XeXqXn.dXR.x.BXA.$XuXqXwXeXqX=XeXwXwXqXaX/.}.g.D %X5XP.tXtX-XB.mXd.).hXm.6XwXqXqX",
"qXqXeX<X'.p.| kX8XyX Xm.#X=XL.L.uX0XqXqXqX9X*XwX0XqXqXqXwXC.L.`.{.@.u.vX5XiXT.G.*X%XB.'.iX0XqXqX",
"qX0XtX%XF.=X%.+.kX8XyX*XF.V.[.yXqXqXqXqXqX9X*XwXqXqXqXqXeXwX).A.R.#XU l.xX6XyX|.Z.S.#XuX0XqXqXqX",
"qX0XrX>X9XpXhX+.@.kX8XuXqX2XsX0XqXqXqXqXqX9X*XwXqXqXqXqXqXqXsX,XrXdX0XJ z.xX5XsX4X9XiX9XqXqXqXqX",
"qX0XrX:X1XqX0XjX+.@.jXqX1X-XwX0XqXqXqXqXqX9X*XwXqXqXqXqXqX0XqX&X7X9XyXqXJ z.zX9X;X<XwXqXqXqXqXqX",
"qX0XrX:X2XeX0X0XjX+.+.lX3X-XrX0XqXqXqXqXqX9X*XwXqXqXqXqXqXqXeX*X8XwX9XyXqXJ l.vX=X2XeXqXqXqXqXqX",
"qX0XrX:X<XeX0X0X9XjXO.#.pX=XwX0XqXqXqXqXqX9X&XwX0XqXqXqXqX0XwX*X8XqXqX8XtX0XH c.tX,XeXqXqXqXqXqX",
"qXqXeX2XrXeXeXeXwXwXlX%.| rXrXwXeXeXeXeXeXqX=XrXeXeXeXeXeXwXtX-X0XrXeXeX0XiXwXI f.wXqXqXqXqXqXqX",
"qX9XpX/.h.9X$X*X*X&X&X7X{ X.8X&X&X*X*X*X=X&X}.=X*X*X*X*X*X*X-X|.%X=X*X*X=X$X>X;Xa #XuX0XqXqXqXqX",
"qX0XyX%XB z.jX4X8X8X7X8XsX_ +.fX7X7X8X8X8X6X%X9X8X8X8X8X8X8X0X%X5X9X8X8X7X6XgX1.[ 8XwX0XqXqXqXqX",
"qXqXwX3X1XL c.xX8XwXwXeX2XqX%.@.kXqXqXwXwX0X*XeXqXwXwXwXwXqXrX=X9XeXwXqX9XzX1.[ 7X3XwXqXqXqXqXqX",
"qX0XrX-X7XwXG c.zX7XqXeX3X-XzXO.@.kX0X0XqX9X*XwXqXqXqXqXqX0XeX*X8XwX0X8XzX<._ hX>X1XeXqXqXqXqXqX",
"qX0XrX:X,XiX0XH c.zX7XeX3X=XwXjX+.@.kX0XqX0X*XwXqXqXqXqXqXqXeX*X8XqX8XzX<.` dXrX-X1XeXqXqXqXqXqX",
"qXqXrX>X8XqXtX0XH c.zXqX9X2XtX8XkX+.@.kX0X9X*XwXqXqXqXqXqXqXeX*X8X9XzX<.` fX0XrX3X7XrX0XqXqXqXqX",
"qX0XtX=X].wXwXtX0XG c.dX}.~.4XyX9XkX+.@.kX8X&XwXqXqXqXqXqXqXeX*X5XxX<.` fX0XtX8X[.].qXtX0XqXqXqX",
"qX0XuXXXb.V.>XwXtX9XI r.b.B.V.}.yX8XjXO.@.hX&XqX0X0X0X0X0X0XwX&XhX1._ dX0XtXOXn.6.M.B.:XtX0XqXqX",
"qX0XuX.X<.1XM.uX0XdXA.-X#.h.zXc.3XyXwXzX$.@.3XrXeXrXrXrXrXeXrX5X,.{ hXrXrX5XF.Z.@.0.,Xm.rXqXqXqX",
"qX0XtX-X .iXJ.}.5X.XA.vXG.f.bX).U.6X-X:XeX` 6.0X-X>X>X>X>X-X0Xt.E 9X>X-X5XT.XXN.,.%.yXP.&XyX0XqX",
"qX0XuXOX' gXF.OX8X%XV.nXV.e.NX~.Q.9X1X1X2X9X%X3X2X2X2X2X2X2X3X%X8X3X1X1X8X^.{.S. .@.sXG.-XtXqXqX",
"qX0XuXXX_.#XC.pXqXaXD..X*X}.9Xc.8XtXeXeXeXwXyXeXeXeXeXeXeXeXeXyXwXwXeXeXrXqXM.OXa.'.#XV.yX0XqXqX",
"qXqXeX3XP.C.7XeX0XwX9XA.K.E.n.=XyX0XqXqXqX0X0XqXqXqXqXqXqXqXqX0X0XqXqXqX0XtX:XB.(.Y.C.7XeXqXqXqX",
"qXqXwX4X*XuXeX0XqX0XwXuX-X$XwXyX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXeX#X*XuXeX0XqXqXqX",
"qXqXqXwXtX0XqXqXqXqXqX0XtXyXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXyXtX0XqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqX0XqXqXqXqXqXqXqXqXqXqXqXqX0XqXqXqX0XqX0XqXqXqXqX0X0XqXqXqXqX0XqXqX0XqXqXqXqXqXqX",
"qXqXqXwXrXeXeXeXeXeXeXeXeXeXeXeXeXrXwX9XwXrXqXrXeXeXeXeXtXrXeXeXeXeXrXqX0XtX0XwXwXqXqXqX",
"qXqXwX7X>X2X2X2X2X2X2X2X2X2X2X2X2X,X4XpXwX<XqX>X2X2X1X3X=X;X3X1X2X2X>X0XyX>XeX7X7XwXqXqX",
"qX0XrX>X+X3X<X<X<X<X1X>X+X1X<X,X5X`.].-Xq.d.yXF.6X,X,X4X.XoX3X,X,X6XH.qXa.>.zX~.XXuX0XqX",
"qXqXeX2X3XyXeXeXeXeXrXqX:XtXeXeXqXdXd.T.s.*Xg.+XdXqXeXtX6X3XtXeXqXaX=Xs.x.l.OXS.9XwXqXqX",
"qXqXeX2X<XeX0XqXqXqXqX8X-XwX0X7XlXm.( R.W.E.0.| uXeX9XeX1X<XeX9XqXsX@.3._.T.H.<XtX0XqXqX",
"qXqXeX2X<XeXqXqXqXqXqX7X*XwX7XzXm.! eXpX X3XvXf.' pXeXwX2X<XwXqXfX..w.cX4X.XyXrX0XqXqXqX",
"qXqXeX2X<XeXqXqXqX0XeXtX,XuXzXm.! rXrXyX2XrX9XlXg.` pXtX<X,XrXdX..e.lX9XrX1XiX9XqXqXqXqX",
"qXqXeX2X<XeXqXqX0XeX9X[.I.%Xn.~ eXtXwX#XR.(.7X0XlXg.` sX3X,XhX..e.lX0X9X].Y. XrXqXqXqXqX",
"qXqXeX2X1XrXqXqXwX8XH.9.3.L.` 9XtXrX(.d.O.F.F.5X9XzXg.[ 0XwXo.e.zX9X8XH.w.2.P.R.yX0XqXqX",
"qXqXeX2X>XqX8X7XyX~.}.*X` ,X'.$XtX*XL.8Xf.z.:XY.yX4XkXd.` %.e.hX5XyX^.`.0.@. XQ.%XtX0XqX",
"qXqXeX2X+X:X-X*X2XA.:X3X$..X.XY.8XW.(.yX-.%X8XV.<X=X%XeXt.f 0X;X%X2XD.-X>.o._.OX[.iX0XqX",
"qXqXeX2X1XtXwXwXuX@X~.V.2.,XH.1XtX8XE.S.( ;X(..XiXqXwXqXsXs.[ aXeXuX{.~.B.2.4XG.<XrXqXqX",
"qXqXeX2X<XeX0X7XzXn._ (.`.G.[.eXpX&XY A.).Q.} f.zX7X0XeX>XuXj.` pXwXeXY.Y.[.G.[.uX0XqXqX",
"qXqXeX2X,XeX7XzXm.~ 0X%XT.1XeXaX*XJ _.qXE.#XrX] f.zX7XeX1X;XvXf.` pXeXtX#XR.1XuX0XqXqXqX",
"qXqXeX2X4XqXlXm.! eXtXtX6XtXpX*XJ _.gXeX2XqXtXpX' g.zXqX5X4X0XlXg.` pXeXtX6XuX8XqXqXqXqX",
"qXqXeX1X XfXm.! rXtXtX>X_.9X&XJ _.hX7XeX=X7X0XeXpX` g.gX#X.XrX0XlXg.' yX>X_.4XuX0XqXqXqX",
"qX0XtX=XZ.s.( eXeXeX~.z.c.L.Y _.gX7X0XwX-X7XwX9XwXiX} q.w.c.H.2X9XlXg.} Z.x.F. XuX0XqXqX",
"qXqXrX:X,.#XI.aXyX X(.Z.:.hXB.qXeXeXwXtX:X9XrXeX0XsX!.!.z.<.&XH.uXyX#X~.C.:.kXB.2XeXqXqX",
"qX0XyX@Xg.hXA.oX4XS.3X=X8.kX`.R.2X=X-X:XXX*X;X-X:X%XZ.zX_.p.jXA.+X4XA.5X*X9.kX_.}.iX0XqX",
"qX0XtX&XY.pXU.4XtXW.OX<X0.bXL.+XwX7X7X9X*X4X8X7X7X9XG.:XF J.sXI.4XtXW.+X,X0.bXL.%XyX0XqX",
"qXqXeX3X/.s.9.vX9X7XC.{.#X~.L.uXqXwXqXrX;X8XeXwXqXuX@Xm.L.(.a.0.vX9X7XC.}.#X~.P.yX0XqXqX",
"qXqXrX<XY.@X .s.lX0X6XW.F.`.eXqXqXqX0XeX-X7XwXqXqX0XyX-XR.Y.@X| d.lX0X6XW.F.'.rXqXqXqXqX",
"qXqXeX1X5XdXiX' f.lX0XyX<XaX0XqXqXqXqXeX-X8XwXqXqXqX9XiX7X4XdXuX' g.lX0XyX<XaX0XqXqXqXqX",
"qXqXeX2X,XqXwXpX' f.zX4X*XqXqXqXqXqXqXeX-X8XwXqXqXqXqXwX<X,XqXeXpX' f.zX4X=XqXqXqXqXqXqX",
"qXqXeX1X,XeX9XwXpX' f.kX%XwX0XqXqXqX0XeX-X7XqXqXqXqX0XeX1X<XeX9XeXpX` g.kX&XeXqXqXqXqXqX",
"qXqXeX3X4XrXeXwXtXdX{ d.wXqXeXeXeXeXeXtX:X0XrXeXeXeXeXtX3X2XyXeXwXtXsX[ d.0X0XqXqXqXqXqX",
"qX0XtX-XXXqX>X2X<X3X0X! u.sX>X1X2X1X1X3X@X,X2X1X2X2X1X3X*X&X3X1X2X<X2XqX_ k.gX8XqXqXqXqX",
"qX0XtX=XF /.eX;X1X,X1XwX! w.iX:X<X<X<X2X+X:X1X<X<X<X<X2X&X%X2X<X<X,X,XrX] s.hX8XqXqXqXqX",
"qXqXqX9X).U oXjX0XrXwXwX2X} g.vX0XeXeXtX:X0XrXeXeXeXeXyX3X2XyXeXwXrXhXo.e.9X0XqXqXqXqXqX",
"qXqXeX,XwX+XH  XfX7XwX7X:XaX` d.zX7X0XeX-X7XqX0XqXqX0XeX1X<XeX9XqXdX .r.jX*XeXqXqXqXqXqX",
"qXqXeX2X-XgXoXJ .XfX8X8X&XeXpX' d.zX7XeX-X8XwXqXqXqXqXeX1X<XwXqXfX .r.zX4X*XqXqXqXqXqXqX",
"qXqXeX1X6XrXsXOXJ  XjXwX<XiXwXpX' d.zX9X-X8XwXqXqXqXqXeX2X,XrXdX .r.lX0XrX,XpX0XqXqXqXqX",
"qX0XrX1XE.=XeXdXoXP (..XP.{.eXeXpX' d.cX&X8XwXqXqXqXqXeX<X1XhX .r.lX0X8X].Y. XrXqXqXqXqX",
"qX0XtX&Xj.H.XXeXhX_.X.v.i.).I.tXwXaX' h.rX6XwXwXwXwXqXeX4XwXo.r.zX9X7XH.w.2.P.T.yX0XqXqX",
"qXqXeX2X-.5XD.8XrX_.;XQ.:.MXJ.$XwX0XuX' 7.tX8X9X9X9X8XqX2X/ r.jX4XyX~.'.0.@. X!.$XtX0XqX",
"qXqXeX4Xo.qXJ.oX4XZ.2X-X5.kX`.E.2X&X>X=Xg.-X-X-X-X-X=X,X[.l.7X*X*X1XD.-X>.o._.OX[.iX0XqX",
"qX0XtX*Xm.<XF.yXiX}.!.5XN.fXZ.2XtXwXqXeXgXwXeXeXeXeXeXwXtXfXqXwXqXpX{.~.V.2.4XG.<XrXqXqX",
"qXqXwX6X`.Z.<XrX9XtXY.P.{.A.{.uX9XqXqX0X9XqXqXqXqXqXqXqX0X9XqXqXqX0XtXY.Y.[.F.{.uX0XqXqX",
"qXqXwX7X.X0XtX0XqXqXuX&X{.<XuX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXyX%X{.<XuX0XqXqXqX",
"qXqXqXwXuXwX0XqXqXqX0XtXiXrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXiXrX0XqXqXqXqX",
"qXqXqXqX0XqXqXqXqXqXqX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXwXrXeXeXeXeXeXeXeXeXeXrXqXqXtXwXrXeXeXrXtXeXeXeXrXqXrXwXwXwXqX",
"wX6X,X3X2X2X2X2X1X2X2X3X;X0X0X-X7X:X3X2X<X=X3X2X3X-XeX,X8X7X7XwX",
"rX,X:X6X4X4X5X3X*X5X4X8XoX.Xh.A.oX&X6X5X1X+X6X3X8X.X.X$.@X).:XrX",
"eX3X6XrXwXeXeXqX,XrX8XlXE.2.R./.*.=XdX0XwX1XrX8XzXU.1.Y.K.].tX0X",
"eX2X4XwX0XqXqX9X>X8XhX!.%.3X+X-XoXo.;XaX6X,X8XhXT.*.6X@X&XtXqXqX",
"eX2X4XeXqX0XeXyX:XhX!.#.9XgX8X8XkX+XX.:XiX&XkXT.%.eXfX5XqXtX0XqX",
"eX2X5XeXqXeX6XS.N.Z.=.9XpX{.g.H.#XjX@Xo.*XsXY.&.eXuX{.c.H.=XtX0X",
"eX2X3XqX9XwX~.W.2.!._.fX+X~.z.c.).:XdXOX#.c.<.8XuX$XH.%.V./.3XeX",
"eX1X*X,X<X$X^.qX>.;XE.4XE.8Xj.].=X`.<X7X Xn ].0X>X(.`. .Z.@X$XyX",
"eX2X5XrX8XhXG.m.B./.{.fX;Xh.e.(.c.eXeX9XaX.X+.-XgX*XY.c.~.Q.8XwX",
"eX2X4X8XhX!.=.].~.{.tXuX<.M.}.`.t.f.jX9X5X6X@X..-XfX@X^.^.1XrX0X",
"eX2X7XlX!.#.0XdX1XgXuX:.F.cX,X8XlXy.s.jXeX,XjX+XX.=XzX3XtXtX0XqX",
"rX>X#XR.%.0XiX%X_.*X1.F.jX8X<X4X0XhXy.f.>X).:XhXOX+.XX X{.wXwXqX",
"uX+Xc.8.2XfXXXc.l.V.n.cX8XtX3X7XrXqXhXp.t.8.P.&XxX'.w.u.Y./.eX0X",
"pX{.G.-X|.1X!.*Xi.sX~.2X<X3X*X;X2X2X-X`.8Xy.:XY.8X(.8Xg.&X|.=XtX",
"yX+XoX|.*X6XE.1XF.5XT.0X4X7X;X<X6X5X1X(.B.r.6X).tX(.*XT.*X_.>XrX",
"rX<XT.=.oXlX@XY.`.Y.1XtXqXrX2X6XrXqXuX$XA.W.d.a.zX8XE./.W.].tX0X",
"rX>X:X=Xo.OXjX,X{.9XrX0X0XeX1X5XwXqX0XtX4X XtXi.a.kXwX.X*XyXqXqX",
"eX3X5XdX;XX.+XdX<XeX0XqXqXeX1X5XwXqXqXqXqX2XeXhXu.a.lX3X9XqXqXqX",
"eX2X3X0XaX:XX.+X8X9XwXqXqXeX2X5XeXqXqXwX9X>XwX9XjXu.f.eX5XwXqXqX",
"eX2XwX0X6XiX;X| ].sX6X0X9XqX<X4XqX9X9X0X8X:XqX9X8XdXi.s.eXqXqXqX",
"iX|.7.0X>X-X6XOX] `.9X-X>X<X%X=X<X>X>X,X:X@X,X>X;X2X2XE 2XeXqXqX",
"wX9Xp.t.hXqX9XpXXXO.#XfX8XrX2X6XrXwXwXeX0X,XrX0XyXeX=.I.eXqXqXqX",
"eX1XpXl.q.gX0X5X5X:X..@XsX9X1X5XwXqXqXqX9X>X0XrXeX$.W.eX2XwXqXqX",
"eX2X7XzXj.w.gXtX<XgX;XX.+XgX>X6XwXqXqXqX0X:XyXeX%.R.zX1XqXeX0XqX",
"rX,X{.7XlXj.r.;X/.%XfX;X..#XwX2XwX0XqXqX8X3XrX$.R.lX2X`.|.qXwXqX",
"uX+Xz./.9XlXh.d.g.(.OXjX>X@.`.eXeXeXeXeXeX-X-.W.zX2XH.>.M.).wXqX",
"uXOXh.+X{.<X].:Xi.iXI.1X9XXX#.-X2X<X1X,X8X3.D.tX2X'.!.O.C.XX&XtX",
"iXXXF.{.#X9XT.,XH.3XE.qX3XqX8X3X6X6X6X6X5X4XeX2XqX|.^.,.Y.'.>XrX",
"eX3XW.'.tXyX*XU.`.Y.2XtXwXqXwXeXwXwXwXwXwXeXqXwXeXqX!.E.W.{.tX0X",
"wX8X,XtXqX0XtX6X*X9XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXwXeX:X<XtXqXqX",
"qXwXrX0XqXqX0XeXyXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXrX0XqXqX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"9X4X5X5X5X5X5X5X4X3XtX3X9X2X6X3X1X5X5X2XeX5XwX8X",
"4X>X6X4X5X1X>X4X8XOXI.V.[.3X5X1X&X5X7X-XS.M.+X;X",
"5X6XrXwXeX7X2XyXyXi.D.`.t.}.gX7X3XwXfXx.n.E..XeX",
"5X4XwX0XeXwX9XyXe._.fX7XrX0.}.pX>XfXj.G.jX4XpX0X",
"5X5XeXeX0XI.W.p._.gXU.H.3XtXw.[.sXk.G.kX'.H.&XrX",
"5X1X7X8X XH.d.(.wX|.Y.k.].3X7Xe.3.L.aX%Xz.<.`.,X",
"5X>X3X5XXXT.B.|.>X#XS.G.+X:X7X5X%.[.yX XZ.r.|.=X",
"5X4XyXyXp.D.W.%XgXg.M.^.r.#XsX0X4Xw. XsX~.R. XeX",
"4X0XyXe._.pX4XgXp.R.yX1X4X8.@XaX9XtX9.|.hX,XiXqX",
"2X].i._.fX~.'.f.R.jX7X3XpX5Xt.I.Y.2XrXy.I.~.=XrX",
"*Xb.W.yXXXM.G.!.wX7X5X<X6XyX XS.g.(.7X%XB.n..X>X",
"*X}.+X<X]. X].oX=X5X,X-X3X4X XE.V.%X;X}.$X!.$X$X",
"6XR.r.rX1XQ.^.+XyXeX9X4XrXrX6XH.T.i.@XuX!.^.{.wX",
"3X6X|.0.tX6X-XyX0XqX7X2XwX0XeX9X,X2X8.%XpX#XrXwX",
"6X3XgX|.w.8X8XqXqXwX8X3XeXqXwX9X2XpX5X8.+XeX0XqX",
"3X9X8XpX{.5.4XeX7X0X6X<X0X8X9X7X<X8XrX1Xe.}.yX0X",
";Xi.5X1XwX).2.2X5X1X,X=X3X1X2X<X=X3X;XdXb.l.fX8X",
"wXT.i.uXwXyX(.e.wXuX7X4XrXwXeX0X3X0XjXT.d.6XqXqX",
"3XsX(.r.uX0XpX.X9.wXqX<XwX0XqX9X>XhXY.a.sX7XeX0X",
"3X|.fX(.a.OX`.aX Xq.8X7XwXqXwX7XyXR.a.fX-X).3XeX",
";Xn.}.dXE.f.G.}.sX}.7.-XeX9X9XrXA.a.aX1Xx.6.).5X",
"&XS.{.=X.X|.`.XX#XeX(.'.6X<X1X1XJ.2X5X|.V.4..X&X",
"4XQ.OXiX%X~.(..XtX9XuXyXqXwXwXwXaXqXeX4XY.K.].9X",
"0X<XeXqXrX<X;XwXqXqX0X0XqXqXqXqX9XqX0XeX7X:X9XeX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"9X6X7X6X6X5X0X4X9X6X4X5X9X5X6X0X",
"6X4X9X5X3XeXU.F.Q.yX:XeX#Xb.'.9X",
"7X9XrX9X8XW.).4XQ.^.sX*XG.>X5XeX",
"6X5XqX[.v.`.,XZ.5X!.Z.K.4XZ.E.wX",
"6X3X8XJ.S.7XW.m.'.fXB.I.wXh.P.8X",
"7XrXE./.3X[.P.=XJ.OXhX~./.3X<XeX",
"3XG.'.=XI.T.yX9XeXK.G.,X^.G.+XwX",
";XR.5X^.R.:X6X;X8X%Xb._.4XU.).4X",
"8XE.!.3X X8XqX4XwX4X{.J.oX-X#XwX",
"7XaX^.Q.uXwXqX5XwXeX0XeXH.+XtXqX",
":X}.dXI.L.rX3X,X5X5X>X4XeXj.<XrX",
"8XG.|.kXE.W.iX2X0X0X2XuX`.T.wXqX",
"6X5XI._.6X/.Q.qXwXwXwX`.R.3X<XeX",
"&XI.4XD.I.7XE.~.qX0X[.K.qXs.H.0X",
",X(.4XOX_.>XeX3X8X8X3XwX4XG.^.9X",
"0X8XrX7X4XeXqXeXwXwXeXqXeX9X8XwX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
