#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX9X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X3X9XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXwX2X/./././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././././.(.XX6XwXqXqXqXqXqXqX",
"qXqXqXqXqXqXwX3X].].'._._._._._._._._._._._._._._._._._._._._.`.].'.`._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._.`.`.'.`.`.`._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._.}.gXyXqXqXqXqXqXqXqX",
"qXqXqXqXqXqX0XpXFXFXMXwX7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8XsXVXvXtX8X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8X0XpXhXjXjXfXrX8X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X9XkXJXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqX0XsXUXJX8X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXZXPXxXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXrXuXgXxXvXzXjXpXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXHXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXrXaX8X}.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXhXHXZXsXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXrXuXfXxXvXlXgXuXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqX5X{.(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXZXLXlXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXiXgXxXvXlXgXuXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X(.(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXhXJXAXaXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXaXgXxXvXkXdXuXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXyXZXKXkXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXaXhXxXcXkXsXuXwX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXhXLXDXiXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXaXjXkXdXwX6XdXyXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXuXAXKXlXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXrX1X.X<XHXcXpXrXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXeXjXLXFXyXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwXwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X=X.XvXPXAXnXjXpXrXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqX0XpXAXKXzXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X1X>X:X,X5X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX3X@X:XLXIXGXnXcXcXkXaXeXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXeXlXPXFXyXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7XK.Q t 9 m e.>XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX=X#XzXPXHXsXaXkXcXvXcXkXsXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqX0XsXAXKXcXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7XW.z # 9 q ; 0 >.qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX3XOX,XKXLXvXrXwXrXpXjXvXvXxXkXsXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXeXxXPXDXuXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX<X%.$ D n.!.+.* b .X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX&X$XjXUXGXiXwXqXqXeXtXpXhXcXvXxXjXsXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqX0XdXSXKXvXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX2Xe./ B.2XsXS.d t H.9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX2X.X3XJXLXnXrXqXqXqXqXqXwXtXpXgXxXvXxXjXsXtXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXwXvXIXSXiXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XXX_.>X0XuXJ.z r S.9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX$X#XgXUXFXpXwXqXqXqXqXqXqXqXqXrXpXgXzXvXcXjXaXyXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqX0XdXSXKXvXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXrXwXwXwXa.< g ].0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX3X|.6XGXLXmXeXqXqXqXqXqXqXqXqXqXqXqXrXpXgXzXvXcXjXpXyXwXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXeXmXIXZXpXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX).P + _ 7XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X#X+XhXUXDXsXwXqXqXqXqXqXqXqXqXqXqXqXqXqXwXpXhXzXvXcXjXpXtXwXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXfXDXLXvXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX&X| & M P.qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X3X{.8XFXPXmXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXiXhXzXcXcXkXpXrXwXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXwXBXIXCXsXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX4X<.5 r p.eXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X+X XkXUXSXdXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXyXgXzXcXcXkXpXrXwXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXfXFXPXcXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8Xh.u > 1.4XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X4X[.0XDXIXnXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXtXfXxXcXcXkXaXeXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXwXCXIXCXsXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XY.k + @.$XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X+X}.xXUXAXfXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXtXdXzXvXxXkXsXuXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXwXgXGXIXzXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XXXA O / `.rXeXeXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X3X[.9XSXUXvXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXyXsXzXvXzXcXPXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXeXZXPXZXsXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX<X-.; + G &.;.=.r.XX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X+X{.bXIXSXfXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXuXaXkXnXPXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXwXgXJXIXlXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX;XH     $ = * $ l Y.9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X1X[.5XFXUXcXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXuXfXPXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXtXCXPXAXaXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4Xc.<.-.=.*.=.&.w.XX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X+X}.nXPXDXdX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXwXgXLXIXlXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXyXiXpXpXpXpXpXuXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X>X[.1XHXUXxXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXuXCXLXDXiXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX5XOX XbXPXGXsXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXwXhXIXPXzXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X;X].>XKXIXcXyXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqX0XiXVXLXFXyXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX3XoXoXcXPXHXpXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqX0XdXFXmXyX<X1X7X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX-X'.>XLXPXcXyXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXwXhXBX8X=X%X%X*X<X7XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX3X.XOXzXIXHXiXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqX0XpXVXJXcXuX<X%X#X%X=X1X8X0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX&X`.<XKXLXbXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXlXLXIXFXcXfXyX<X$X#X%X-X1X8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX3X X+XjXUXGXiXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwX0XaXVXUXGXlXkXvXcXdXeX1X$X@X%X;X2X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX%X_.4XJXLXnXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXuXiXiXuXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXwXxXLXKXbXeXyXsXjXcXcXdX0X<X$X@X&X>X2X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX3X}.oXhXUXFXaXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8X Xh.4.4.j. XqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XqXaXCXUXAXiXwXqXqXyXsXjXcXcXsX8X<X$X@X%X,X4X8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X#X_.7XGXLXmXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X{.} 4 % + 7 o.'.rXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXbXLXKXvXqXqXqXqXqXqXrXsXkXxXcXdX6X>X%X@X%X,X5X8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX4X{. XhXUXDXsXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX;Xq.X 9 _ ( 0 = 2.9XqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XsXAXUXCXiXqXqXqXqXqXqXqXwXrXsXlXxXcXsX4X-X%X#X&X,X6X8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X@X_.9XDXPXmXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX.X .p 9.1XrX$.% ! @XwXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.5XMXPXLXcXwXqXqXqXqXqXqXqXqXqXwXeXaXlXxXxXaX3X*X%X#X&X,X7X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X4X].}.lXUXSXdXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX1X~.J.$X9XwX8.3 T .XeXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.eXDXUXBXiXqXqXqXqXqXqXqXqXqXqXqXqXeXrXpXkXxXzXaX4X&X%X$X*X1X9X0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X+X_.0XSXIXnXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X8X7X9X5X#XP o @.5XwXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).).xXIXKXzXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXrXpXkXxXlXaX5X$X$X%X*X<X7XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X3X'.[.cXUXAXfXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X%.h $ S I.eXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).).NXUXMXuXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXtXpXjXxXjXiX4X%X#X%X=X<X7XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X+X_.8XDXUXvXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX1Xl   . | .XrXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).).VXLXjXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXtXaXhXxXhXuX4X&X#X%X-X1X8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X1X`.[.bXIXSXfXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7XD.3.i 0 t.7XqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).).CXMXuXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXyXaXjXcXgXrX2X&X@X%X:X2X8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X+X_.4XFXUXcXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXrXrXwXrX>X;., J `.eXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).).mXhXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXsXjXzXfXwX1X%X@X%X>X3X9XqXqXqXqXqXqXqXqXqXqXqXqXqX0X,X`.}.nXPXDXdXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX1X`.'.8XqXrXJ.k g B.rXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.sXiXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXsXkXzXfX9X<X%X@X&X,X4X8XqXqXqXqXqXqXqXqXqXqXqX5X+X_.<XHXUXxXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX{.X.] }.wXuXV.s h C.rXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.7XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXdXkXzXfX7X>X%X#X%X,X5X8XqXqXqXqXqXqXqXqX0X;X_. XbXLXGXaXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX).C % *.T.~.` - U '.eXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.6XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXrXaXlXxXfX6X:X&X#X%X,X7X9XqXqXqXqXqXqX4XOX_.>XKXIXcXyXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX>Xs.4 % i e - 0 i.qXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXrXaXlXxXfX6X-X%X$X&X,X7X9XqXqXqXqX=X).oXcXPXHXpXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX:Xg.B 8 9 Z x.,XwXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXrXpXkXzXdX6X*X%X$X&X1X8X0XqX3XXX).>XLXPXvXyXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X5X:X-X-X>X5X0XqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXrXpXjXlXsX6X%X$X%X*X<X8X=X_.+XlXIXHXiXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwXwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXwX4X{./.(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXtXpXhXjXpX7X&X$X%X=XoX`.1XKXLXbXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXwX1XQ.!.^.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXyXaXgXhXiX5X&X#XoX=XjXUXJXaXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwXuXyXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXyXsXhXdX6X*XOX9XSXSXlX6X7X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqX0XdXUXUXlXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXpX<XXX.XyXCXyX<X*X;X1X6X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqX0XuXBXzX$X6XqXqXqXqXqXqXqXqXqXqXqXqXqXwXeXtXyXyXtXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X4X{.~.%XzXBXqX1X=X#X$X;X2X7X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqX7X@X).4XwXqXqXqXqXqXqXqXqXqXqXqXwX7X#X!.U.R.].2XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X&X`._.eXKXLXVXlXqX<X=X#X$X:X4X7X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqX0X_.O.8 % > V M.<XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X{.(.&XcXPXGXZXvXvXzXwX,X*X$X$X:X5X8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXeXOX .o 5 C f * q H.eXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X*X_.).yXGXbXiXkXzXcXvXxXlXeX>X&X%X%X:X6X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXyXm.i e k.;XXXD $ <.=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X[.).=XmXZXsXwXeXrXaXzXcXvXzXkXyX,X%X%X%X:X7X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXuXu.; n #XwX5X<.> ' |.rXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X&X).).aXHXcXwXqXqXqXeXtXpXkXcXvXxXhXuX<X$X%X&X;X6XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXuXr.& V ,XqX5Xq.1 ^ [.rXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX4X[._.=XBXZXdXqXqXqXqXqXqXwXtXpXjXcXbXxXgXuX1X$X$X*X>X6XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXuXa.< z ].yX8X..= ^ ].rXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X*X(.`.dXJXxXrXqXqXqXqXqXqXqXqXwXtXpXhXxXbXcXdXyX2X%X$X=X,X5X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X9XKXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXyXZ.j : ` z.q.k O / ].rXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX2X{._.*XCXAXsXqXqXqXqXqXqXqXqXqXqXqXqXtXaXgXxXbXvXdXeX3X&X#X-X<X6XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X;XJXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXeX@X*.& . y l N & / ].rXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X*X/.[.fXJXzXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXsXhXzXvXbXfXqX2X*X$X;X2X6X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X1X.XHXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXtX`.+.Z J ,.<.2 ~ ].rXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX1X{._.*XSXDXaXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXaXhXzXvXvXgX9X1X*X$X;X2X7X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X@X}.HXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqX4X>X,X>X1X7Xe.1 ^ ].rXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X&X^.|.hXJXzXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXpXhXzXcXvXjX9X,X*X%X;X3X8X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX<X`..XHXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXrX(.t.n.3XwX5X1.> ' |.rXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX>X{.).*XFXFXiXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXeXuXhXxXcXcXlX0X>X*X&X;X5X8X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX5X#X`.;XJXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXyXl.e j G.,XOXF # <.=XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X%X/.oXhXJXxXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXeXuXhXxXcXxXkXwX:X&X&X;X5X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX:X`.{.0XLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXrX`.! o q D j * 0 G.eXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X,X}.).>XHXGXuXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXeXtXgXxXvXxXhXrX>X%X&X:X7X9XqXqXqXqXqXqXqXqXqXqXqXqX6X@X`.%XrXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqX8XE._ 4 % : N b.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X#X/.OXhXJXcXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXyXdXzXvXzXgXtX>X%X*X:X6X0XqXqXqXqXqXqXqXqXqXwX;X`.}.5XtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXwX5XXXU.G.L.).1XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X>X{.(.2XHXFXuXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXyXsXzXbXxXdXtX,X%X*X>X5XqXqXqXqXqXqXqXqX5X+X`.%X0XtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXwXrXyXuXyXtXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XOX/.@XjXKXbXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXiXdXlXbXxXsXwX<X&X*X,X5XqXqXqXqXqXqX-X'. X4XqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X<X[.(.7XHXSXpXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXiXdXkXvXxXsXqX<X&X=X<X6XqXqXqX6XoX_.%XqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XOX(.@XlXPXnXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXuXdXkXcXxXsX9X<X*X;X2X6X0X:X[. X2XqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X1X[.(.qXHXAXaXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXuXfXkXcXcXdX8X,X*X;X2X#X].&XqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7XoX).@XxXPXbXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXyXfXlXcXcXfX7X>X&XOX@X1XwXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X2X`.(.rXGXZXsXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwXrXdXlXzXlXiX,X%X<X0XqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6XoX_.#XbXIXvXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXrXuX0X$X}.<XqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X2X`.).iXHXZXdXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X[..X4XwXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6XOX_.%XNXIXcXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXeXrXeXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X;X'.;X9XqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X<X_.`.aXJXAXdXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX+Xu.R S E 0.&X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X X.X4XqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX5X+X_.%XVXPXzXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX&X*.8 * < - 9  .;XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X:X'.;X9XqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X>X_.].sXJXSXsXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXc.r 7 o.h.*.4 ; S.5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX5X.X|.6XqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.<X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX4X+X).&XAXPXzXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXo.% / +XdX=X*.A v.1XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X;X`.-X9XqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.%X2X6X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X;X_.|.sXKXFXpXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX( X *.9XwX2X+XE.oX7XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX3X|.}.7XqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X)./.+X$X=X2X7X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX4X+X(.*XDXPXzXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX( X %.+XP.B.!.>X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X-X'.*X0XqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.-X-X%X$X-X4X9X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX=X_..XaXLXGXiXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX( o Q +.< @ 6 r.1XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX1X|.}.7XqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4X9X3X-X%X%X=X3X9X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX5XoX/.-XGXLXxXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX( # 3 S T j O 8 `.9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X&X'.&X0XqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwX0X8X3X-X$X&X-X3X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX*X_.OXfXPXGXuXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX( O H I.,XI.j - h.1XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX,X{.|.6XqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqX0X8X3X;X$X&X;X4X9X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX5XXX/.<XGXLXvXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX( X O.1XyX@X' - 5.:XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X$X'.&XqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqX0X7X3X;X%X*X:X3X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X&X`.OXfXIXFXiXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX( X *.8XrX$Xo.- 1.;XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX>X{. X5XqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqX0X7X2X;X&X*X>X4X0XqXqXqXqXqXqXqXqXqXqXqXqX0X5X X(.6XGXKXbXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXX.% / @XdXXXF = u.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X+X'.&XqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqX7X1X;X&X*X<X4X0XqXqXqXqXqXqXqXqXqXqX0X&X_.OXjXUXDXpXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXx.r 7 O.h.#.< 6 R.7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX>X[..X4XqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqX7X1X-X&X*X1X5X0XqXqXqXqXqXqXqX0X6X}.(.9XFXLXnXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX&X%.6 * , * e #.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XoX`.*XqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqX8X1X-X&X=X2X6X9XqXqXqXqXqX9X&X_.OXzXUXAXaXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX+Xt.T A W t.;X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX>X[..X3XwXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X1X=X&X-X2X7X0XqXqX0X6X{._.eXFXLXbXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXeXeXeXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X.X_.-XqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X2X=X&X;X3X9X9X9X-X`.OXbXUXZXsXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X:X]..X3XwXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X9X3X-X%X-X3X6XoX`.yXFXPXvXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X|._.;X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X8X3X-X&X%XOX@XMXUXZXdXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X;X`..X4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X7X3X=X#XpXHXUXvXrXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X|._.:X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X6X6XVXSXxX9X2X8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X;X`. X5XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX5X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXfXyX2X*X&X;X1X7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX5X|._.;X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXwX6X).(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X4X<X;X%X@X%X:X2X7XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X;X).|.6XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqX8X*X(.(.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X<X-X&X#X$X:X3X7XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX3X|.`.-X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXwX1X~.^./.3XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX0X7X<X=X%X@X#X-X2X7X9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X8X*X/.{.6X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XrXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXwX5XoXoXoXwXpXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXtX8X1X1X<X<X6XrXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiX0X=X@X1XuXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXsXLXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqX0XaXPXLXVXKXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXPXPXPXIXIXIXIXIXIXIXIXIXIXDXFXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXPXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXLXZXIXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqX0XaXPXDX3XSXUXIXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXiXaXUXUXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXVX3XKXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXeXtX2X{.VXUXxXyXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuX9XXX8XUXDXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXrX>X XHXUXsX0XqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqX0X7X2XuXsXrX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX8X3X0XdXiX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX0X6X3XpXsXeXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXwX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0X0XqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqXqXqXqXqX",
"qXqXqXeXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXyXrXqXqXqXqX",
"qXqXeX2X%X*X&X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X&X&X&X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X&X&X&X&X&X&X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X&X#X:XeX0XqXqX",
"qX0XyXoXH.U.T.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.U.U.T.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.T.Y.Y.Y.Y.T.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.U._.eX0XqXqXqX",
"qXwX8XgXCXnX6X3X4X3X3X3X3X3X3X3X3X3X3X4X3X4XhXcX9X3X4X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X4X5XtXsXaXiX7X2X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X3X2XcXAX6XwXqXqX",
"qXwX6XbXUXwX9XrXeXeXeXeXeXeXeXeXeXeXeXeXwXaXUXBXwXrXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXrXyXsXcXmXbXkXtXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXuXUXBX7XwXqXqX",
"qXqXqXwX1X/.6XwXqXqXqXqXqXqXqXqXqXqXqX0X0XVXHXuX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0X0XuXlXcXcXsXwX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XrXUXBX7XwXqXqX",
"qXqX0XtXXXW.8XwXqXqXqXqXqXqXqXqXqXqXqX0XpXUXmX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXaXlXvXvXpXeX9X9XwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqX0XAXJXyXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXaXkXnXxXdXpX9X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqX0XdXIXMX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XwXaXhXiX-XaXfX9X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXwX9XSXPXrXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0X0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XrX$X.XHXAXhXuX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXwX9XjXIXnXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXuXiXpXuXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0X}.tXUXJXmXcXjXuX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXAXUXtXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX<X@.2 > Y #XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX;X@XFXUXdXpXxXbXvXkXyXqX0XqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXwX8XkXUXvXwXqXqXqXqXqXqXqXqXqXqXqXqX0XwX0X{   n A   c rX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0X|.wXUXnXwX0XwXsXxXvXbXjXtXwX0XqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqX0XrXAXIXuX0XqXqXqXqXqXqXqXqXqXqXqXqX0XuX*Xl Y 5XbXY + (.tX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX;XoXKXPXsX9XqXqXqXwXaXlXvXnXhXyXwX0XqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXwX9XjXUXcXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7X).+X0XtX;.% G.uX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0X{.eXUXmXwXqXqXqXqXqX9XwXaXjXbXnXgXuXqX0XqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqX0XtXFXKXpX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXuXrX7XiXx # *XwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX-X XPXKXfX9XqXqXqXqXqXqXwX0XwXpXhXnXbXhXiX0X0XqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqX0XkXUXvX0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X5XhXq.  [ pX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X].yXUXNX0XwXqXqXqXqXqXqXqXqXqX0XwXiXjXnXvXhXiX0X0XqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqX0XrXLXHXpX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7XfXD.+ s 1XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX&X{.PXLXfX0XqXqXqXqXqXqXqXqXqXqXqXqX0XwXuXjXnXvXkXuX0XqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqX0XzXUXnX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XiX{.8 $ '.yX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X_.aXUXVX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXtXkXvXvXkXyX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXeXIXHXiXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XtX<XC   T.zXpXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX$X|.KXIXsXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXyXkXcXbXhXpXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqX9XnXUXmX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqX&.  X. X].{.4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8X(.sXUXCX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuXjXzXMXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXtXPXLXyXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XpX X@         $ Q.tX0XqXqXqXqXqXqXqXqXqXqXqX0XrX#X.XFXUXiXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXhXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXwX8XNXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX1Xk.0.9.9.8.t.&XeX0XqXqXqXqXqXqXqXqXqXqXqXeX5X^.aXUXBXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XeXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqX0XiXKXIXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXlXcXcXvXvXcXtXqXqXqXqXqXqXqXqXqXqXqXqXqXwX+XOXDXUXiXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXwX8XNXUXbXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X7X6X6X6X6X7X0XqXqXqXqXqXqXqXqXqXqXqXqXeX5X~.yXUXmXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqX9XsXLXUXyXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXXX+XGXUXpX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXwX7XxXZX0X;X1X8XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X^.rXUXnXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXVXkX>X$XoX&X2X9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX|.oXKXPXsX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XeX8XgXUXUXNXuX3X@XOX=X2X9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX3X(.rXUXmXwXwXqXqXqXqXqXqXqXqXqXqXqXqX0X7X6X6X8XqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XqXeXVXUXmXgXmXvXuX2XOX@X-X2XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX}.|.IXKXfX9XqXqXqXqXqXqXqXqXqXqXqXqXqXwXhXvXxXpX0XqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XqXfXUXFXtXqXyXhXmXxXpX>XOX#X=X3XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X(.uXUXNX0XwXqXqXqXqXqXqXqXqXqXqXqX0XtX-X=.N J m.uX9XqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.7XrXAXUXzX9XwX0XwXtXjXnXxXpX-X+X#X*X5XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX{.[.IXLXdX0XqXqXqXqXqXqXqXqXqXqXqX0X0X7XG   8 $ O k.gX7XqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.7XjXUXSXtXqXqXqXqXqXwXtXkXvXvXrX*X@X@X-X7X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX:X~.sXUXVX9XwXqXqXqXqXqXqXqXqXqXqXqX8XpXU.> ( eX.XO L wX0X0XqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.9XJXUXzX9XwXqXqXqXqXqXqXqXyXkXvXcX0X=X@X+X>X7XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X}.{.KXIXaXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX:XW.&XxX6X4 V 9XqX0XqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXE.hXUXDXwXwXqXqXqXqXqXqXqXqXqX0XuXhXbXxX9X-XoX#X1X7XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX-XE.fXUXCX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXtXeX[.<.  7.fX8XqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXOXR.DXUXjX0XqXqXqXqXqXqXqXqXqXqXqXqX0XuXhXmXkX8X*XXX%X<X7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X{.XXFXUXiXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX1   M ,XeX9XqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXOXR.GXGXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0XqXyXhXnXgX0X%XOX&X,X9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXeX;XT.sXUXBXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XwXc.R O d.aX8XqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXOXE.GXgX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXyXkXnXgX7X#X+X&X<X0XqXqXqXqXqXqXqXqXqXqXqXwX7X`.@XDXUXiXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXiXqXxX:Xt a ;XrX9XqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXE.nXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXtXkXvXhX3X@X@X%X3X0XqXqXqXqXqXqXqXqXqXwX;XR.uXUXmXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XiX).w.;XiXtX[ < `.pX9XqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.wXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXyXlXcXfX<X$X+X%X5X0XwXqXqXqXqXqXwX7X^.#XGXUXaX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7XhXh.  :.0X|.2 k -XrX9XqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXyXkXvXaX<X$XOX=X5X9XwXqXqXqXqX%X~.eXUXnXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX;XD   > o X d.fX7XqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XrXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuXkXvXiX1X+X+X;X5XqXwXqX7X~.oXKXPXdX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XyX*X3.Y ( A.yX9XqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX9XiX+XW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuXkXxXyX<XXX#X>X4XeX@X/.rXUXmXwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXjXnXvXaX9XqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qX0XeX<X`.^.7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0XqXuXkXlXyX:XoX$X:X].|.PXKXfX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X7X5X6X8XqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qX0XyXOXU.Q.7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXuXjXlXtX=X@XoXiXUXCXqXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXwX8XzXLXBXeX0XqXqXqXqXqXqXqXqXqXqX0X9X9X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXuXkXtX$X+XFXmX8X,X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXwX7XcXUX4X6XwXqXqXqXqXqXqXqXqXqX0XiXgXgXuX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XwX+X!.>XAX3X&X@X#X<X8XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqXqXwX;X~.6XwXqXqXqXqXqXqXqXqXwXrX+XT.W.&XiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2X'./.mXUXZXgX4X=XOX$X2X8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XyXXXW.8XwXqXqXqXqXqXqXqX9XtXM.,     g R.pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX#XR.3XLXZXVXbXMXdX5X*XXX*X2X9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXOXW.8XwXqXqXqXqXqXqX9XuXXX8 4 l.i.  b wX9X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2X`._.mXSX9XiXdXzXmXmXaX8X%XoX-X2XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqX8XhXZ.  r.bXhXL 6 ].yX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X#XT.7XUXsXqX0XqXyXsXzXmXbXsX9X@X+X-X2XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqX7XjXC.  l.fX8X{ < /.iX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X^.}.MXAXeXqXqXqX0X0XrXaXxXmXvXgX6X+X#X=X5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqX8XgXH.  X.rX5Xd 4 ^.uX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X@XR.7XUXsX9XqXqXqXqXqX0XqXeXaXxXnXcXjX3X#X#X*X6XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X6XUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqX9XtX$Xc   z v 2 6 ^.iX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X!. XVXCXeXqXqXqXqXqXqXqXqXqXqXwXaXxXbXbXjX1X%X@X;X8X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XOXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqX8XdXT.M p -.{ < /.uX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXXX!.7XUXdX9XwXqXqXqXqXqXqXqXqXqXqXqXqXsXlXvXmXdX2X&XOX>X7XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX=X[.UXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXwX5X2XtXtXaX{ < /.iX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqX3X!.|.GXBXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXaXjXbXMXaX5X%X+X,X7XwXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqX'. XUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqX8XdXE.h N.xXsXV 8 |.tX9XqXqXqXqXqXqXqXqXqXqXqXqXqXwX|.^.0XUXgX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXpXjXmXmXpX6X#X$X<X8XwXqXqXqXqXqXqXqXqXqXqXqXwX*X^.3XUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqX9XiX[.: * ;.}   G iX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqX1X/.|.LXVXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXiXjXMXbXsX5X@X%X<X0XwXqXqXqXqXqXqXqXqXqX9X{.[.rXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqX9XyXU.u     K XXyX9XqXqXqXqXqXqXqXqXqXqXqXqX0XwX X!.uXIXgX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXyXjXmXcXfX3X@X&X<XqXqXqXqXqXqXqX0XrX*X^.,XtXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXwXrX4X=X;X7XyX0XqXqXqXqXqXqXqXqXqXqXqXqXqXwX:X(. XLXAX0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXtXlXnXcXgX1X$X%X2XqXqXqXqXqXqX7X[.}.9XtXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXrXuXyXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXXXW.gXIXfXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXuXlXvXbXdX<X%X%X4X0XwX0XeX*X!.<XwXrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX:X^.@XJXDX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXjXvXnXaX1X%X=X5XqX8X[. X9X0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XOXW.jXUXaXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XuXgXvXmXpX2X@X-X;X_.:XrX9XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX,XW.=XHXSXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXuXfXnXbXsX7X@X$X8XwX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8X.X~.hXUXpXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXtXdXpX;X#X0XqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX1XR.:XPXVXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXrXtXtXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqX3X^.-XrX0XqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX9X{.`.jXUXsX9XqXqXqXqXqXqXqXqXqXqXqXqXwXrX4X<X2XeXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX%X[.qX0XqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX<XW.;XUXNXeXqXqXqXqXqXqXqXqXqXqXqXqX0XrXa.1   % ,.7XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X`.-XeXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X'.'.cXUXfX9XwXqXqXqXqXqXqXqXqXqXqX9XuXG.  u >.C   9.pX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX#X[.qXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.4XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX-X^.;XUXNXwXwXqXqXqXqXqXqXqXqXqXqXqX7XhX)   ~.MX$XZ -.7XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X_.;XwXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXQ.$X<X7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0X'._.NXIXhX9XwXqXqXqXqXqXqXqXqXqXqXqX7XjXT   1XaXwX0X:X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXOX].0XqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXQ.&X@X%X,X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX*X/.<XUXCXqXwXqXqXqXqXqXqXqXqXqXqXqXqX7XjXT X L.A g 8.9XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX3X_.:XwXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.7X7X=X#X&X<X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X[./.ZXIXgX0XqXqXqXqXqXqXqXqXqXqXqXqXqX7XjXE   l c &   n.sX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXOX].9XwXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XeXqX5X*X$X%X2X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX*X!.9XUXAX0XwXqXqXqXqXqXqXqXqXqXqXqXqXqX7XjXR   z.gXL.  ] 0XwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX<X/.:XeXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqX5X=X$X&X4X9XwXqXqXqXqXqXqXqXqXqXqXqXwX6X{.).ZXUXdXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7XjXT   ;XuX+Xy H 4XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXoX[.9XwXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXwXwX4X-X#X=X4XqXwXqXqXqXqXqXqXqXqX0XeX=XE.tXUXAX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7XjXQ . XXBX+X2 R 6XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXeX<X^.:XrX0XqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXwXqX4X-X#X;X4XwXwXqXqXqXqXqXqXwX6X'.|.CXUXaXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XpXg.  Y P...  q.pX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X.X}.9XwXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXwXqX4X-X#X;X4XwXqXqXqXqXqXwX=XT.tXUXCXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X}       W =XyX9XqXqXqXqXqXqXqXqXqXqXqXqXqXwX1X^.;XrX0XqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXwX0X5X=X#X;X6XwXqXqXwX6X).OXZXUXaXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX7X~.G.E.3XtX9XqXqXqXqXqXqXqXqXqXqXqXqXqXwX0X{.}.0XqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXwXqX5X=X$X>X8XqXqX=XQ.tXUXNXrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXdXjXfXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX>X/.-XeX0XqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqX5X=X%X,X8X].+XFXUXdX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X9X8X9X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX'.[.qXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX4X=X#X.XrXUXBXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX=X(.;XeXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XtXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwX<X3XLXKXpX6XeXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X].].qXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX0XrXoXW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXuXlX6X$X*X1X9XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX&X/.:XwXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qXqX9XuX+XW.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X5X2X:X@X+X*X<X9XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X[.].0XqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXBX7XwXqXqX",
"qX0XrX;X/.~.7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXeX0X6X:X+X@X&X<X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX%X!.>XwXqXqXqXqXqXqXqXqXqXqXqXqX9XrXUXBX7XwXqXqX",
"qX0XtX#XW.(.8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0X7X;X@X#X&X<X0XqXqXqXqXqXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX4X].{.9XwXqXqXqXqXqXqXqXqXqXqXqXqX0XyXUXBX7XwXqXqX",
"qXwX7XvXUXZXKXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXSXLXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXAXUXBX7XwXqXqX",
"qXwX7XlXKX&XHXUXDXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXDXDXFXFXFXFXFXFXFXFXFXDXFXZX%XUXUXSXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXDXFXMX&XUXCX6XwXqXqX",
"qXqXqX0X2X.XnXMX5X8X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8X,XoXVXvX5X8X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8X;X@XSXlX8XwXqXqX",
"qXqXqXqXeXyX7X7XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeXtX7X8XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrXtX6X8XqXqXqXqX",
"qXqXqXqXqX0XwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXwXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqX",
"qXqXqXqXqXqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X8XqXqXqXqX",
"qXqXwX8XR.T.W.!.!.!.!.!.!.!.!.!.!.!.!.!.!.E.E.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.Q.W.E.W.Q.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.W.XXqXqXqXqX",
"qXqXqXqX6X9X-X+X#X#X#X#X#X#X#X#X#X#X#X@X$X3X<X#X@X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X$X:X,X>X=X+X@X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X#X$XmXtX0XqXqX",
"qXqX0XeXUXSXwXyXtXtXtXtXtXtXtXtXtXtXyXeXkXUXxXrXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXyXdXzXBXmXlXiXrXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXyXqXmXUXeX0XqXqX",
"qXqXqXqXtX}.=XrX9X0X0X0X0X0X0X0X0X0X0XqXAXZXqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9X9XeXgXcXxXdXwX9X9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX6XnXUXwX0XqXqX",
"qXqXqXeX1XT.,XrX0XqXqXqXqXqXqXqXqXqX0XfXUXgX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XtXjXcXvXaXeX9X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XnXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqX0XGXZXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXhXbXcXfXyX8X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqX9XkXIXhX9XqXqXqXqXqXqXqXqXqXqXqXqX0X8X8X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXyXdX8X*XbXuX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXwXFXDX0XwXqXqXqXqXqXqXqXqXqXqXqX0XeXgXkXaX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XeX}.7XUXBXjXyXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXwX8XzXUXfXqXqXqXqXqXqXqXqXqXqXqXqX0XtX3XL.V./.yXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X.XCXUXnXcXnXhXyXqX0XqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqX0XrXGXDXwXqXqXqXqXqXqXqXqXqXqXqXqXwX2XK     O y.aX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXoX8XUXmX9XiXhXnXbXhXuX0X0XqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqX9XlXUXdX0XqXqXqXqXqXqXqXqXqXqXqX8XdXt.  9.*Xb ; >XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X.XCXUXyXqX0XwXyXhXbXvXjXyX0X0XqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqX0XrXPXZXeXqXqXqXqXqXqXqXqXqXqXqXqX0XuXR.j.6XbXe.; E.iX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXoX4XUXvXqXqXqXqX0XqXtXhXvXbXkXyXqX0XqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqX9XcXUXhX9XwXqXqXqXqXqXqXqXqXqXqXqXqX0XtXiX7XgX) & $XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXwX3X{.DXPXiX0XqXqXqXqXqXqX0XtXgXcXnXhXyXqX0XqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXrXPXAXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6XdXT.  ! sX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX.X6XUXnX0XqXqXqXqXqXqXqXqXqX0XyXfXvXnXhXuX0X0XqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXwX8XmXUXhX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XuX%X8 q :XrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX<X'.DXPXpX0XqXqXqXqXqXqXqXqXqXqX0X0XtXdXvXvXkXyX0XqX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXwX9XiXKXDX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX8XB   Q.yX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX}.9XUXMX9XwXqXqXqXqXqXqXqXqXqXqXqXqX0XqXeXfXcXbXkXuX7XnXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXwX9XnXUXdXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XiXX.  J.NXsXeXqXqXqXqXqXqXqXqXqXqXqXqXqXeX,X[.ZXUXuXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXfXxXmXdXBXUXeX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXwX9XpXIXAXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XaXv.  p u.8.i.;XeX0XqXqXqXqXqXqXqXqXqXqXqXwX[.8XUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XrXsXlXGXUXeX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXmXUXfX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8XhX=.+ * # . 4 [.yX0XqXqXqXqXqXqXqXqXqXqXeX>X}.ZXUXyXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqX0XNXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqX0XiXUXCXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X6X5X6X6X7X0XqXqXqXqXqXqXqXqXqXqXqXqXqX].5XUXvXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX6XnXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqX9XVXUXhX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXeXeXrXrXeXqXqXqXqXqXqXqXqXqXqXqX0XeX-X].FXPXpX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrXqX0XsXUXFXeXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X].6XUXnX0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrXqX7XMXVX0X,X9XwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX-X_.FXPXpX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XwXZXtX*X+X#X1X8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX9X).qXUXMX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XtX7XkXUXKXlX0X*XoX&X1X9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX=X].ZXUXyXqXqXqXqXqXqXqXqXqXqXqXqX0X0X0X0X0XqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XeXeXDXUXjXkXMXjXqX$XOX&X2XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0X/.8XUXnX0XqXqXqXqXqXqXqXqXqXqXqX0XrXaXsXaXyXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XeXjXUXmX0XwXyXzXbXlX7X$X+X&X4X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX#X{.AXUXuX0XqXqXqXqXqXqXqXqXqXqX9XuX|.J < d S.tX0XqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.>XyXGXPXpX0XqXqXqXuXlXnXkX4X%XoX=X5X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X).5XUXvXqXqXqXqXqXqXqXqXqXqXqX0XeX2Xp   ..a O |.uX0XqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.:XbXUXmX0XwXqXqXqXqXqXiXjXmXfX5X@X+X-X4XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX+X`.GXPXpX9XqXqXqXqXqXqXqXqXqXqX9XuXXXE l.SX!.  j.pX0XqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.1XPXKXiX0XqXqXqXqXqXqX0XwXyXlXbXdX4X+X@X-X7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.8XUXmX0XwXqXqXqXqXqXqXqXqXqXqXqXqX0X8X9XhXg.  P.pX0XqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX4XU.sXUXnX9XwXqXqXqXqXqXqXqXqX0XqXuXzXcXfX,X@X@X;X7XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX#X).FXPXpX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX6XB   ^ 0XwX0XqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX4XI.kXUXrX0XqXqXqXqXqXqXqXqXqXqXqXqX0XiXlXvXpX,X@X+X,X7XwXqXqXqXqXqXqXqXqXqXqXqXqXwX5XW.wXUXMX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0X5XU & L 5XeX0XqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX4XI.zXMX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXiXlXbXuX,XOX$X,X8XwXqXqXqXqXqXqXqXqXqXqXwXoX[.ZXUXyXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXaXqXcXN.  a.pX0XqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX4XU.sXsX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXuXzXxXuX-XOX$X<X0XqXwXqXqXqXqXqXqXwX5XQ.8XUXnXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX@Xk.,XsX<Xi ^ iXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XT.3XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXiXzXxXrX=X+X#X2X9XwXqXqXqXqXqXwX|.{.AXUXuX0XqXqXqXqXqXqXqXqXqXqXqXqXqX8XdXY.  -.qXv.  q.iX0XqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXiXzXxXwX-XoX%X3X9XwXqX0XeX<X^.5XUXbXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqX8X{   O   x :XrX0XqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXiXzXlXwX&XOX*X3XqXqXqX|.).GXLXpX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX7XC.9.h.>XtX0XqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX4XW.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXiXlXjX9X#X@X*X6X<X!.0XUXmX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXgXcXkXeX0XqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXwX9XQ.P.;XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXiXlXjX7X%X#XOX{.SXUXpX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X8X7X7X0XqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqX0X2X2X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXpXzXdX<XXXyXUXbX5XwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqX0XeXUXGXqXqXqXqXqXqXqXqXqXqX0XwXrXrXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXuX@X`.lXfX%X$X:X7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXqXuX X=XtX0XqXqXqXqXqXqXqXrXeX4X6XrXrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX>XE.%XPXMXuX:X@X#X>X9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX1XT.,XrX0XqXqXqXqXqX0XtXoXZ   @ X.2XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwX}.(.kXUXDXmXbXuX>X@X@X1X8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqX0XwX9XK o 6.O.  7.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX:X~.*XIXaXtXgXxXmXvXrX<XOX$X1X9XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqX0XuX-Xo +.MXeXa G 9XwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X|.~.mXCX0XqX0XtXsXxXMXxXuX>XOX&X<XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XnXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqX0XuX-X  ,.cX7XM B 6XeX0XqXqXqXqXqXqXqXqXqXqXqXqX0XeX:XW.,XLXdX0XwXqX0X0XeXaXxXmXxXiX-X#X%X3XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX6XnXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqX0XtX>X6 b #XI.@ G 5XeX0XqXqXqXqXqXqXqXqXqXqXqXqXwX8X}./.mXSX9XqXqXqXqXqXqXqXwXsXzXnXbXtX:X@X%X4X0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX<XkXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqX0XrX6.  . j 9 A 5XeX0XqXqXqXqXqXqXqXqXqXqXqXqXwX,XR.3XIXaXqXqXqXqXqXqXqXqXqX0XwXsXlXmXvXrX>XOX-X4XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX#XtXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqX0XtXeXV.r.^.F M 7XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqX'.'.MXAXqXqXqXqXqXqXqXqXqXqXqXqX0XeXpXkXMXzXuX-X+X-X5XwXwXqXqXqXqXqXqXqXqXqXqXqXqXwX0X/.yXUXqX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXrX3Xf.@XAXsXx A 7XeX0XqXqXqXqXqXqXqXqXqXqXqXwX=XQ.2XUXpX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXuXzXnXcXuX=X$X=X7XqXwXqXqXqXqXqXqXqXqXqXqXwX;X~.jXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqX0XtX1X2 s `.B.  @.pX0XqXqXqXqXqXqXqXqXqXqXqXqX0X].'.AXVXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXpXlXnXbXeX:X@X;X7XwXqXqXqXqXqXqXqXqXqX9X'. XNXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqX0XtXC.&     x XXiX9XqXqXqXqXqXqXqXqXqXqX0XrX=XQ.7XUXdX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXpXjXmXcXrX;X@X>X7XeXqXqXqXqXqX0XeX&X_.<XMXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXwXtXXXG.P.>XuX9XqXqXqXqXqXqXqXqXqXqXqXwX7X[.`.GXCX0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XwXyXkXMXzXyX=X$X:X9XwXqXqXqXqX8X].OX9XnXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqX0XiXhXgXrX9XqXqXqXqXqXqXqXqXqXqXqXqXwX;XR.rXIXdX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXyXlXbXxXeX=X$X,X0XwXqXeX&X/.6X8XnXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqX9X8X8X0XqXqXqXqXqXqXqXqXqXqXqXqXwX8X_.|.DXAX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXkXbXcXqX;X$X1X0X8X'.+XeX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX-XW.tXUXpXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XuXhXmXxXeX=X*X=X'.3XrX6XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X(..XGXCXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXtXhXnXlXeX#X-XqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX$X~.tXUXaX0XqXqXqXqXqXqXqXqXqXqXqX9X6X6X7XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XtXyX@X@XrXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X`..XIXBXwXqXqXqXqXqXqXqXqXqXqXqX0XiXcXbXgXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X6X_.,XeXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX%XW.fXUXdX9XwXqXqXqXqXqXqXqXqXqXqXyX~.X.` g.qXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX#X XwXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX6X_.@XLXCX0XwXqXqXqXqXqXqXqXqXqX0XyXQ.- # 5   | aX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX6X'.<XwXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.:XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX&XW.jXUXsX0XqXqXqXqXqXqXqXqXqXqX9XdXR > {.sXW i $XtX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX#X XqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX2XW.+X3X8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX7X~.*XPXZX0XqXqXqXqXqXqXqXqXqXqXqX9XfXz d bXdX0X|.2XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX5X).<XeXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX2XW.+X#X%X1XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX@X/.hXUXpXqXqXqXqXqXqXqXqXqXqXqXqX9XfXz h C.b ` %XyX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX+X XwXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.>X9X=X$X*X2XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX6X/.&XUXNXwXqXqXqXqXqXqXqXqXqXqXqXqX9XsXB O A k   L pX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X).<XeX0XqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XtXqX6X-X$X&X4XqXwXqXqXqXqXqXqXqXqXqXqXqX0XeXOX(.cXUXsX9XqXqXqXqXqXqXqXqXqXqXqXqX9XdXm 4 @XlXU 4 @XtX9XqXqXqXqXqXqXqXqXqXqXqXqXqXwX.X|.eXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XwXwX5X;X#X-X4XqXwXqXqXqXqXqXqXqXqXqXwX3X(.*XUXBXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XfXz g dXtX2.2 `.iX9XqXqXqXqXqXqXqXqXqXqXqXqXwX1X_.<XeXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXwXqX6X;X#X-X6XwXqXqXqXqXqXqXqXqXwX@X~.NXUXdX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdXG 5 >XnXI 5 $XtX9XqXqXqXqXqXqXqXqXqXqXqXqXwX.X|.wXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXwXqX6X-X%X-X7XqXwXqXqXqXqXwX4X!.2XUXCX0XwXqXqXqXqXqXqXqXqXqXqXqXqXqX0XuXS.  w n   ` sX8XqXqXqXqXqXqXqXqXqXqXqX0XeX<X(.2XwXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXwXwX5X-X$X;X7XwXqXqXqXqXOX).MXUXaXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtXB.Z c <.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqX0X X XqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXwXwX5X-X$X>X8XwXwX5X!.5XUXVXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXpXzXxXfXwXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.1XeX0XqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXwXqX5X-X&X>XqX+X].NXUXpX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X7X7X8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX]..XqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXwXqX5X-X&X X4XUXBXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX;X(.<XeX0XqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwX3X:XDXPXuX8XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X]. XeXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX3XR.,XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXjX5X#X=X3XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX*X/.1XwXqXqXqXqXqXqXqXqXqXwX7XmXUXwX0XqXqX",
"qXqXqXeX5XE.,XtXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqX7X5X,X$X#X=X3XwXeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXwX9X{. XeXwXwXwXwXwXwXwXwXwXwXeX8XmXUXwX0XqXqX",
"qXqXwX9X~.I.=XqX7X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X9X0X8X5X-X+XoX@X,X6X7X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X0X@XR.,X9X8X8X8X8X8X8X8X8X8X8X9X3XbXUXwX0XqXqX",
"qXqXqX0X:X;XuXjXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXhXsXqX9X8XeXfXgXgXgXgXgXhXjXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXdX2X3XfXgXgXgXgXgXgXgXgXgXgXgXgXdXAXUXeX0XqXqX",
"qXqX0XeXUXSXSXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXZXCXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXDXMXUXeX0XqXqX",
"qXqXqXqXsX|.fXUXiXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXpXpXpXpXpXaXaXaXpXpXdXXXiXUXpXpXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXpXpXpXpXaXaXaXaXaXaXaXaXaXpXpXfX+XeXUXqX0XqXqX",
"qXqXqXqX8X7XwXeX9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X8X7XwXeX9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X8X7XqXrXqXqXqXqX",
"qXqXqXqXqXwXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqX0XqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeXqXqXqXqX",
"qXqXqX0X5X5X6X6X6X6X6X6X6X6X6X6X5X5X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X5X5X5X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X4X0XqXqXqX",
"qXqXwX6X`.`.(.).).).).).).).).(._.).(.).).).).).).).).).).).).).).).(._.`.)./.(.).).).).).).).).).).).).).).).).).).^.#XrX0XqXqX",
"qXqX0XyXKXyX7X9X9X9X9X9X9X9X6XsXCX0X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9XeXfXlXaX0X7X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9XFXiX9XqXqX",
"qXqX0XtX2X@XtXqXwXwXwXwXwXwX0XDXzX9XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXuXlXcXdXwX0XqXwXwXwXwXwXwXwXwXwXwXwXwXwXqXrXUXyX0XqXqX",
"qXqX0XtX.XoXtX0XqXqXqXqXqX8XgXFXqXqXqXqXqXqXqXqXqXqX0X0XqXqXqXqXqXqXqXqXqX0XqXiXlXzXsXrX8X0XqXqXqXqXqXqXqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXqXqX0XFXlX8XwXqXqXqXqXqXqX0X0XtXqX0XqXqXqXqXqXqXqXqXqXqX0X0XpXyX1XzXeX0X0XqXqXqXqXqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXwX8XjXGXqXqXqXqXqXqXqXqX0XtXuX,XwXyX0XqXqXqXqXqXqXqXqXqXqXqXeX%XwXUXcXgXrX0X0XqXqXqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXqXqXGXkX9XqXqXqXqXqXqX0XeX<XL 2 c OXyX0XqXqXqXqXqXqXqXqXqXwX9X$XJXcXyXzXvXgXrX0X0XqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXwX8XzXGXqXqXqXqXqXqXqXqX9XfXN.m ;XZ  .hX9XqXqXqXqXqXqXqXqX0XrX&XyXPXqX9XqXiXlXcXgXrX0X0XqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXwXJXkX9XqXqXqXqXqXqXqXqXwX4X3XVX_ ` hX9XqXqXqXqXqXqXqXqXwX9X@XJXzX8XwXqX0X0XuXkXcXgXrX0X0XqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXwX8XxXHXqXqXqXqXqXqXqXqXqXqXqX0XfX^.= W.aX9XqXqXqXqXqXqXqX0XrX$XtXIXwXqXqXqXqXqX0X0XuXkXcXgXrX0X0XrXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqX0XeXKXkX9XqXqXqXqXqXqXqXqXqX0XyX,X5 2.hX8XqXqXqXqXqXqXqXqXwX7XOXJXzX8XqXqXqXqXqXqXqX0X0XyXjXcXgXeXwXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XwX8XvXHXqXqXqXqXqXqXqXqXqXqXqXqXrXS _ mXtX0XqXqXqXqXqXqXqX0XrX#XtXIXwXqXqXqXqXqXqXqXqXqXqX0X0XyXjXxXjXPXuX0XqXqX",
"qXqX0XtXOXoXtX0X0XrXPXkX9XwXqXqXqXqXqXqXqXqX8XgXl.  b j y.pX9XqXqXqXqXqXqXwX6XoXKXzX8XwXqXqXqXqXqXqXqXqXqXqXqX0X0XtXkXUXyX0XqXqX",
"qXqX0XtXOXoXtXqX8XnXGXqXqXqXqXqXqXqXqXqXqXqX0XtX$XK.A.m.].rX0XqXqXqXqXqXqXrXOXtXIXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XwXPXuX0XqXqX",
"qXqX0XtXOXoXtX9XyXUXlX9XqXqXqXqXqXqXqXqXqXqXqX0XyXgXgXjXpX0XqXqXqXqXqXqXwX5X.XKXzX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXPXuX0XqXqX",
"qXqX0XtXOXoXyX7XcXMX5XqXwXqXqXqXqXqXqXqXqXqXqXqX0X8X8X8X0XqXqXqXqXqXqX0XrXXXtXPXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XVXrX#X$X3XwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X XKXzX8XwXqXqXqXqXqXqX9X8X8X9XqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXOXeXgXUXmXjX7X#X%X4XwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX.XtXIXwXqXqXqXqXqXqXqX0XiXjXjXuX0XqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtXGXNX9XaXxXjX5X#X&X5XwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX2X|.LXzX8XqXqXqXqXqXqX9XiXR.B V ~.iX9XqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOX XcXIXuX0X0XqXaXxXhX3X@X=X6XwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXrX|.tXIXwXqXqXqXqXqXqX0XwX0Xx +.#.d wXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXOXUXmX9XwXqXqX0XqXaXzXfX1X@X-X8XwXwXqXqXqXqXqXqXqXqXqXqXeX<X}.LXzX8XqXqXqXqXqXqXqXwX8X|.xXF.i 9XwX0XqXqX0XeXPXuX0XqXqX",
"qXqX0XyX.X1XUXrX0XqXqXqXqXqX0XqXaXzXsX,X@X;X8XeXqXqXqXqXqXqXqXqXqXeX{.tXIXwXqXqXqXqXqXqXqXqXqX8XkXx.  u.hX8XqXqXqX0XeXPXuX0XqXqX",
"qXqX0XyX X6XVX7XwXqXqXqXqXqXqXqX9XqXaXlXaX>X@X>X9XwXqXqXqXqXqXqXeX,X}.LXzX8XwXqXqXqXqXqXqXqXqXwXfX,X+.Z 8XwX0XqXqX0XeXPXuX0XqXqX",
"qXqX0XyXXX:XdX9XqXqXqXqXqXqXqXqXqXqX9XqXaXlXiX;X@X,X0XeXqXqXqXqXeX].tXIXwXqXqXqXqXqXqXqXqX0XrX,Xt.kX7X6 '.pX9XqXqX0XeXPXuX0XqXqX",
"qXqX0XtXoXOXtX0XqXqXqXqXqXqXqXqXqXqXqXqX9XqXsXkXyX-X#X<XqXwXqXeX:X{.LXzX8XwXqXqXqXqXqXqXqX0XeX5Xd A V M 0XqX0XqXqX0XeXPXuX0XqXqX",
"qXqX0XyX@XoXtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XwXsXjXrX=X$X1XqXeX`.tXPXwXqXqXqXqXqXqXqXqXqXqX0XuX%X=.;.&XyX0XqXqXqX0XeXPXuX0XqXqX",
"qXqXqXqX)..XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XwXsXhXqX&X*X*X|.PXxX8XqXqXqXqXqXqXqXqXqXqXqX0XtXxXxXtX0XqXqXqXqX0XeXPXuX0XqXqX",
"qXqXwX9X&X2XwXqXqXqXqXqXqX8X7X9XqXqXqXqXqXqXqXqXqXqX9XwXsXgX8X.XpXGX0XwXwXqXqXqXqXqXqXqXqXqXqXqX0X7X7X0XqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XuXKXwXqXqXqXqXqXqXwXjXvXdX0XqXqXqXqXqXqXqXqXqXqXqX9XtX2X[.nX8X@X;X9XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XrX+XXXtX0XqXqX0XwX8X3.J n.uX0XqXqXqXqXqXqXqXqXqXqXqXqX).<XUXmXiX:X#X>X9XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXoXoXtX0XqXqX8XfX,.w ,.: R.aX9XqXqXqXqXqXqXqXqX0XeX;X_.BXfXpXcXbXiX:X#X,X0XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqX8XkXb p.UXD 7.hX8XqXqXqXqXqXqXqXqXqXqX).7XZX8X0XqXiXxXbXiX:X$X<XqXwXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqX8XjXY F '.9 e.gX9XqXqXqXqXqXqXqX0XrX=X`.ZXaX9XwXqX0XqXiXzXbXiX:X%X1XqXeXqXqXqXqXqXqXqXqXqXqXqXqX7XLXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqX0XyX|.t D g w.gX9XqXqXqXqXqXqXqXqXqX).0XZX8XqXqXqXqXqX0X0XuXzXbXuX:X&X2XqXwXqXqXqXqXqXqXqXqXqXqX@XHXiX9XqXqX",
"qXqX0XtXOXoXtX0XqXqX0XtX^.-XAXK 6.hX8XqXqXqXqXqXqX0XrX*X'.DXaX9XqXqXqXqXqXqXqX0X0XuXlXvXuX:X&X3XwXwXqXqXqXqXqXqXeX,X|.PXuX9XqXqX",
"qXqX0XtXOXoXtX0XqXqX8XgX..a 7.; T.aX9XqXqXqXqXqXqXqX0X(.tXZX8XqXqXqXqXqXqXqXqXqXqX0X0XyXlXvXuX:X*X4XwXwXqXqXqXqXwX}.:XUXyX0XqXqX",
"qXqX0XtXOXoXtX0XqXqX0XeX5X=.F v.uX0XqXqXqXqXqXqX0XrX&X{.GXaX9XqXqXqXqXqXqXqXqXqXqXqXqX0X0XyXlXvXyX:X=X5XwXwX0XeX,X[.eXIXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXqXeXkXcXdX0XqXqXqXqXqXqXqXqX0X/.iXZX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XyXlXcXyX:X-X6XwXwX}.-XyXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXqX0X8X7X9XqXqXqXqXqXqXqXqXrX$X XJXpX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X9XtXkXxXyX:X,X>X}.0XrXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX9X/.sXZX8XqXqXqXqXqXqXqX0X8X8XqXqXqXqXqXqXqXqXqXqX0X9XtXkXzXwX#X<XwXeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX#XXXLXpX9XqXqXqXqXqXqX0XyXzXgXqXqXqXqXqXqXqXqXqXqXqXqX0X9XuX:X$XtX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8X(.hXZX8XqXqXqXqXqXqX0XuX@Xr.A.tXwXqXqXqXqXqXqXqXqXqXqXqXqX0X X3XeX0XeXPXuX0XqXqX",
"qXqX0XtXOXOXyX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX@X+XPXiX0XqXqXqXqXqX0XtX&Xp b , &.dX9XqXqXqXqXqXqXqXqXqX0XrX;X@XrXqX0XeXPXuX0XqXqX",
"qXqX0XtX+X}.0XwXwXqXqXqXqXqXqXqXqXqXqXqXqXwX7X(.zXZX8XqXqXqXqXqXqX8XjXl.u KXOXd.wXqXqXqXqXqXqXqXqXqXqXqX0X|.4XwXqX0XeXPXuX0XqXqX",
"qXqX0XtX+X[.=X;X8XwXwXqXqXqXqXqXqXqXqXqX0XrXOX$XUXiX0XqXqXqXqXqXqX8XjXk.f <.R -XyX0XqXqXqXqXqXqXqXqX0XrX=X+XrX0XqX0XeXPXuX0XqXqX",
"qXqX0XtXOXOXwX:X&X>X8XeXqXqXqXqXqXqXqXqXwX6X(.vXCX8XqXqXqXqXqXqXqX8XhXn.% t.y W fX9XqXqXqXqXqXqXqXqXwX9X{.5XwXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXyXwX8X>X&X,X9XeXqXqXqXqXqX0XrXoX*XUXiX0XqXqXqXqXqXqXqX8XkXg.g UXN.v wXwX0XqXqXqXqXqXqX0XrX&X+XrX0XqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XwXeX8X>X*X<X0XeXqXqXqXwX6X).MXCX8XqXqXqXqXqXqXqXqX9XdXL.> R.U L dX9XqXqXqXqXqXqXqXwX8X[.5XwXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXwXeX8X>X=X1X0XwXqXrX.X:XUXiX0XqXqXqXqXqXqXqXqXqX0XtX<.9 N {.uX9XqXqXqXqXqXqX0XrX$X+XrX0XqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXqXwXeX8X>X-X2XwX5X_.VXVX9XqXqXqXqXqXqXqXqXqXqXqXwXaXtXpXyX0XqXqXqXqXqXqXqXwX7X].5XwXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXOXoXtX0XqXqXqXqXqXqXwXwX8X>X>XOX2XUXiX9XqXqXqXqXqXqXqXqXqXqXqXqX9XqX0X0XqXqXqXqXqXqXqXqXrX@XOXrX0XqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XtXoXoXtX0XqXqXqXqXqXqXqXqXwXeX7X:XCXvX6XeXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX5X'.5XwXqXqXqXqXqX0XeXPXuX0XqXqX",
"qXqX0XyX#XOXyXqXwXwXwXwXwXwXwXwXwXwXwXtXyX;X$X,X0XrXeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXtX+X+XtXqXwXwXwXwXwXqXrXPXuX0XqXqX",
"qXqXwX9XE. XqX6X7X7X7X7X7X7X7X7X7X7X7X6X5X6X,X@XoX*X3X6X7X7X7X7X8X7X7X7X7X7X7X7X7X7X7X7X7X6X8X:X~.2X8X6X7X7X7X7X7X6X0XPXuX0XqXqX",
"qXqXqXwXiXdXBXBXBXBXBXBXBXBXBXBXBXBXBXBXVXVXCXBXcXkXxXBXBXBXVXMXvXNXBXBXBXBXBXBXBXBXBXBXBXBXVXzXhXVXBXBXBXBXBXBXBXVXmXPXuX0XqXqX",
"qXqX0XuXzXdXUXmXBXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXVXCXVXBXNXNXZXtXNXLXmXBXNXNXNXNXNXNXNXNXNXBXNXVXCXNXNXNXNXNXNXNXNXVX9XHXiX9XqXqX",
"qXqXqXqX3X8XrX6X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X6X6X6X7X7X7X7X3XwXqX6X7X7X7X7X7X7X7X7X7X7X7X7X6X6X7X7X7X7X7X7X7X7X6X4XyXwXqXqXqX",
"qXqXqXqXeXqX0XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeX0XqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeX0XqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXeXwXwXwXwXwXwXwXeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeXqXqXqXqX",
"qXqXqX0X3X5X6X6X6X6X6X6X5X5X6X6X6X6X6X6X6X6X6X6X6X6X5X4X5X6X6X6X6X6X6X6X6X6X6X6X6X6X6X5X0XqXqXqX",
"qXqXqX0X:XXX X X X X.X|.+X+X X X X X X X X X X X X XoX#XXX}. X.X X X X X X X X X X.X}.>XrX0XqXqX",
"qXqX0XyXdX8XrXwXwXwXwXwXZXpXqXeXwXwXwXwXwXwXwXwXwXwXrXdXzXfXeXqXeXeXeXwXwXwXwXwXwXeXqXAXuX9XqXqX",
"qXqX0XrX|.<XeX0XqXqX8XjXbX7XqXqXqXqX0X8X8X0XqXqXqXqX0X9XwXdXjXaX0X9X0XqXqXqXqXqXqXqX9XZXyX0XqXqX",
"qXqX0XrXoX1XeXqXqXqXqXCXyX0XqXqXqXqXeXhXhXyX0XqXqXqXqXqXqX9XyX4XsXxXwX9X0XqXqXqXqXqX9XZXuX0XqXqX",
"qXqX0XrXoX1XeXqXwX8XlXnX8XwXqXqX0XeX4X$.^ +XyX0XqXqXqXqXqXqX0X>XSXjXlXfXeX9X0XqXqXqX9XZXuX0XqXqX",
"qXqX0XrXoX1XeXqXqXwXAXyX0XqXqXqX9XpX~.9.q.| jX8XqXqXqXqXqXrX>XfXnX5XrXdXlXfXeX9X0XwX0XZXuX0XqXqX",
"qXqX0XrXoX1XeXqX8XxXnX8XwXqXqXqXqXqX8XAX>.3.jX8XqXqXqXqXqX0X:XSXrXqXqX9XwXsXlXfXeX0X9XZXuX0XqXqX",
"qXqX0XrXoX1XeX0XeXDXyX0XqXqXqXqXqX8XjXG.R pXqXqXqXqXqXqXrX;XdXnX7XwXqXqXqX9XwXsXkXfXwXZXuX0XqXqX",
"qXqX0XrXoX1XrX7XvXmX8XwXqXqXqXqX0XuXoX, q.oXeX0XqXqXqXqX9X-XDXrX0XqXqXqXqXqXqX9XwXsXjXFXyX0XqXqX",
"qXqX0XrXoX2XwXrXFXtX0XqXqXqXqXqX0XuX}.>.-.F.iX0XqXqX0XrX=XdXnX7XwXqXqXqXqXqXqXqXqX0XqXAXyX0XqXqX",
"qXqX0XrXoX2X0XnXmX0XwXqXqXqXqXqXqX0XyXlXlXaX0XqXqXqXwX9X*XDXrX0XqXqXqXqX0XqXqXqXqXwX9XZXuX0XqXqX",
"qXqX0XrXoX1XtXnX,X>XqXeXqXqXqXqXqXqX0X7X7X9XqXqXqX0XtX&XsXmX7XwXqXqXqX0XeXwX0XqXqXqX0XZXuX0XqXqX",
"qXqX0XrXoX>XzXDXaX5X*X<XqXeXqXqXqXqXqXqXqXqXqXqXqXwX8X&XDXrX0XqXqXqX0XpX3X9XtX0XqXqX9XZXuX0XqXqX",
"qXqX0XrXXX1XHXsXeXhXdX3X*X2XwXeXqXqXqXqXqXqXqXqX0XtX$XsXmX7XwXqXqX9XsXA.m ^ ;XrX0XqX9XZXuX0XqXqX",
"qXqX0XtX XaXSX8XqX9XtXgXaX2X=X3XwXwXqXqXqXqXqXqXwX7X$XDXrX0XqXqXqX0XuXP.XXE P.dX9XqX9XZXuX0XqXqX",
"qXqX0XrXXXnXdX9XwXqX0X9XtXgXiX<X=X4XeXwXqXqXqX0XtX@XaXmX7XwXqXqXqXqX7XBXn.i 7XeX0XqX9XZXuX0XqXqX",
"qXqX0XrXOXpXwXqXqXqXqXqX0X9XtXfXyX,X-X5XeXwX0XwX6X#XFXeX0XqXqXqXqX0XrX'.fX+.x.hX9XqX9XZXuX0XqXqX",
"qXqX0XrXOX2XeXqXqXqXqXqXqXqX0X9XyXdXrX>X;X6XwXtXOXaXmX7XwXqXqXqXqX8XfX8.U J ^.pX9XqX9XZXuX0XqXqX",
"qXqXqXeX{.1XeXqXqXqXqX0XqXqXqXqX0X0XyXdXwX:X>X2X#XGXeX0XqXqXqXqXqXqXwXwXJ.].iX0XqXqX9XZXuX0XqXqX",
"qXqXqX0X&X7XwXqXqX0XqXuX0XqXqXqXqXqX0X0XyXaXqXOXaXzX8XeXqXqXqXqXqXqXqXqXfXiX0XqXqXqX9XZXuX0XqXqX",
"qXqX0XyXgX7XwXqX0XrXqX#XtXwXqXqXqXqXqXqX0XwX9XOXMX3X*X5XwXwXqXqXqXqXqXqX9X0XqXqXqXqX9XZXuX0XqXqX",
"qXqX0XrX|.<XeX0XqXwXX.v 2.pX9XqXqXqXqXqXqXtXXX7XVXlXpX,X-X6XeXwXqXqXqXqXqXqXqXqXqXqX9XZXuX0XqXqX",
"qXqX0XrXoX1XeX9XpX{.G qXZ 2XeX0XqXqXqXqXwX4X.XnX9XqXdXzXpX<X;X6XeXwXqXqXqXqXqXqXqXqX0XZXuX0XqXqX",
"qXqX0XrXoX1XeX0XeX5XL ) D 2XeX0XqXqXqX0XtX.XeXkX8XqX9XqXsXzXiX<X:X7XeXwXqXqXqXqXqXeX3XnXiX9XqXqX",
"qXqX0XrXoX1XeX0XwX8XH.Y.K <XrX0XqXqXqXeX3XoXMXqXqXqXqXqX9XqXsXlXiX1X>X8XeXwXqXqXqXrX+XcXpX9XqXqX",
"qXqX0XrXoX1XeX0XeX4X( R o.iX0XqXqXqX0XrX.XuXkX8XqXqXqXqXqXqX9XqXaXkXuX1X,X8XeXqXeX4XXXAXyX0XqXqX",
"qXqX0XrXoX1XeXqX0XtX,XY.8XeX0XqXqXqXeX2X+XBX0XqXqXqXqXqXqXqXqXqX9XqXaXkXuX2X<X8XrX+X>XDXyX0XqXqX",
"qXqX0XrXoX1XeXqXqX0XrXdXwX0XqXqXqX0XrX XsXkX8XqXqXqXqX9X9XqXqXqXqXqX9XqXpXjXyX4X<X+XqXZXuX0XqXqX",
"qXqX0XrXoX1XeXqXqXqX0X9XqXqXqXqXqXeX1X#XCX0XqXqXqXqX0XsXhXqXqXqXqXqXqXqX9X0XaXdX*X6XqXZXuX0XqXqX",
"qXqX0XrXoX1XeXqXqXqXqXqXqXqXqXqXqXrX XgXkX8XqXqXqX0XuXY.N.0XwXqXqXqXqXqXqXqXqX1X&XrX9XZXuX0XqXqX",
"qXqX0XrXXX1XtXqXqXqXqXqXqXqXqXqXeX<X*XAX0XqXqXqX9XdXJ.P { g.fX9XqXqXqXqXqXqXeX$X6XeX9XZXuX0XqXqX",
"qXqX0XrXoX@X4XqXwXqXqXqXqXqXqXqXrX XlXjX8XqXqXqX8XlXq.o.F..XtX0XqXqXqXqXqXeX1X%XrXqX0XZXuX0XqXqX",
"qXqX0XrXoX,X2X;X3XqXwXqXqXqXqXrX>X-XSX9XqXqXqXqX8XkXu.Y Q q.hX8XqXqXqXqXqXwX+X6XwXqX9XZXuX0XqXqX",
"qXqX0XrXoX2XtX8X<X:X4XwXwXqXqXeX XcXjX8XqXqXqXqX8XlX9.9.F.] kX8XqXqXqXqXeX,X$XrX0XqX9XZXuX0XqXqX",
"qXqX0XrXoX1XeXqXeX8X<X>X5XqXtX:X>XDX9XqXqXqXqXqX0XtX%XT A ).iX9XqXqXqXqXwXOX6XwXqXqX9XZXuX0XqXqX",
"qXqX0XrXoX1XeXqXqXwXeX8X<X,X7X.XmXhX8XqXqXqXqXqXqX0XyXeXqXuX0XqXqXqX0XrX:X$XrX0XqXqX9XZXuX0XqXqX",
"qXqX0XrXoX2XrXqXqXqXqXwXeX9X:XwXCX0XeXqXqXqXqXqXqXwX0XqXwX0XwXqXqXqXwXqXXX6XeXqXqXwX0XZXuX0XqXqX",
"qXqXqXeX}.,XqX8X9X9X9X9X8X0X9XtX,X%X1X8X9X9X9X9X9X9X9X8X8X9X9X9X9X8XqX&X+XwX8X9X9X9X7XCXuX0XqXqX",
"qXqXqX0X$XeXdXsXsXsXsXsXsXsXsXaXsXyX5X8XiXdXsXsXpXsXsXsXsXsXsXsXsXsXsX>XyXdXsXsXsXsXaXDXyX0XqXqX",
"qXqX0XtXjXZXZXBXVXVXVXVXVXVXVXVXVXCXCXBXBXBXZXkXVXAXBXVXVXVXVXVXVXVXBXVXVXVXVXVXBXZXlXMXuX0XqXqX",
"qXqXqXqX6XqX9X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X6XqX9X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X6XqXwXqXqXqX",
"qXqXqXqXwXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXqXqXqXqX",
"qXqXqX0X1X4X4X4X4X4X4X3X3X4X4X4X4X4X4X4X4X4X4X4X3X3X4X4X4X4X4X4X4X4X4X4X4X4X4X3X0XqXqXqX",
"qXqXqXqX1XOXOXOXOXOXoX&X&XoXOXOXOXOXOXOXOXOXOXOX$X=X+XXXOXOXOXOXOXOXOXOXOXOXXX<XtX0XqXqX",
"qXqX0XyXqX9XrXeXeXrXwXVXsXwXrXeXrXeXwXeXrXeXeXeXyXgXlXdXrXrXeXrXeXeXeXeXeXrXqXCXpX9XqXqX",
"qXqXqXwX|.5XwX0XqX8XgXvX7XqX0XqX0XwXsXwX0XqX0XqX0X9XwXsXdX0XeX9X0XqXqX0X0XqX8XNXiX9XqXqX",
"qXqXqXeXOX6XwXqXqX0XBXyX0XqXqXqXeX7XQ.6XrX0XqXqXqXqX0XwX<XdXBXpXwX9XqXqXqXwX8XNXiX9XqXqX",
"qXqXqXeXoX6XwXqX8XjXbX8XwXqXqX9XaX2.K =.uX0XqXqXqXqXqX0X1XCXtXdXkXsXwX9XqXwX9XNXiX9XqXqX",
"qXqXqXeXoX6XwXqXqXCXyX0XqXqXqXqX0X-X-XL eXqXqXqXqXqXrX,XgXxX7X0XeXsXkXsXwX0X8XBXiX9XqXqX",
"qXqXqXeXoX6XeX8XlXnX8XwXqXqXqXqX0XxX .A.fX9XqXqXqXqX0X,XCXqXqXqXqX9XwXsXjXdX0XNXiX9XqXqX",
"qXqXqXeXoX6XwXwXAXyX0XqXqXqXqX9XgX-.C %X0XqXqXqXqXrX:XfXxX7XwXqXqXqXqX9XwXsXgXAXuX9XqXqX",
"qXqXqXeXoX7X9XxXnX7XwXqXqXqXqX0XyXp.&.g.eXqXqXqXqX9X>XCXqXqXqXqXqXqXqXqXqX0X0XVXiX9XqXqX",
"qXqXqXeXoX5XrXCXyXwXqXqXqXqXqXqX0XgXkXdXqXqXqX0XrX-XdXxX7XwXqXqX0X8X0XqXqXwX8XNXiX9XqXqX",
"qXqXqXeXOX3XjXhX*X2XwXeXqXqXqXqXqX8X7X9XqXqXqXqX9X;XZXqXqXqXqX0XrXjXtX0XqXwX9XNXiX9XqXqX",
"qXqXqXeXoX5XAXxXaX5X-X3XwXwXqXqXqXqXqXqXqXqX0XrX*XdXxX7XwXqX0XrX>Xn.-XtX0XwX8XNXiX9XqXqX",
"qXqXqXeX XsXZX7XrXfXaX3X-X4XwXwXqXqXqXqXqXqXwX8X=XZXqXqXqXqX9XsXq.} [ rX0XqX8XNXiX9XqXqX",
"qXqXqXeXoXBXsX9XqX9XrXdXiX2X;X5XeXwXqXqXqX0XtX%XsXxX7XwXqXqXqX9XtXd.[ sX9XqX8XNXiX9XqXqX",
"qXqXqXqX$XlX0XqXqXqX0X9XrXdXyX1X:X6XeXwXqXwX7X&XZXqXqXqXqXqXqX9XpXK.' wXqXqX8XNXiX9XqXqX",
"qXqXqXwX+X9XwXqXqXqXqXqX0X9XtXsXrX,X>X7XwXtX#XsXxX7XwXqXqXqX0XiX1.0.Q 5XwXqX8XNXiX9XqXqX",
"qXqXqXwX|.5XwXqXqXqX0X0XqXqX0X0XtXaXwX>X<X3X&XSXqXqXqXqXqXqX0XtXoX7.}.uX0XwX8XNXiX9XqXqX",
"qXqXqX9X*X9XwXqXqXqXaXeX0XqXqXqX0X0XtXpXwX+XaXhX9XeXqXqXqXqXqX0XuXzXuX0XqXwX8XNXiX9XqXqX",
"qXqX0XyXuX7XwXqXwXrX).2XtX0XqXqXqXqX0XqX0X#XmX2X;X6XeXwXqXqXqXqX0X8X0XqXqXwX8XNXiX9XqXqX",
"qXqXqXwX|.6XwX8XdXi.I  .9XqXqXqXqXqX0XtX+X8XnXjXpX1X:X7XeXwXqXqXqXqXqXqXqXwX8XBXiX9XqXqX",
"qXqXqXeXOX6XwX8XfXR R.^ OXuX0XqXqXqXwX6XOXvX8XqXaXkXiX1X>X7XeXwXqXqXqXqXqXwX8XMXiX9XqXqX",
"qXqXqXeXoX6XwX9XaXD.[ P #XyX0XqXqX0XtX+XrXgX9XqX9X0XpXkXiX2X,X8XeXqXqXqXqXeX<XhXsX9XqXqX",
"qXqXqXeXoX6XwX9XpXz.x.E ;XrX0XqXqXwX5X@XnX0XqXqXqXqX9X0XpXjXuX2X<X9XeXqX0XrXOXzXaX9XqXqX",
"qXqXqXeXoX6XwX9XuX_...F.iX0XqXqX0XtXOXiXgX8XqXqXqXqXqXqX9X0XiXhXuX3X1X9XrX3XOXCXiX9XqXqX",
"qXqXqXeXoX6XwXqX0XiXlXaX0XqXqXqXeX4X%XMX9XqXqXqXqX9X0XqXqXqX9X0XiXgXyX3X7X#X<XVXiX9XqXqX",
"qXqXqXeXoX6XwXqXqX0X7X9XqXqXqX0XrXOXsXgX8XqXqXqXqXgXuX0XqXqXqXqX0X0XuXgX4X-X0XNXiX9XqXqX",
"qXqXqXeXoX6XwXqXqXqXqXqXqXqXqXeX3X*XNX9XqXqXqXwX9XC.|.yX0XqXqXqXqXqX9XqX&X8X9XNXiX9XqXqX",
"qXqXqXeXoX5XrXqXqXqXqXqXqXqX0XrXOXhXfX8XqXqX8XfX7.| *.3XeXqXqXqXqXqXeX1X-XrX8XNXiX9XqXqX",
"qXqXqXeXXX&X3XqXwXqXqXqXqXqXeX1X;XVX8XqXqXqX8XfX[ >.n.eXqXqXqXqXqXqXwX$X7XwX8XNXiX9XqXqX",
"qXqXqXeXoX4X2X:X4XqXwXqXqXqXrXOXlXfX9XqXqXqX8XfX_ a.R &XtX0XqXqXqXeX,X=XrXqX8XNXiX9XqXqX",
"qXqXqXeXoX6XrX9X1X>X5XqXwXeX<X,XCX8XqXqXqXqX8XgX&.2.^ -XtX0XqXqXqXqX@X8XwXqX8XNXiX9XqXqX",
"qXqXqXeXoX6XwXqXeX9X2X,X5XeXoXvXdX9XqXqXqXqX0XrX>X7.W.iX0XqXqX0XrX>X*XrX0XwX8XNXiX9XqXqX",
"qXqXqXeXoX6XwXqXqXwXeX9X4X=X9XAX0XwXqXqXqXqXqXqXrXzXaX0XqXqXqXqXqXOX8XwXqXwX9XNXiX9XqXqX",
"qXqXqXeXXX5XqX0X0X0X9X0XqX6XaX3X<X0XqX0X0X0X0X0X9X6X8X0X0X0X9XeX=X%XeX9X0X0X7XNXiX9XqXqX",
"qXqXwX9XoXwXuXyXyXyXyXyXyXuXrXqX3X1XqXuXyXuXtXyXyXyXyXyXyXyXuXtX&XeXuXyXyXuXtXCXiX9XqXqX",
"qXqX0XtXgXZXVXBXBXBXBXBXBXBXVXCXCXMXMXBXCXzXBXZXBXBXBXBXBXBXVXNXNXVXBXBXBXCXvXMXiX9XqXqX",
"qXqXqXqX8XeX9X9X9X9X9X9X9X9X9X9X9X0X0X9X0X7XwX0X9X9X9X9X9X9X9X9X0X9X9X9X9X0X7XqXwXqXqXqX",
"qXqXqXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXqXqX",
"qX0X3X4X4X4X4X3X3X4X4X4X4X4X4X4X4X4X3X3X4X4X4X4X4X4X4X4X4X4X0XqX",
"qXwX3X%X&X&X%X;X1X%X&X&X&X%X&X&X&X*X1X:X%X&X*X&X&X&X&X*X$X5XtX0X",
"qXwX,XwXrXrXqXbXfXwXrXeXtXiXeXrXrXrXuXgXhXyXqXeXrXrXrXrXqXnXpX9X",
"qX0X+X0XqX9XuXcX8XqX0XwX5X&XtX0XqX0X0X9XeX0XzXtX0X9XqXqX8XxXiX9X",
"qXqX$X0XwX9XvXiX9XqX9XiXk._ ^.aX9XqXqXeX2XfXhXaXgXyX0X0X8XcXiX9X",
"qXqX#XqX9XpXbX9XwXqXqX8XdXr.G.fX9XqXqX0X6XbX8X0XrXdXfXuX7XxXiX9X",
"qXqX#XqX9XnXiX9XqXqX9XsXC.X.uX0XqXqXeX1XfXsX9XwX0X0XrXdXaXnXiX9X",
"qXqX$X8XdXmX8XqXqXqX9XpXe.=.@XyX0XqX0X4XbX9XqXqXqXqX0X0XqXmXiX9X",
"qXqX$X9XxXeXqXwXqXqXqX0XsXpXwXqXqXeX<XdXsX9XqX0XwXqXqXwX8XxXiX9X",
"qXqX@XuXnX4X<X7XeXwXqXqX9X9XqXqXqX9X2XbX9XwX0XeX8X0XrXqX8XcXiX9X",
"qXqXOXbXhXuXuX4X<X7XeXwXqXqXqXqXrX>XdXdX9XqXwX7X1.:.6XeX8XcXiX9X",
"qX9X:XMX9X0XeXpXtX3X1X8XeXqXqXqX9X<XbX9XqXqXqXeX|.) 5XeX8XcXiX9X",
"qX9X,XiX9XwXqX9XeXiXrX2X1X9XwXrX;XsXdX9XqXqXwX5X[.o.#XuX7XcXiX9X",
"qX0X+X0XqXqX0X9XqX0XeXiXwX2X3X7X,XnX8XqXqXqXwX6X3.8.6XeX8XcXiX9X",
"qX9X;XqXqX0XiXfXqXqXqX0XrXyXwX&XpXiX0XwXqXqXqXeXuXyXeXqX8XcXiX9X",
"0XrX9X0X0XuX{.F.rXqXqXqX0X0XwX-XcX3X1X8XeXqXqXqX0X0XqXwX8XcXiX9X",
"qX0XOX0XwX6X#.o.Q.sX9XqX0XrX=X0XgXdXuX4X2X9XeXqXqXqXqXwX8XvXiX9X",
"qXqX$X0XqX0Xt.} J.fX9XqXwX8X=XjX8X0XyXdXuX5X3X9XwXqXqXwX7XdXpX9X",
"qXqX#X0XqXwXl.( ^.aX9X0XrX=XtXiX9XqX0X0XtXsXyX5X4X0XwXrX;XuXsX9X",
"qXqX#X0X0XtX^.H.eXqXqXwX7X;XlX9XqXqX0X0X0X0XtXsXyX6X5X0X@XxXpX9X",
"qXqX#X0XqX0XpXfXqXqX0XrX*XiXiX9XqX0XpXiX0XqX0X0XtXaXuX,X:XbXiX9X",
"qXqX$XqXqXqX9X9XqXqXwX7X>XzX8XwX0XtX_.}.tX0XqXqX0X0XeX:X9XcXiX9X",
"qXqX@X8XeXqXqXqXqX0XrX*XdXiX9X0XiX}.` s.0XqXqXqXqXrX>X2X0XxXiX9X",
"qXqX+X,X2X9XwXqXqXwX5X1XcX8XwX9XdXT._ a.9XqXqXqXqX9X*XwX8XcXiX9X",
"qX0X$XqX6X<X3X0XwXrX*XhXuX0XqX9XsX!.O.o.,XeXqX0XrX:X1XrX8XcXiX9X",
"qXqX#X0XwXwX6X1X6X3X5XvX7XwXqXqXqXwXx.U.uX0XqXwX8X&XwXqX8XcXiX9X",
"qXqX$X0XqXqXwXqX7X>XjXrXqXqXqXqXqXqXfXaX0XqX0XrX-X1XeXqX8XcXiX9X",
"wX9X+XqXwXwXqXwXwXrX0X:X3X0XwXwXqXqX9X0XwXqXeX7X%XeXqXwX9XvXiX9X",
"qXwXaXNXbXnXnXnXnXbXnXbXlXcXmXzXnXmXnXnXnXnXnXcXxXmXnXnXcXnXuX9X",
"qXqXwXeXqXwXqXqXqXqXqXwXeXwXwX0XeXwXqXqXqXqXqXwXwXqXqXwXqXqXwXqX",
"qXqXqX0XqXqXqXqXqXqXqXqXqXqXqXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"0X3X2X2X2X1X2X2X2X2X2X2X2X2X1X1X2X2X2X2X2X2X3XqX",
"wX2X>X,X>X0X1X>X,X>X>X,X>X3X7X1X>X>X,X,X,X:XeXrX",
"8X:XtXwXpXxXwXeXtXuXiXeXrXeXuXaXuXiXwXeXrXwXxXtX",
"7X-XeX8XlXtX9XwX7Xw.F.iX9X0XqX4XjXdXpXeX0X8XkXtX",
"7X;XqXuXlX9XqX0XuXT.l.sX9XwX8XrXfX7XtXaXaXwXkXtX",
"7X;XqXcXyX0XqXwX9X` ^.iX9XwX4XhXeXqX0X0XrXpXvXrX",
"7X=XaXjX9XwX0XwX7X'.&XeXqX7XwXgX8XqXeXwX0X8XlXtX",
"8X*XcXeX2X8XwXqXqXpXtX0XeX2XgXeX0XwX3X8XeX9XkXtX",
"5X2XbXrXyX6X3X9XwX0X0XwX7X0XgX8XqXyXs.t.pX8XlXtX",
"5XqXpX8XwXyXrX6X4X9XwXeX<XgXeXqXqXtX.X1.yX8XkXtX",
"6X-XeXqX9X8XwXtXwX5X6X5X9XhX8XqXqXeXf.u.tX9XkXtX",
"8X1XwXqXpXiXqX0XwXtXwX:XaX0XwXqX0XeX3X8XeX9XkXtX",
"qX4XqXrXV.F.yX0XqXqX8X3XjX5X4X9XwXqXeXwXqX9XlXtX",
"6X*XrX7X>.*.8XwX0XrX:XtXtXiXyX8X5X0XwXqXqX9XhXtX",
"7X-XwXrXa.%.wXqXwX6X3XsX8X0XeXiXyX8X6X0XrX3XyXuX",
"7X-XwXrX`. XtX0XeX>XpXwXqX0X0X9XeXuXyX8X9X*XgXyX",
"7X;XeX0XpXuX0XeX5X6XsX9XwXtXqXwX0X0XwXiX8X>XzXtX",
"7X=XeXwX9X0XqXeX,XdXwX9XiXM.s.eXqXqX0XqX,X8XlXtX",
"8X%X3X7XwXqXwX4X9XdX9X0XyX-.5.5XeX0XeX4X1XqXkXtX",
"7X;XqX3X3X8XeX,XhXqXqX0XuXi.#.2XrX0XwX;X0X0XlXtX",
"7X-XeXwX9X5X,XtXdX9XqX0XeX1X*XrX0XeX2X,XeX8XkXtX",
"6X=XrXqXwXeX0XrX1X8XwXwXqXrXyXqXwXqX=XqXwX0XzXtX",
"0XsXcXlXzXlXzXlXhXgXzXhXzXlXlXzXzXkXhXzXzXlXlXrX",
"qXwXqXqXqXqXqXqXwXwXqX0XwXqXqXqXqXqXwXqXqXqX0XqX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qX7X5X5X5X6X4X5X6X6X5X6X6X5X6XqX",
"qX2X2X8X7X2X9X5X2X9X6X2X2X1X0XtX",
"8X2XrXhXeXtX!.:XyXqXuXfXuXqXsXuX",
"8X,XsXiX8XyXf.oXuX7XiXwXeXyXfXyX",
"8X1XgX0XwX0X~.5XqXqXiX0XiX0XdXuX",
"6X0XdX6X8XqXpXeX7XuXeX8XQ.5XaXuX",
"7XqXrXqXqX8X6X9X0XiX9XwXt.#XgXyX",
"9X3XwXuXrXwXqX4XrXwXwX8X(.5XsXyX",
"9X6X8Xc.;XrXqX6XiX8X8XqXpX0XaXuX",
"7X2X0X-.|.pX4XqXeXeXeX0X8X9XwXyX",
"8X2XeX&X9XqX6XyXwXuXwXrXrX4XqXiX",
"8X<XwXyXeX6XrXtX>XS.0XqXeX2XpXuX",
"8X,X7X8X9X0XyXyXoX#.5XtX6X3XsXyX",
"7X<XqX6X3XrX0X0X7XXX8X0X,X7XpXuX",
"9XeXfXsXdXiXuXsXdXkXdXiXyXsXgXyX",
"qXtXrXrXrXtXtXrXrXeXrXtXtXrXeXqX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
