#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqX8X7X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXrXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX8X[._.<XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXVXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXJXNXrXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X_.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXAX4X0XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXMXfXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXaX3X}.8XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXlX8X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX<X'._.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXuXuXeXqXqXqXqXqXqXqXqXqXyXiXyXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX6XY.O.%.'.7XwXqXqXqXqXqXqX6Xi.[ 8.).wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XJ.H   $ C.4XwXqXqXqXqXqX0XQ.h   d n.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqX8XL.L # & : A.4XwXqXqXqXqXqX6X&.1   l N.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqX<XO.r N g , A.4XwXqXqXqXqX9X+Xl O   l N.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXeXV.z.A.B , A.4XwXqXqXqXwX3Xu.5 7 - j N.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX5X8X~.B , A.4XwXqXqXqXwX*XV > ! h g N.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXyX^.B , A.4XwXqXqXwX4XS.4 F 1.x f N.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXqXrX$X) * i.l.l f N.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXwX9XU.0 d (.A.k f N.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXeX%X,.= >.2XJ.l h C.rXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXyX!.v * =.b.-.e 9 5.:X0XqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXyXU.u & $ # + .   z T.9XqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXtX'.} Y U Y b : * ! [.0XqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXqX8X,X:X:X>Xc.g a x.9XqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.N : Z.4XwXqXqXqXwXwXwXrXZ.h d N.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,XR.D.*X9XqXqXqXqXqXqXqXqX&XI.P.%XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXyXuXeXqXqXqXqXqXqXqXqXqXeXyXyXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.>XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.4XaXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXGXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.jXUXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXZXLXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXUXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXDX3XAXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXBXiXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXyX1X{.BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXnX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX4X'.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX3X/.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXxXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX<X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXhX:X*X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X+X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).MXCX4X`.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.~._.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).bXiX&XoXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOX$X9XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).NXUXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXKXMXeXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXVX,X0XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXeXeXwXqXqXqXqXqXqXwXeXeXeXeXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXnXiXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXtX:X{.8XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX6XT.E L J.3XwXqXqXwX9X'.1.T J [ b.4XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX<X_._.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XL.D     d.<XeXqXqX9X|.! 1 - * = x p.8XqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqX8XK.K % , @ h.<XwXqXeX,Xu.# q @.9.J % b #X9XqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXwX5Xw.d I n & g.<XwXqXeX=X4.m 5.&XgXV.e 0 U.7XqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXrX~.v.!.I * g.<XwXqXwX6X}.R.#X8XyXA.f q I.7XqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXoXI * g.<XwXqXqXqX0X9X0X2X@X-.$ c $X0XqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXOXI * g.<XwXqXqXqXqXqXeXq.j & y f.7XqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXOXI * g.<XwXqXqXqXqXqXeX( o   b I.0XqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXOXI * g.<XwXqXqXqXqXqXwX~.u.D , ! *X0XqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXOXI * g.<XwXqXqXwXrXrXwXtX6Xz.s 7 V.5XwXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXOXI * g.<XwXqXwX5X}.`.3XqXyX{.) , 1.1XwXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXOXI * g.<XwXqXeX&X:.` Q.9XpX'.Q > 1.1XwXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXOXI * g.<XwXqXrXOXP # ..R.OXu.r 0 M.5XwXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXOXI * g.<XwXqXwX1Xx.7 % a k 5 - I ;X0XqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrXOXR , j.1XwXqXqXqX>Xh.B 1 ; u O.[.9XqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX6XoX_.;X9XqXqXqXqX0X<X.X).(.].%X8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXeXeXwXqXqXqXqXqXeXeXeXeXeXeXeXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXrXtXeXqXqXqXqXqXqXwXrXtXtXtXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XZ.P E ~.6XwXqXrX+X6.J F F D D S 3.eXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXwX5XM.v   % C.4XwXqXtX'.I   & 2 3 3 1 ' eXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqX5Xm.N $ : > A.4XwXqXtX].R & Q 0.p.i.u.H.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqX2X$.j I k , A.4XwXqXtX].T : s.3XuXyXyXrXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXeXJ.Z.K.V , A.4XwXqXtX].T : p.<XrXeXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XeX^.B , A.4XwXqXtX].T ; 8.|.*X-X3X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXtX].R + 8 7 8 M i.>XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXtX].R X O y e ; e 3.wXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXrX.X%.c X.D.T.) % C .X0XqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXwX1X/.G. XqXaXv.u p D.9XqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXqXqXwXrXtXwXrXJ.M r c.9XqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXeX;XD.x. X0XiXn.s i A.9XqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXtX'.U % O.!.|...% B |.0XqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX^.B , A.4XwXqXeX,Xh.< & g a : 6 :.qXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXtX/.S 4 D.4XwXqXqXqX*Xi.c , ; j 0.*XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX4X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX3X X`.<X0XqXqXqXqX0X>X|.).(.}.;X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXmX0XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeX5X(.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXrXtXwXqXqXqXqXqXqXeXrXtXtXtXeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXUXcX;X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X#XoX/.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.lXCX5X'.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.!.~.^.).BXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.uXtX#X X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.X.XOXCXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXzX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX,X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXxX0XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX<X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.,XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXFXUXgX=X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X@X#X.X^.`.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.>XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqXSXbX>X).Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.Q.!._.7XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X`.^.3XdXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXDXsX<X-X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X<X0XqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX7X'. XsXJXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXLXtXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqX8XoXpXDXLXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXLXGXrXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqX8XwXrXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXrXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqX",
"qXqXqXwXtXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX8X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8X7X0XqXqXqX",
"qXqXwX6X=X5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXhXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXgXlXuX0XqXqX",
"qX0XtX;XL.=XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXSXeXqXqXqX",
"qX0XrX>XR.;XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXFXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXzX#X=XtX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXZX3X8X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X6X0X=XT.:XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX8XeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXyX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXwXwXqXqXqXqXqXqXqXqXwXwXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXrXwXqXqXqXqXqXqXqXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqX0XuXoXi   E.rXqXqXqXqX9X8Xy   y.yX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqX0XqX{.t     Y.rXqXqXqX8XdXy..   w.yX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqX0X8XpXR t K O U.rXqXqXqX8XtXn   . e.yX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqX9XsXT.=X:.  Y.rXqXqX7XfXm.# z # q.yX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqX9XtXhX$.  Y.rXqXqX7XaXY ; 7.* 9.uX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqX6XaX%.  Y.rXqX8XaXE.+ ,.k.O 0.uX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqX8XdX%.  Y.rX0X8XgXo.  `.b.X 8.yX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqX8XdX%.  Y.rX8XiX}.3 ' cXN.o i.aX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqX8XdX%.  Y.rX7XkXl.  > w ,   7 ).rX0XqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqX8XdX&.  Y.rX8XfXJ.C M b t   p [.eX0XqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqX8XdXO.  P.tXqXqXwXwXqXaXf.  7.uX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqX8XaXw.a /.rXqXqXqXwX0XyXC.f k.yX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqX0XaXlXtXqXqXqXqXqXqX0XuXlXpXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XY.;XyXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXtXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqX9X6X0XqXqXqXqXqXqXqX9X6X9XqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.*X0X6X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X5X9XUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XI.9XAXnXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXNXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.sXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXyXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXgXuXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXiXaX2X].UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXuX6X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X8X0X/.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXpX9XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXZX6XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XrX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXZX9XyXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXrXpX:XY.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX+X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X.X{.W.:XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.[.SX+XW.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.Q.W.:XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0X0XqXqXqXqXqXqX0X0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.].UXFXHXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXGXaX9XqXqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqX0XeXdXiXqXqXqXqX0XwXpXsXaXeX0XqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXUXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXUXuX,XrXqXqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqX0XrX7X).@XqXqXqXqXeX0XoX]..X7XtX0XqXqXqXqXqXqXqXqXqXqXeX(.'.UXZX5X0X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9XqX2X/.-XtX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXyX0X .  S 7XqX0XwX0X:.o     o.<XrX0XqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XY.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXeX>X(   O I 8XqX9XtXl.  k t.G   y.fX8XqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXtX{.t :.6 F 9XqX9XtXy.I Q.CX].$ ` 9XwX0XqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXwX8X@X*X2 H 9XqX0XqX5X<X9XvXP.  +.iX0X0XqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqX0XjXoX2 H 9XqX0XqXwXuX;X;.r 2 Q.aX9XqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqX9XyX+X2 H 9XqX0XqX9XaX'.    _ 7XeX0XqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqX0XpX+X2 H 9XqX0XqXwXeX7X[.[   i.aX9XqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqX0XpX+X2 H 9XqX0XqXqXqXqXfXOXe v ;XyX0XqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqX0XpX+X2 H 9XqX9XrXe.4.qXfX4XM y @XiX9XqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqX0XiX@X6 L 9XqX9XuXI   s.<Xz.  E 6XeX0XqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqX9XpXoXo n 9XqX0XrX_.w   o   5 U.sX8XqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqX0X7X5X0XqXqXqX0X6X6X6X6X6X6XqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqX0XyX:X@.t.0XqX0XqXyX].:.' &.).uX9XqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqX9XlXnXyXqXqX0XtXxXnXnXnXmXcX0XqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqX0XeXcXkXqXqXqXqX9XyXxXmXcXyX9XqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqX0X9XrXp.$.+XeX9XyX#X9.$.*.&.#.7.yX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqX0X6X7XqXqXqXqXqX9X6X5X6X9XqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqX0X0XiX3.    P.tX8XsXT.%   . .   q sX9XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqX0X9XrX;.  q & T.rX8XaX/.5 P `.|.]..XeXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqX8XgX,.y.#.  U.rX8XaX/.> ) uXgXsXpXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXeX5XgX=.  Y.rX8XaX/., ~ 5XwX0XwXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqX0XfX%.  Y.rX8XaXQ.8 + * + G OXrXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqX8XsX%.  Y.rX8XaX!.q   J H   k rX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqX8XdX%.  Y.rX9XyX$X3.k.rXzXG @ W.tX0XqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqX8XdX%.  Y.rXqX0XuXmXjX5X8X5.# v.uX9XqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqX8XdX%.  Y.rX9XiX|.*.D.fXnX) + K.yX9XqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqX8XsX=.O T.rX8XiX}.* O r.t.@ 7 5X0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqX8XfX|   K.tX0X9XuXD.6     e G.uX0XqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXiX8XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XeX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqX0XrXXXI.,XwXqXqXwXeX+XY.T.oXuX0XqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXUXpX0XeXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrX(.'.UXAX7XwXqXqXqXqXqXqXqXqXqXqXqX0XiXgXrXqXqXqXqXqXiXhXgXpX0XqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.pXUX3X(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.).!.'.UXZX7XwXqXqXqXqXqXqXqXqXqXqXqXqX0X9X0XqXqXqXqXqX0X9X9X0XqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX,XL.iXiX)._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._._.). XUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.=XrXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXyXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9XeXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXAX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX-XT.>XrX0XqX",
"qX0XrX>XT.-XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXUXZX8XtXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXwXuX:XY.>XrX0XqX",
"qX0XrX>XT.-XyXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXrXUXGX3X5X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X3X7X&XE.>XrX0XqX",
"qX0XrX>XT.-XqX6X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X6XqXPXwXW.P.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.P.Y.I.-XtX0XqX",
"qX0XrX,XI.-XzXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXSX6X4X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X5X6X0XqXqXqX",
"qX0XtX=X}.MXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXcX6XwXqX",
"qXqXeX5X0XzXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXhXyX0XqXqX",
"qXqXqXwXqX7X7X8X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8X7X0XqXqXqX",
"qXqXqXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqX0X0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqX",
"qXqXqXrXtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8XqXqXqXqX",
"qX0XrX#X XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XkXSXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXDXmX0XqXqXqX",
"qX0XtX{.~.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XNXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXLX3X0XqXqXqX",
"qX0XtX|.(.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXwX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XwX$X).wXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX].).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqX7X7X0XqXqXqXqXqXqX7X6X0XqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXwXkXzXeXqXqXqXqXqX0XhXxXuX0XqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqX0XyX6X^ D *XeX0XqXqX9XiX| c P.uX9XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqX0XqX,XL   $ oXrX0XqX8XaXU.O   l.aX9XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqX9XdX4.9 Z 5 OXrX0XqX8XsX{   & v.pX9XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqX0XiX}.*X&.; OXrX0X8XaX].> k > z.aX9XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqX0XeXkXX.: OXrX0X9XsX1.= 7., l.aX9XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqX7XsXo.: OXrX9XuX:X; o.B.# l.pX9XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqX9XfXo.: OXrX9XpXg.@ $XY.# B.dX8XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqX9XfXo.: OXrXwX0Xg e C.+.o -.0XqX0XqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqX9XfXO.: OXrXwX5Xg @       q @XrX9XqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqX9XfX..= OXrX0X0X].~. X8.X 0.tX0XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqX9XdX%.7 @XrX0XqXpXpXzXS.2 B.sX9XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X9X9X9X0X0XqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.eXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeX8XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXwXwXqXqXqXqXqXqXqXqXwXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.9X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8X3XmXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).SXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXFXZXHXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}._.UXUXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXLXUXsXhXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXmX5X0X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X0X7XQ.iXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXrX4XP.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX5XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXrXeXrXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXuX}.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XP.sXUX@X~./././././././././././././././././././././././././././././././././.(.W./.eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XP.aXaXXXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOX+X;XwXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqX9X7X9XqXqXqXqX0X8X7X7X0XqXqXqXqXqXqXqXqXqXqXeX4XI.aXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXvX0XqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqX0XiXxXaXqXqXqX0XrXgXzXkXuXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXkXuX{.wXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXsXS.9 u.tX0X9XyX@X' d A I.yX0XqXqXqXqXqXqXqXqXeX4XI.sXUX9X6X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7XqX[.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXwXM.#   o.yX9XqX2Xk   B 1 $ _.pX9XqXqXqXqXqXqXqXeX4XI.sXUXeXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXtX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXwX,Xp L 1 +.uX8XiX~.g 7.bXW.  0.iX0XqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqX'.@X: O.iX0XwX6X&X4XmXE.  u.aX0XqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqX9XhX+X- +.uX0X0XwXtX8X3.q r #XyX0XqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqX9XtX+X- +.uX0XqX0XqX2X,   ] qXwX0XqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqX9XiX@X- +.uX0X0XeXyX0X7X4.  z.pX0XqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqX9XiX@X- +.uX0XwX2X@X7XtX;Xp J qXwXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqX9XiX@X; +.uX7XfXB.y E.BX*X5 T qXwXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqX9XiX+X% X.iX8XuX`.= 1 O.b   B.pX0XqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqXqX9X9XqXqXqXqX0X9X9X9X9X9XqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqX0XuX#Xq ;.uX0X9XiXY.z * 9 a.wXqX0XqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqX9XaXfXwXqXqXqXpXgXgXgXhXsX0XqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXtXeXqXqXqXqXtXuXyXyXuXwXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqX9XuX`.T.6XwXqXqX{.P.I.I.K._.tX0XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XqXqXqX0XqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqX9XdXA.    oXrXqX0XG         N xX6XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqX9XuXm.+ > 9 OXrXqXwXY w A.R.L.].tX0XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqX9XfXk.8.X.> OXrXqXeXJ d wXnXhXiX0XqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXwX0XlX+.: OXrXqXeXP y ^.oX-XrX0XqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqX9XfXo.: OXrXqX0XE       d !.iX9XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqX8XfXo.: OXrXqXqX' 3 4.l.@ z rX9X0XqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqX9XfXo.: OXrX0XqX+X XuXbX{ 2 ].yX9XqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqX9XfXo.: OXrX0XqX-X3XtXdX&.< (.uX9XqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqX9XdX@.2 +XrXqXeXF : W.&X7 y 5XqX0XqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqX8XgX_   XXrX9XtXY.;     % j.dX8XqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXMX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4XI.sXUXwX0XqXqXqXqXqXqXqXqXqX0XyXI.u.<XwX0XqXtX[.t.w.T.iX0XqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.).UXBX8XrXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXtX6XI.sXUXwX0XqXqXqXqXqXqXqXqXqXqX0XdXzXeXqXqXqX9XuXxXcXsX9XqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}._.UXdX).(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.(.).I.pXUXwX0XqXqXqXqXqXqXqXqXqXqXqX8X7X0XqXqXqXqX9X7X7X8XqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX}.`.xXoX{.|.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}. X`.hXUXwX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.0XrXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXyXqXBXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.eX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX6XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXwX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XrX{.).eXqXqXqX",
"qX0XtX|./.wXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XMXUXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXiX}.).eXqXqXqX",
"qX0XtX|./.eXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeX8XNXUX9X-X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X;X,X].`.eXqXqXqX",
"qX0XtX|./.0X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8X3XmXfX~.P.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.Y.(.eXqXqXqX",
"qX0XtX}._.bXGXDXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXFXDXPXCXnXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXnX0XqXqXqX",
"qX0XrX+XsXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXKXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXJX9XqXqXqX",
"qXqXqXwXwX9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9XqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqXqXqXqX",
"qXqXqXqX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXtXwXqXqXqX",
"qXqXwX9X_.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX8XkXUXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXUXnX9XqXqXqX",
"qXqXwX9X/.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXHXtXpXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXpXyX X7XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXDX5X0X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9XqX2X^.0XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX5X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqXqXqX0X8XqXqXqXqXqX8X9XqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqXqX0XeXgXeXqXqXqX0XdXpX0XqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqX0XiX6XD.1XeXqX0XrXI.'.rX0XqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqX0XeX,XZ   _.iX8XiX{.  ' dX9XqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqX9XaXP.) a /.iX7XfXO.  %.aX9XqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqX0XuX3Xt ^.iXrX@Xf C | sX9XqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqX0XtX*Xr /.yXkX*.o.:.' gX9XqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqX0XtX=Xr ^.dX<X0 g./ I uX0XqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqX0XtX=Xt ^.gX#Xc f = w =XrX0XqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqX0XyX=X0 ^.pX0X7XsX` / fX9XqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.5XeXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXeX8XvXFX7XwXqXqXqXqXqXwX8XXX5XwXqXwXrX*X&XeXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.1X8X6X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X3XxXFX7XwXqXqXqXqXqXqXwXiXeXqXqXqX0XyXyX0XqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X/.gXCXBXBXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXBXVXMXSXSX8XwXqXqXqXqXqXqXqX0XqXqXqXqXqX0X0XqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X/.DXHXNXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXBXZXjXaXGX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.AXfX3X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X6XqX].4XKX6XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXkX9XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXuX|.6XKX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX|.5XKX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX|.5XJX6XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XwX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX|.5XIXqXyXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXtXuX8X).9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX|.5XbX(.`.`._._._._._._._._._._._._._._._._._._._._.`.(.Q.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqX0X9X0XqXqXqX9XqX9X0XqXqXqXqXqX0XyX X2XmXyXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXaXiXqXqXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqX0XrXsXrXqXqXeXsXuXaXtX0XqXqXqXqX0XyX|.4XUXCXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXAXDX0X7XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqX0XeX7XA ` iX0X8X..7 K =XtX0XqXqXqX0XyX|.5XHX1X7X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X8X<X~.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqX0XuXo.@ L yXaXZ.e E.c ..hX8XqXqXqX0XyX|.5XKX7XwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXeX5X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqX0X*X5.H pXwX>X:XvXU X.hX9XqXqXqX0XyX|.5XKX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqX8XnX7.S aX0XqXaXN . +XiX9XqXqXqX0XyX|.5XKX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqX8XjX6.D aX9XyXpX].n ,.dX9XqXqXqX0XyX|.5XKX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqX8XkX8.H iXiXP.D.UXa.k yXqXqXqXqX0XyX|.5XKX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqX8XlX>.v iXdXc.= &.8 ;.dX9XqXqXqX0XyX|.5XKX7XwXqXqXqXqXqXqX9X0XqXqXqX0XqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqX9XaXH.y.yX9XuXb.R 9.9XeX0XqXqXqX0XyX|.5XKX7XwXqXqXqXqXqXqXpXuXwXqXqXtXtXtXrXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqX0XpXgX0XqX0XfXvXjXwXqXqXqXqXqX0XyX|.5XKX7XwXqXqXqXqX9XsXg.w  XpX1XF r r P yX0XqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqXqX9X8XqXqXqX9X7X8XqXqXqXqXqXqX0XyX|.5XKX7XwXqXqXqX9XaXI.q - /.dX>Xw q._.^.wXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX|.5XKX7XwXqXqXqX0XrX-X).s ~.dX,Xg H.dXgXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX|.5XKX7XwXqXqXqXqX9XpX,Xe ^.dX,X8 & 5 6.aX9XqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX|.5XKX7XwXqXqXqXqX0XtX*Xr ^.aX5Xq.U.N.1 $XtX0XqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX8XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XyX|.5XKX7XwXqXqXqXqX0XtX-Xu /.aX5X{.vX6Xq /.pX9XqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.SXjX7XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XtX|.5XKX7XwXqXqXqXqX0XyX*X< Q.sX7Xg A J f 0XqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.AXkXqXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXeXpX X5XKX7XwXqXqXqXqX0XrX1X,.@XrXyXOX| [ .XuX0XqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X^.FXdX=X,X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X>X2X_.5XKX6XwXqXqXqXqXqXqXwXjXrXqX0XtXxXxXyX0XqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X).hX#X(.`._._._._._._._._._._._._._._._._._._._._._.`.~.eXJX7XwXqXqXqXqXqXqXqX7X0XqXqX0X7X7X0XqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.2XwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeX8XvXFX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.5XeX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXeX4X(.9XwXqXqX",
"qXqXwX9X(.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XcXFX7XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XwX4X(.9XwXqXqX",
"qXqXwX9X(.5XeXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX7XvXFX0XtXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXyX7X).9XwXqXqX",
"qXqXwX9X).4XqX9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X0X5XcXDX=X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X:X;X>X&X~.9XwXqXqX",
"qXqXwX9X~.7XaXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXpXtXnXiX}. X|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.+X0XqXqXqX",
"qXqXwX7X$XAXUXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXLXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXeX0XqXqX",
"qXqXqX0XeXtXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXqXqXqXqX",
"qXqXqXqXqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqXqX",
"qXqXqXwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X7X8XqXqXqXqX",
"qXqXwX6X4XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XsXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXgXqXqXqXqX",
"qX0XrX-XOXtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XFXVXnXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXNX0X8XwXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXwX6X7X7X7X7X7X7X7X7X7X7X7X7X7X7X8X5X].0XqXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXuXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwX0X|.0XqXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXyX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX9X|.0XqXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXyX0XqXqXqXqX9X9XqXqXqX8X0XqXqXqXwX9X|.0XqXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXyX0XqXqXqX9XpXpX0XqXqXfXrX0XqXqXwX9X|.0XqXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXyX0XqXqX9XaX^./.uX0XqXD.:XrX0XqXwX9X|.0XqXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXyX0XqX0XyX@X5 @.gXiXU.  _.pX9XqXwX9X|.0XqXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXyX0XqX0XqXqXe.;.fXpX' r _.pX9XqXwX9X|.0XqXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXyX0XqXqX8XzXc.#.mXY.+.o.E.sX9XqXwX9X|.0XqXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXyX0XqXqX8XjXh.O.ZX4.v q g.fX9XqXwX9X|.0XqXqXqX",
"qX0XrX;X@XtXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXAXyX0XqXqX8XhXc.:.kX-X{.L K.sX9XqXwX9X|.0XqXqXqX",
"qX0XrX;X+XqX7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X6XAXyX0XqXqXqXwX7X5XqXrXaX7X0XqXqXqXwX9X|.0XqXqXqX",
"qX0XtX=X-XbXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXxXlXFXyX0XqXqXqXqXwXeXqX0X9XeXqXqXqXqXwX9X|.0XqXqXqX",
"qX0XtX&XqXJXxXnXbXbXbXbXbXbXbXbXbXbXbXbXbXbXMXyXmXiX9XqXqXqXqXqXqXqXqXqX0XqXqXqXqXwX9X|.0XqXqXqX",
"qX0XtX&XqXzX3X8X7X7X7X7X7X7X7X7X7X7X7X7X7X6XqX{.xXpX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX9X|.0XqXqXqX",
"qX0XtX&XqXvX8XwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXtXoXcXiX9XqX0X0X0X0X0X0X0X0X0X0X0X0X0XqX8X}.0XqXqXqX",
"qX0XtX&XqXvX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqX0XtXXXvXfXrXyXtXtXtXtXtXtXtXtXtXtXtXtXtXyXrX X0XqXqXqX",
"qX0XtX&XqXvX7XwXqXqXqX0X8XqXqX9X8X0XqXqXqX0XrXXXkX>XoX@X+X+X+X+X+X+X+X+X+X+X+X+X+X@XoX_.qXqXqXqX",
"qX0XtX&XqXvX7XwXqXqX0XyXgXqX0XaXzXrX0XqXqX0XrXoXfXhXpXaXaXaXaXaXaXaXaXaXaXaXaXaXaXaXsXyX0XqXqXqX",
"qX0XtX&XqXvX7XwXqX0XuX@XM.wXyXR.8.-XtX0XqX0XtX.XbXbXhXkXkXkXkXkXkXkXkXkXkXkXkXkXjXjXkX:X8XwXqXqX",
"qX0XtX&XqXvX7XwXqXqXwXU p uX=XR +.! pX9XqX0XrXXXxXyX6X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X5X].0XqXqXqX",
"qX0XtX&XqXvX7XwXqXqXwX/.E 9X6X8Xe.} dX9XqX0XrXXXcXpX0XwXqXqXqXqXqXqXqXqXqXqXqXqXqXwX0X|.0XqXqXqX",
"qX0XtX&XqXvX7XwXqX0XiX&XI 7XuXhXT -.dX9XqX0XrXXXcXpX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX9X|.0XqXqXqX",
"qX0XtX&XqXvX7XwXqX0XuXOXH rXoXM.1Xb 5XeX0X0XrXXXcXpX9XqXqXqXqX8X9XqX0X8X8X0XqXqXqXwX9X|.0XqXqXqX",
"qX0XtX&XqXvX7XwXqX0XyX$X( qX1XE v t.pX9XqX0XrXXXcXpX9XqXqXqXqXhXpX9XuXjXhXtX0XqXqXwX9X|.0XqXqXqX",
"qX0XtX&XqXvX7XwXqXqXqX0X7X0XtXrX>XiXqXqXqX0XrXXXcXpX9XqXqX0XyX3.j.xXL.E W ^.pX9XqXwX9X|.0XqXqXqX",
"qX0XtX&XqXvX7XwXqXqXqXqXwXqX0XqXrX0XqXqXqX0XrXXXcXpX9XqX9XuXXXi +.AX5...:X>XeXqXqXwX9X|.0XqXqXqX",
"qX0XtX&XqXvX7XwXqXqXqXqXqXqXqXqX0XqXqXqXqX0XrXXXcXpX9XqXqX9XhXb.$.ZXq.p q.2XeX0XqXwX9X|.0XqXqXqX",
"qX0XtX&XqXvX7XwXqXqXqXqXqXqXqXqXqXqXqXqXqX0XrXXXcXpX9XqXqX8XjXk.%.vX!.Z.X.<.jX8XqXwX9X|.0XqXqXqX",
"qX0XtX&XqXcX6XqX0X0X0X0X0X0X0X0X0X0X0X0X0X0XrX.XcXpX9XqXqX8XkXd. .mXL.F.<.=.jX8XqXwX9X|.0XqXqXqX",
"qX0XtX&XqXmXqXtXtXtXtXtXtXtXtXtXtXtXtXtXtXrXiXOXcXpX9XqXqX9XsXL.g.jXOX! _ ;XtX0XqXwX9X|.0XqXqXqX",
"qX0XtX&XwXiXXX$X#X#X#X#X#X#X#X#X#X#X#X#X#X@X%X_.vXpX9XqXqXqX0XyXiX9XyXhXgXrX0XqXqXwX9X|.0XqXqXqX",
"qX0XrX-X&X4X*X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-X-XCXuX0XqXqXqXqX0X9XqX0X8X8X0XqXqXqXwX9X|.0XqXqXqX",
"qX0XrX;X+XuXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXtXeXSXyX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX9X|.0XqXqXqX",
"qX0XrX;X@XrX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX9XAXyX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXwX9X|.0XqXqXqX",
"qX0XrX;X@XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XAXyX9XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X|.0XqXqXqX",
"qX0XrX;X@XrX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX9XSXiXqXeXwXwXwXwXwXwXwXwXwXwXwXwXwXeX0X}.0XqXqXqX",
"qX0XrX-XOXuXwXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXeXMX%X XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX.X}.qXqXqXqX",
"qXqXrX>XrXHXAXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXSXDXAXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXNXmXqXqXqXqX",
"qXqXqXqXrXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXeXqXqXqXqX",
"qXqXqXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXqXqXqXqXqX",
"qXqXqXwXwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX9X8X8X8X8X8X8X8X8X8X8X8X8X8X8X8X7X8XqXqXqXqX",
"qXqXwX6X5XwXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XsXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXgXqXqXqXqX",
"qX0XrX-X$XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX0XDXnXcXvXvXvXvXvXvXvXvXvXvXvXvXcXnX9X8XwXqXqX",
"qX0XrX;X%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXVX0X7X7X7X7X7X7X7X7X7X7X7X7X7X7X7X{.8XwXqXqX",
"qX0XrX;X%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXCXrXqXwXwXwXwXwXwXwXwXwXwXwXwXwXwXXX8XwXqXqX",
"qX0XrX;X%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXCXrX0XqXqXqXqX0XqXqXqX0XqXqXqXqXqX.X8XwXqXqX",
"qX0XrX;X%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXCXrX0XqXqXqXqXrXqXqXqXrXqXqXqXqXqX.X8XwXqXqX",
"qX0XrX;X%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXCXrX0XqXqXeXrX<XwXqXwX1XqXqXqXqXqX.X8XwXqXqX",
"qX0XrX;X%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXCXrX0XqX0XiX} Q aXdXM.j eXqXqXqXqX.X8XwXqXqX",
"qX0XrX;X%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXCXrX0XqXqXeXh.' iXpXP v 0XwX0XqXqX.X8XwXqXqX",
"qX0XrX;X%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXCXrX0XqX9XaXoX] xXJ...@.3XeXqXqXqX.X8XwXqXqX",
"qX0XrX;X%XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXCXrX0XqX0XpX).! bX7.M u +XyX0XqXqX.X8XwXqXqX",
"qX0XrX;X%XtXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXCXrX0XqX0XuX.X4.uX7X}.#.3XeX0XqXqX.X8XwXqXqX",
"qX0XrX;X$XeX9X9X9X9X9X9X9X9X9X9X9X9X9X9X9X0XZXrX0XqXqXqXwXyXqXeXyXiXwXqXqXqXqX.X8XwXqXqX",
"qX0XtX*X8XGXBXVXVXVXVXVXVXVXVXVXVXVXVXVXCXmXCXrX0XqXqXqXqX0XqXqX0X0XqXqXqXqXqX.X8XwXqXqX",
"qX0XtX&XuXcXeXuXyXyXyXyXyXyXyXyXyXyXyXyXpX-XzXyX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX.X8XwXqXqX",
"qX0XtX&XyXhX6X0X0X0X0X0X0X0X0X0X0X0X0X9XeXOXzXyX9XqX0X0X0X0X0X0X0X0X0X0X0X0XqX.X8XwXqXqX",
"qX0XtX&XyXjX8XwXqXqXqXqXqXqXqXqXqXqXqXqXrX@XxXaXrXtXtXtXtXtXtXtXtXtXtXtXtXtXtXoX8XwXqXqX",
"qX0XtX&XyXjX8XqXqXqX0X8XqXqX8X8XqXqXqX0XrX@XjX,X%X*X*X*X*X*X*X*X*X*X*X*X*X*X&X'.9XwXqXqX",
"qX0XtX&XyXjX8XqXqX0XtXhXqXqXhXjXwXqXqX0XrX@XdXaXtXyXtXtXtXtXtXtXtXtXtXtXtXtXyXwX0XqXqXqX",
"qX0XtX&XyXjX8XqX0XtX*Xg.8XeXj.t.9XwXqX0XrX+XvXcXhXjXjXjXjXjXjXjXjXjXjXjXjXjXlX<X7XwXqXqX",
"qX0XtX&XyXjX8XqX9XaXe.w 8X|.:.[ d.jX8X0XrX@XzXeX7X8X8X8X8X8X8X8X8X8X8X8X8X8X8X}.8XwXqXqX",
"qX0XtX&XyXjX8XqXqXqX7X` =XpX3XV W.aX9X0XrX@XzXuX0XwXqXqXqXqXqXqXqXqXqXqXqXqXwXXX8XwXqXqX",
"qX0XtX&XyXjX8XqXqXwX9X/ ;X9XeX;.f.gX9X0XrX@XzXyX0XqXqXqX0X9XqX0X8X9XqXqXqXqXqX.X8XwXqXqX",
"qX0XtX&XyXjX8XqXqXwX8XL 3X(. . .t.hX8X0XrX@XzXyX0XqXqX0XtXaX9XyXjXhXwXqXqXqXqX.X8XwXqXqX",
"qX0XtX&XyXjX8XqXqXqX0XT.5XtXV.k.wXwXqX0XrX@XzXyX0XqX0XyX*X~.iX+Xx.M.7XwXqXqXqX.X8XwXqXqX",
"qX0XtX&XyXjX8XqXqXqXqXaXwX0XgXjXqXqXqX0XrX@XzXyX0XqXqXyXR F BX3.^ V.3XeXqXqXqX.X8XwXqXqX",
"qX0XtX&XyXjX8XqXqXqXqX9XqXqX9X8XqXqXqX0XrX@XzXyX0XqXqXyXY.[ nX3.I ].yX0XqXqXqX.X8XwXqXqX",
"qX0XtX&XyXjX8XqXqXqXqXqXqXqXqXqXqXqXqX0XrX@XzXyX0XqX0XaX}.] jXI.g.I /.pX9XqXqX.X8XwXqXqX",
"qX0XtX&XyXhX7XqXqXqXqXqXqXqXqXqXqXqXqX0XrX+XzXyX0XqX0XaX(.W lXK.V.! E.sX9XqXqX.X8XwXqXqX",
"qX0XtX&XuXlX9XeXeXeXeXeXeXeXeXeXeXeXeXwXyX@XzXyX0XqX0XtX&Xn.aX#XO.h.yX0XqXqXqX.X8XwXqXqX",
"qX0XtX*XqX2X|.oXXXXXXXXXXXXXXXXXXXXXXXXXoX].vXtX0XqXqX0XrXsX0XtXlXfXqXqXqXqXqX.X8XwXqXqX",
"qX0XrX;X%X9X5X6X6X6X6X6X6X6X6X6X6X6X6X6X6X7XCXrX0XqXqXqX0X9XqX0X8X8XqXqXqXqXqX.X8XwXqXqX",
"qX0XrX;X%XyXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXwXCXrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqX.X8XwXqXqX",
"qX0XrX;X%XrX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXCXeX0X0X0X0X0X0X0X0X0X0X0X0X0X0XqX.X8XwXqXqX",
"qX0XrX;X&XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXZXuXrXrXrXrXrXrXrXrXrXrXrXrXrXrXtXXX8XwXqXqX",
"qX0XrX-X#XtX0XqXqXqXqXqXqXqXqXqXqXqXqXqX0XwXnX%X+X@X@X@X@X@X@X@X@X@X@X@X@X@X+X[.9XqXqXqX",
"qXqXrX>XrXDXVXCXCXCXCXCXCXCXCXCXCXCXCXCXCXZXCXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXwXqXqXqX",
"qXqXqXqXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXrXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXuXtXqXqXqXqX",
"qXqXqXqX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0XqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX",
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qXqXqXqXqXqXqXqXqXqXqXqXqXqXqXqX0X9X0X0X9X9X9X9X9X9X9X0X9X9XqXqX",
"qXqX0XqXqXqXqXqXqXqXqXqXqXqXqXqXeXuXuXuXuXuXuXuXuXuXuXuXuXuXqXqX",
"wX6X&XeXqXqXqXqXqXqXqXqXqXqXqX0XMXmXvXvXvXvXvXvXvXvXvXvXmXpX8XwX",
"wX6X$XeX0XqXqXqXqXqXqXqXqXqXqX0XnXqX8X9X9X9X9X9X9X9X9X8XqX+X5XeX",
"wX6X%XeXqXqXqXqXqXqXqXqXqXqXqX0XnXrXqXwXwX0XqXwXqXqXwXqXrX%X6XwX",
"wX6X%XeX0XqXqXqXqXqXqXqXqXqXqX0XnXeX0XqXqXyXeX0XrXrX0XqXeX%X6XwX",
"wX6X%XeX0XqXqXqXqXqXqXqXqXqXqX0XnXeX0XqXeX@X4XyX:X>XrX0XeX%X6XwX",
"wX6X%XeX0XqXqXqXqXqXqXqXqXqXqX0XnXeX0XrX>XA ].vXD z.hX8XeX%X6XwX",
"wX6X%XeX0XqXqXqXqXqXqXqXqXqXqX0XnXeX0X9XaX9. XoXF K.dX8XeX%X6XwX",
"wX6X%XrXqXwXwXwXwXwXwXwXwXwXwXqXnXeXqX8XhX1.|.n.h u.hX8XeX%X6XwX",
"wX6X$X0X8X8X8X8X8X8X8X8X8X8X8X7XbXeX0X0XiXK.@XiXJ.Q.pX9XeX%X6XwX",
"eX5X;XlXhXhXhXhXhXhXhXhXhXhXhXhXNXwXqXqX0XiXrXqXaXuX0XqXeX%X6XwX",
"eX2X0XMXfXjXhXhXhXhXhXhXhXhXlXtXjXtX0XqXqX9X0XqX9X0XqX0XeX%X6XwX",
"eX3X9XsX5X8X8X8X8X8X8X8X8X7XqX*XpXuXqXwXwXwXwXwXwXwXwXwXrX%X6XwX",
"eX3X9XgX9XwXwX0X0XwX9X0XwXqXrX:XaXqX5X6X6X6X6X6X6X6X6X6X8XOX5XwX",
"eX3X9XfX8XwX0XsXuXqXjXpX0XqXrX:XtX8X3X4X4X4X4X4X4X4X4X3X4X<X9XwX",
"eX3X9XfX8X0XuXK.`.wXd.Q.yX9XrX;XdXcXhXjXjXjXjXjXjXjXjXjXlX0X7XwX",
"eX3X9XfX8X0XpX .f.8X5. .rX0XrX:XaXeX7X8X8X8X8X8X8X8X8X7X0X+X5XwX",
"eX3X9XfX8X9XfXY.h.NX}.O.yX0XrX:XaXyX0XwXwX9XqX0X8X0XwXqXrX%X6XwX",
"eX3X9XfX8X9XgXC.l.*X5.+.5XwXrX:XaXyX0XqXwXgXwXuXjXyX0XqXeX%X6XwX",
"eX3X9XfX8XqXtX=X#XeXC.}.yX9XrX:XaXyX0XwX9Xn.3X'.w.[.uX9XeX%X6XwX",
"eX3X9XfX8XqX0XrXtXqXgXuX0XqXrX:XaXyX9XrX1XS &X7.&.6XeX0XeX%X6XwX",
"eX3X9XfX8XqXqX0X0XqX8X9XqX0XrX;XaXyX0X8XhXu. XI.+.N.aX8XeX%X6XwX",
"eX3X9XhX0XrXeXeXeXeXeXeXeXeXyX>XaXyX0X8XgX2.].}.:.9.fX8XeX%X6XwX",
"eX2X0XyX>X2X1X1X1X1X1X1X1X1X4X#XaXyX0X0XtX.X3X;Xm.2XrX0XeX%X6XwX",
"eX5X-X1X&X=X=X=X=X=X=X=X=X=X=X&XzXrX0XqX0XuXeXrXhXeX0XqXeX%X6XwX",
"wX6X$XtXrXrXrXrXrXrXrXrXrXrXrXeXmXeX0XqXqX9X0X0X8X0XqX0XeX$X6XwX",
"wX6X%XeX0XqXqXqXqXqXqXqXqXqXqX0XnXyXeXrXrXrXrXrXrXrXrXeXyX&X6XwX",
"wX6X@XqX8X9X9X9X9X9X9X9X9X9X9X8XcX2X>X,X,X,X,X,X,X,X,X,X1X.X6XwX",
"eX5X4XMXvXvXvXvXvXvXvXvXvXvXvXbXmXtXtXtXtXtXtXtXtXtXtXtXtXtXqXqX",
"qX0XrXuXuXuXuXuXuXuXuXuXuXuXuXuXyXpXaXaXaXaXaXaXaXaXaXaXaXpXwXqX",
"qXqX0X9X0X9X9X9X9X9X9X9X9X9X9X0X0X9X9X9X9X9X9X9X9X9X9X9X9X9XqXqX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"0X9XqXqXqXqXqXqXqXqXqXqXyXaXaXaXaXaXaXaXaXaXaXwX",
"3X>XeXqXqXqXqXqXqXqXqXqXbXjXhXhXhXhXhXhXhXkXtX6X",
"3X:XrX0XqXqXqXqXqXqXqXwXzX8X9X8X7X9X8X7X8XqX=X2X",
"3X:XeX0XqXqXqXqXqXqXqXwXxXqXqXeXpXqXtXyX0XrX>X3X",
"3X:XeX0XqXqXqXqXqXqXqXwXxX0XwX7X`.rX-X@XtXeX:X3X",
"3X:XeX0XqXqXqXqXqXqXqXwXxX0XtX-X} fX,.p.jXqX:X3X",
"3X>XrXqXwXwXwXwXwXwXqXeXxXqX0XyXa.@XJ h.dXqX:X3X",
"3X;XqX8X8X8X8X8X8X8X8X0XzXqXqXeXS.3XB.D.pXwX:X3X",
"2X8XxXhXjXjXjXjXjXjXjXkXcX0XqXqXyXeXdXuX0XrX:X3X",
"1XiXfXuXiXiXiXiXiXiXaX0XaXeXqXqX0XqX9X0XqXrX>X3X",
"2XtXeX8X9X7X9X7X8X9XqX,XiXqX9X9X9X9X9X9X8XwX-X2X",
"2XyXyX0XwXdXeXaXpX0XeX2XrX7X5X5X5X5X5X5X5X6X<X7X",
"2XyXtXqX8Xz.3Xb.P.yXwX<XsXgXsXsXsXsXsXsXsXgXqX5X",
"2XyXtX0XwX;.-XU.<.aXqX1XiXqX9X9X7X8X6X8X8XqX-X2X",
"2XyXtX8XdXg.OXH.1.tXwX1XpXeXqXeXsXeXfXyX0XrX>X3X",
"2XyXtX9XrX{.3XF.(.tXwX1XpXeXwX3XU.3XV.XXtXeX:X3X",
"2XtXtX0X0XyXwXsXiX0XeX1XpXwXrX;X*.[./ #XrXwX:X3X",
"2XyXyXqXwXqXwX0XqXwXrX2XpXeX9XuXp.$X0.y.aXqX:X3X",
"2XyX0X5X6X6X6X6X6X5X8X;XiXeX0XwXY.4Xx.~.uXwX:X3X",
"3X<X>X-X-X-X-X-X-X-X-X-XhXwXqXqXuXwXpXuX0XrX:X3X",
"3X:XyXeXrXrXrXrXrXrXeXtXcXqXwXwXqXwX0XqXwXrX>X3X",
"3X;X0X7X8X8X8X8X8X8X8X9XlX6X7X7X7X7X7X7X6X9X*X2X",
"3X8XlXhXhXhXhXhXhXhXhXkXzX7X8X8X8X8X8X8X8X8X6X9X",
"0XyXaXaXaXaXaXaXaXaXaXaXpXsXsXsXsXsXsXsXsXsXsXeX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"qX0XqXqXqXqXqXqXtXuXyXyXyXyXyXqX",
"6X3XeXqXqXqXqXeXjXaXpXpXiXdXeX8X",
"6X2XeXqXqXqX0XrXsX7XtXwXtXqX<X6X",
"6X2XeXqXqXqXqXrXsXtX(.#XE.tX2X6X",
"6X1XqX9X9X9X9XwXaXuXQ.M.-.iX1X6X",
"6X7XaXiXiXiXiXsXdXqX2X>X#XeX2X6X",
"6XuXaXuXiXiXpXtXuX0XeXrXtXwX1X6X",
"7XeX0XwXqXwXqX5XwX8X7X7X7X9X3X8X",
"7XeXpX).(.S.7X8XuXyXtXtXtXuX8X7X",
"7XeXpX'.E.f.,X0XrX0XeXrX0XqX1X6X",
"7XeXeX7X<X$XwX7XrXuX^.F.K.pX1X6X",
"7XtXwXwXrXyXeX7XeXiX/.C.p.tX2X6X",
"7X5X1X<X<X,X<X<XuXwX6X2X*XrX2X6X",
"6X<X0X8X8X9X8XwXdX8XqXwXeXqX1X5X",
"6X0XdXaXaXaXaXfXsX8X9X9X8X0X6X9X",
"qXtXuXyXyXyXyXyXtXyXtXtXtXtXyXwX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
